Ls.vie = {
	"tt": "Tiếng Việt",

	"cols": {
		"c": "nút hành động",
		"dur": "thời lượng",
		"q": "chất lượng / bitrate",
		"Ac": "codec âm thanh",
		"Vc": "codec video",
		"Fmt": "định dạng / container",
		"Ahash": "checksum âm thanh",
		"Vhash": "checksum video",
		"Res": "độ phân giải",
		"T": "loại tệp",
		"aq": "chất lượng âm thanh / bitrate",
		"vq": "chất lượng video / bitrate",
		"pixfmt": "subsampling / pixel structure",
		"resw": "độ phân giải ngang",
		"resh": "độ phân giải dọc",
		"chs": "kênh âm thanh",
		"hz": "tốc độ lấy mẫu",
	},

	"hks": [
		[
			"misc",
			["ESC", "đóng nhiều mục"],

			"file-manager",
			["G", "chuyển đổi chế độ xem danh sách / lưới"],
			["T", "chuyển đổi ảnh thu nhỏ / biểu tượng"],
			["⇧ A/D", "kích thước ảnh thu nhỏ"],
			["ctrl-K", "xoá mục đã chọn"],
			["ctrl-X", "cắt mục đã chọn vào bảng nhớ tạm"],
			["ctrl-C", "sao chép mục đã chọn vào bảng nhớ tạm"],
			["ctrl-V", "dán (di chuyển/sao chép) tại đây"],
			["Y", "tải xuống mục đã chọn"],
			["F2", "đổi tên mục đã chọn"],

			"file-list-sel",
			["space", "chuyển đổi chọn tệp"],
			["↑/↓", "di chuyển con trỏ chọn"],
			["ctrl ↑/↓", "di chuyển con trỏ và khung nhìn"],
			["⇧ ↑/↓", "chọn tệp trước / sau"],
			["ctrl-A", "chọn tất cả tệp / thư mục"],
		], [
			"navigation",
			["B", "chuyển đổi đường dẫn / thanh điều hướng"],
			["I/K", "thư mục trước / sau"],
			["M", "thư mục cha (hoặc thu gọn hiện tại)"],
			["V", "chuyển đổi thư mục / tệp văn bản trong thanh điều hướng"],
			["A/D", "kích thước thanh điều hướng"],
		], [
			"audio-player",
			["J/L", "bài trước / sau"],
			["U/O", "lùi / tiến 10 giây"],
			["0..9", "nhảy đến 0%..90%"],
			["P", "phát/tạm dừng (cũng khởi động)"],
			["S", "chọn bài đang phát"],
			["Y", "tải xuống bài hát"],
		], [
			"image-viewer",
			["J/L, ←/→", "ảnh trước / sau"],
			["Home/End", "ảnh đầu / cuối"],
			["F", "toàn màn hình"],
			["R", "xoay theo chiều kim đồng hồ"],
			["⇧ R", "xoay ngược chiều kim đồng hồ"],
			["S", "chọn ảnh"],
			["Y", "tải xuống ảnh"],
		], [
			"video-player",
			["U/O", "lùi / tiến 10 giây"],
			["P/K/Space", "phát/tạm dừng"],
			["C", "tiếp tục phát bài tiếp theo"],
			["V", "vòng lặp"],
			["M", "tắt tiếng"],
			["[ and ]", "đặt khoảng lặp"],
		], [
			"textfile-viewer",
			["I/K", "tệp trước / sau"],
			["M", "đóng tệp văn bản"],
			["E", "chỉnh sửa tệp văn bản"],
			["S", "chọn tệp (để cắt/sao chép/đổi tên)"],
		]
	],

	"m_ok": "OK",
	"m_ng": "Hủy",

	"enable": "Bật",
	"danger": "NGUY HIỂM",
	"clipped": "đã sao chép vào bảng nhớ tạm",

	"ht_s1": "giây",
	"ht_s2": "giây",
	"ht_m1": "phút",
	"ht_m2": "phút",
	"ht_h1": "giờ",
	"ht_h2": "giờ",
	"ht_d1": "ngày",
	"ht_d2": "ngày",
	"ht_and": " và ",

	"goh": "bảng điều khiển",
	"gop": 'thư mục trước">trước',
	"gou": 'thư mục cha">lên',
	"gon": 'thư mục sau">tiếp',
	"logout": "Đăng xuất ",
	"login": "Đăng nhập",
	"access": "quyền truy cập",
	"ot_close": "đóng menu con",

	"ot_search": "`tìm kiếm các tệp theo thuộc tính, đường dẫn / tên, tag nhạc hoặc bất kỳ sự kết hợp nào của chúng$N$N`foo bar` = phải chứa cả «foo» và «bar»,$N`foo -bar` = phải chứa «foo» nhưng không chứa «bar»,$N`^yana .opus$` = bắt đầu bằng «yana» và là tệp «opus»$N`&quot;try unite&quot;` = chứa chính xác «try unite»$N$Nđịnh dạng ngày là iso-8601, như$N`2009-12-31` hoặc `2020-09-12 23:30:00`",

	"ot_unpost": "unpost: xoá các tệp đã tải lên gần đây hoặc huỷ những tệp đang tải dở",
	"ot_bup": "bup: trình tải lên cơ bản, hỗ trợ cả Netscape 4.0",
	"ot_mkdir": "mkdir: tạo thư mục mới",
	"ot_md": "new-file: tạo tệp văn bản mới",
	"ot_msg": "msg: gửi tin nhắn đến nhật ký máy chủ",
	"ot_mp": "tuỳ chọn trình phát phương tiện",
	"ot_cfg": "tuỳ chọn cấu hình",
	"ot_u2i": 'up2k: tải tệp lên (nếu bạn có quyền ghi) hoặc chuyển sang chế độ tìm kiếm để xem chúng có tồn tại ở đâu đó trên máy chủ không$N$Ntải lên có thế tiếp tục nếu bị gián đoạn, chạy đa luồng và giữ nguyên dấu thời gian tệp, nhưng tiêu tốn nhiều CPU hơn [🎈]&nbsp; (trình tải lên cơ bản)<br /><br />trong quá trình tải, biểu tượng này sẽ trở thành chỉ thị tiến trình!',
	"ot_u2w": 'up2k: tải tệp lên với hỗ trợ tiếp tục (đóng trình duyệt và thả lại tệp đó lên sau)$N$Nchạy đa luồng và giữ nguyên dấu thời gian tệp, nhưng tiêu tốn nhiều CPU hơn [🎈]&nbsp; (trình tải lên cơ bản)<br /><br />trong quá trình tải, biểu tượng này sẽ trở thành chỉ thị tiến trình!',
	"ot_noie": 'Vui lòng sử dụng Chrome / Firefox / Edge',

	"ab_mkdir": "tạo thư mục",
	"ab_mkdoc": "tạo tệp văn bản",
	"ab_msg": "gửi tin nhắn đến nhật ký máy chủ",

	"ay_path": "bỏ qua đến thư mục",
	"ay_files": "bỏ qua đến tệp",

	"wt_ren": "đổi tên các mục đã chọn$NPhím tắt: F2",
	"wt_del": "xóa các mục đã chọn$NPhím tắt: ctrl-K",
	"wt_cut": "cắt các mục đã chọn &lt;small&gt;(sau đó dán ở nơi khác)&lt;/small&gt;$NPhím tắt: ctrl-X",
	"wt_cpy": "sao chép các mục đã chọn vào bảng nhớ tạm$N(để dán ở nơi khác)$NPhím tắt: ctrl-C",
	"wt_pst": "dán một lựa chọn đã cắt / sao chép trước đó$NPhím tắt: ctrl-V",
	"wt_selall": "chọn tất cả các tệp$NPhím tắt: ctrl-A (khi tệp được chọn)",
	"wt_selinv": "đảo ngược lựa chọn",
	"wt_zip1": "tải thư mục này dưới định dạng nén",
	"wt_selzip": "tải lựa chọn dưới định dạng nén",
	"wt_seldl": "tải lựa chọn dưới dạng các tệp riêng biệt$NPhím tắt: Y",
	"wt_npirc": "sao chép thông tin bản nhạc theo định dạng irc",
	"wt_nptxt": "sao chép thông tin bản nhạc dưới dạng văn bản thuần túy",
	"wt_m3ua": "thêm vào danh sách phát m3u (bấm <code>📻copy</code> sau)",
	"wt_m3uc": "sao chép danh sách phát m3u vào bảng nhớ tạm",
	"wt_grid": "chuyển đổi chế độ xem danh sách / lưới $NPhím tắt: G",
	"wt_prev": "bài trước$NPhím tắt: J",
	"wt_play": "phát / tạm dừng$NPhím tắt: P",
	"wt_next": "bài sau$NPhím tắt: L",

	"ul_par": "tải lên song song:",
	"ut_rand": "ngẫu nhiên hoá tên tệp",
	"ut_u2ts": "sao chép dấu thời gian chỉnh sửa cuối$Ntừ hệ thống tệp của bạn lên máy chủ\">📅",
	"ut_ow": "ghi đè các tệp đã có trên máy chủ?$N🛡️: không bao giờ (sẽ tạo tên tệp mới)$N🕒: ghi đè nếu tệp trên máy chủ cũ hơn$N♻️: luôn ghi đè nếu hai tệp khác nhau$N⏭️: bỏ qua vô điều kiện tất cả các tệp hiện có", //m
	"ut_mt": "tiếp tục hash các tệp khác trong khi tải lên$N$NCó thể tắt nếu CPU hoặc HDD của bạn bị nghẽn",
	"ut_ask": 'yêu cầu xác nhận trước khi bắt đầu tải lên">💭',
	"ut_pot": "cải thiện tốc độ tải lên trên các thiết bị chậm$Nbằng cách đơn giản hoá giao diện người dùng",
	"ut_srch": "không tải lên, chỉ kiểm tra xem tệp$Nđã tồn tại trên máy chủ hay chưa (sẽ quét toàn bộ thư mục bạn có quyền đọc)",
	"ut_par": "tạm dừng tải lên bằng cách đặt thành 0$N$NTăng lên nếu kết nối chậm hoặc độ trễ cao$N$NGiữ ở mức 1 khi dùng LAN hoặc nếu ổ cứng máy chủ bị nghẽn",
	"ul_btn": "thả tệp / thư mục<br>ở đây (hoặc nhấn vào tôi)",
	"ul_btnu": "T Ả I  L Ê N",
	"ul_btns": "T Ì M  K I Ế M",

	"ul_hash": "hash",
	"ul_send": "gửi",
	"ul_done": "hoàn tất",
	"ul_idle1": "chưa có mục nào trong hàng chờ tải lên",
	"ut_etah": "tốc độ &lt;em&gt;hash&lt;/em&gt; trung bình và thời gian dự kiến để hoàn tất",
	"ut_etau": "tốc độ &lt;em&gt;tải lên&lt;/em&gt; trung bình và thời gian dự kiến để hoàn tất",
	"ut_etat": "tốc độ &lt;em&gt;tổng&lt;/em&gt; trung bình và thời gian dự kiến để hoàn tất",

	"uct_ok": "hoàn tất thành công",
	"uct_ng": "không hợp lệ: lỗi / bị từ chối / không tìm thấy",
	"uct_done": "đã xử lý: gồm cả thành công và không hợp lệ",
	"uct_bz": "đang hash hoặc tải lên",
	"uct_q": "nhàn rỗi, đang chờ",

	"utl_name": "tên tệp",
	"utl_ulist": "danh sách",
	"utl_ucopy": "sao chép",
	"utl_links": "đường dẫn",
	"utl_stat": "trạng thái",
	"utl_prog": "tiến trình",

	// keep short:

	// phần up2k
	"utl_404": "404",
	"utl_err": "LỖI",
	"utl_oserr": "Lỗi hệ thống",
	"utl_found": "tìm thấy",
	"utl_defer": "hoãn",
	"utl_yolo": "YOLO",
	"utl_done": "hoàn tất",

	"ul_flagblk": "tệp đã được thêm vào hàng chờ</b><br>tuy vậy đang có một tiến trình up2k đang chạy ở một tab khác<br>vui lòng đợi cho đến khi tiến trình đó hoàn tất hoặc bị hủy",
	"ul_btnlk": "cài đặt của máy chủ đã khóa tùy chọn ở trạng thái này",

	"udt_up": "Tải lên",
	"udt_srch": "Tìm kiếm",
	"udt_drop": "thả vào đây",

	"u_nav_m": '<h6>chọn phương thức tải lên</h6><code>Enter</code> = Tệp (một hoặc nhiều)\n<code>ESC</code> = Một thư mục (kèm thư mục con)',
	"u_nav_b": '<a href="#" id="modal-ok">Tệp</a><a href="#" id="modal-ng">Một thư mục</a>',

	// settings / config:
	"cl_opts": "tuỳ chọn",
	"cl_hfsz": "kích thước tệp",
	"cl_themes": "giao diện",
	"cl_langs": "ngôn ngữ",
	"cl_ziptype": "định dạng nén",
	"cl_uopts": "tuỳ chọn up2k",
	"cl_favico": "favicon",
	"cl_bigdir": "thư mục lớn",
	"cl_hsort": "#sắp xếp",
	"cl_keytype": "ghi chú bàn phím",
	"cl_hiddenc": "cột đã ẩn",
	"cl_hidec": "ẩn",
	"cl_reset": "đặt lại",
	"cl_hpick": "chạm vào tiêu đề cột để ẩn trong bảng bên dưới",
	"cl_hcancel": "đã hủy việc ẩn cột",
	"cl_rcm": "menu chuột phải", //m
	"cl_gauto": "lưới tự động", //m

	// settings / tuỳ chọn
	"ct_grid": '田 chế độ lưới',
	"ct_ttips": '༼ ◕_◕ ༽">ℹ️ tooltips',
	"ct_thumb": 'ở chế độ lưới, chuyển biểu tượng hoặc hình thu nhỏ$NPhím tắt: T">🖼️ ảnh thu nhỏ',
	"ct_csel": 'dùng CTRL và SHIFT để chọn tệp trong chế độ lưới">sel',
	"ct_dsel": 'dùng chọn bằng cách kéo trong chế độ lưới">kéo', //m
	"ct_dl": 'cưỡng chế tải xuống (không hiện thị trong dòng) khi nhấp vào tệp">dl',
	"ct_ihop": 'khi đóng trình xem ảnh, cuộn xuống tệp đã xem gần nhất">g⮯',
	"ct_dots": 'hiển thị tệp ẩn (nếu máy chủ cho phép)">dotfiles',
	"ct_qdel": 'khi xóa tệp, chỉ hỏi xác nhận một lần">qdel',
	"ct_dir1st": 'sắp xếp thư mục trước tệp">📁 first',
	"ct_nsort": 'sắp xếp tự nhiên (cho tên tệp có số ở đầu)">nsort',
	"ct_utc": 'hiển thị mọi thời gian theo UTC">UTC',
	"ct_readme": 'hiển thị README.md trong danh sách thư mục">📜 readme',
	"ct_idxh": 'hiển thị index.html thay cho danh sách thư mục">htm',
	"ct_sbars": 'hiển thị thanh cuộn">⟊',

	// tuỳ chọn up2k
	"cut_umod": "nếu tệp đã tồn tại trên máy chủ, cập nhật dấu thời gian chỉnh sửa cuối của máy chủ cho khớp với tệp cục bộ của bạn (yêu cầu quyền ghi và xóa)\">re📅",

	"cut_turbo": "nút YOLO, bạn gần như KHÔNG nên bật tuỳ chọn này:$N$Ndùng khi bạn đang tải lên một lượng tệp rất lớn và phải khởi động lại vì lý do nào đó, và muốn tiếp tục tải càng sớm sàng tốt$N$Ntuỳ chọn này thay thế kiểm tra hash bằng kiểm tra <em>&quot;kích thước tệp ở trên máy chủ có giống nhau không&quot;</em> nên nếu nội dung tệp khác nhau thì sẽ KHÔNG được tải lên$N$Nbạn nên tắt tuỳ chọn này sau khi tải lên xong, và &quot;tải lên&quot; lại các tệp đó để xác minh\">turbo",

	"cut_datechk": "không có tác dụng trừ khi nút turbo được bật$N$Ngiảm mức độ yolo một chút; kiểm tra xem dấu thời gian tệp trên máy chủ có khớp với của bạn không$N$Nnên <em>về lý thuyết</em> có thể phát hiện phần lớn tệp chưa xong hoặc bị lỗi, nhưng không thể thay thế cho việc chạy xác minh sau khi tắt turbo\">date-chk",

	"cut_u2sz": "kích thước (tính theo MiB) của mỗi khối tải lên; dùng kích thước khối lớn khi truyền ở khoảng cách lục địa. Hãy thử giá trị nhỏ hơn với kết nối không ổn định",

	"cut_flag": "đảm bảo chỉ một tab được tải lên tại một thời điểm $N -- tab khác cũng cần bật tùy chọn này $N -- tác dụng trong các tab cùng tên miền",

	"cut_az": "tải tệp theo thứ tự bảng chữ cái thay vì tệp nhỏ trước$N$Ntải lên theo thứ tự bảng chữ cái giúp dễ quan sát nếu có vấn đề trên máy chủ, nhưng làm tốc độ tải chậm hơn trên mạng cáp quang hoặc LAN",

	"cut_nag": "thông báo của hệ điều hành khi tải lên hoàn tất$N(chỉ khi trình duyệt hoặc tab không hoạt động)",
	"cut_sfx": "âm báo khi tải lên hoàn tất$N(chỉ khi trình duyệt hoặc tab không hoạt động)",

	"cut_mt": "dùng đa luồng để tăng tốc hash tệp$N$dùng web workers và cần $nhiều RAM hơn (tối đa thêm 512 MiB)$N$làm cho https nhanh hơn 30%, http nhanh hơn 4.5 lần\">mt",

	"cut_wasm": "dùng wasm thay vì bộ hash tích hợp của trình duyệt; nhanh hơn trên trình duyệt chromium nhưng làm tăng tải CPU, và nhiều bản chrome cũ có lỗi khiến trình duyệt dùng hết RAM và treo nếu bật tuỳ chọn này\">wasm",

	// favicon
	"cft_text": "chuỗi favicon (để trống và làm mới trang để tắt)",
	"cft_fg": "màu chữ",
	"cft_bg": "màu nền",

	// big dirs
	"cdt_lim": "số tệp tối đa hiển thị trong thư mục",
	"cdt_ask": "khi cuộn xuống cuối,$Nthay vì tải thêm tệp,$Nhỏi người dùng muốn làm gì",
	"cdt_hsort": "`số lượng luật sắp xếp(`,sorthref`) được đưa vào URL media. Đặt bằng 0 cũng sẽ bỏ qua các quy tắc sắp xếp trong liên kết media khi nhấp vào chúng",
	"cdt_ren": "bật menu chuột phải tùy chỉnh, menu mặc định vẫn truy cập được bằng shift + chuột phải\">bật", //m
	"cdt_rdb": "hiển thị menu chuột phải thông thường khi menu tùy chỉnh đã mở và nhấp chuột phải lần nữa\">x2", //m

	"tt_entree": "hiển thị thanh điều hướng (cây thư mục)$NPhím tắt: B",
	"tt_detree": "hiển thị đường dẫn$NPhím tắt: B",
	"tt_visdir": "cuộn đến thư mục đã chọn",
	"tt_ftree": "chuyển đổi cây thư mục / tệp văn bản$NPhím tắt: V",
	"tt_pdock": "hiển thị thư mục cha trong thanh ghim trên cùng",
	"tt_dynt": "tự mở rộng khi cây mở rộng",
	"tt_wrap": "ngắt dòng",
	"tt_hover": "hiện thị dòng tràn khi rê chuột$N( không cuộn được nếu $N&nbsp; con trỏ chuột nằm ngoài cột trái )",
	"tt_gauto": "hiển thị dạng lưới hoặc danh sách tùy theo nội dung thư mục", //m
	"tt_gathr": "dùng lưới nếu tỷ lệ tệp này là ảnh/video", //m

	"ml_pmode": "ở cuối thư mục...",
	"ml_btns": "lệnh",
	"ml_tcode": "mã hoá lại",
	"ml_tcode2": "mã hoá lại thành",
	"ml_tint": "tô màu",
	"ml_eq": "bộ cân bằng âm thanh",
	"ml_drc": "bộ nén dải động",
	"ml_ss": "bỏ qua khoảng lặng", //m

	"mt_loop": "lặp lại một bài\">🔁",
	"mt_one": "dừng sau một bài\">1️⃣",
	"mt_shuf": "trộn các bài trong thư mụcr\">🔀",
	"mt_aplay": "tự động phát nếu có ID bài trong link bạn nhấp để truy cập máy chủ$N$Ntắt tuỳ chọn sẽ ngăn URL của trang cập nhật theo ID bài khi phát nhạc, tránh tự động phát nếu cài đặt mất nhưng URL còn\">a▶",
	"mt_preload": "bắt đầu tải bài hát tiếp theo khi gần hết bài để phát liền mạch\">preload",
	"mt_prescan": "chuyển đến thư mục tiếp theo trước khi bài cuối cùng $Nkết thúc, giúp giữ trình duyệt hoạt động $N và không dừng phát nhạc\">nav",
	"mt_fullpre": "cố gắng tải trước toàn bộ bài;$N✅ bật với kết nối <b>không ổn định</b>,$N❌ tắt <b>với kết nối chậm</b>\">full",
	"mt_fau": "trên điện thoại, ngăn nhạc dừng nếu bài tiếp theo tải chậm (có thể gây lỗi hiển thị tag nhạc)\">☕️",
	"mt_waves": "thanh tiến trình bài hát dạng sóng:$Nhiển thị biên độ âm thanh trong thanh tiến trình\">~s",
	"mt_npclip": "hiển thị nút để sao chép bài đang phát\">/np",
	"mt_m3u_c": "hiển thị nút để sao chép $Nnhững bài đã chọn dưới dạng danh sách phát m3u8\">📻",
	"mt_octl": "tích hợp hệ điều hành (phím tắt media / OSD)\">os-ctl",
	"mt_oseek": "cho phép tìm kiếm qua tích hợp hệ điều hành$N$Nlưu ý: trên một số thiết bị (iphone), $Nthao tác này sẽ thay thế nút bài hát tiếp theo\">seek",
	"mt_oscv": "hiển thị bài album trên OSD\">art",
	"mt_follow": "giữ bài đang phát trong tầm nhìn\">🎯",
	"mt_compact": "giao diện điều khiển thu gọn\">⟎",
	"mt_uncache": "xoá bộ nhớ đệm &nbsp;(thử nếu trình duyệt lưu trữ đệm $Nmột bản nhạc bị lỗi và không thể phát)\">uncache",
	"mt_mloop": "lặp trong thư mục đang mở\">🔁 loop",
	"mt_mnext": "tải thư mục tiếp theo và tiếp tục\">📂 next",
	"mt_mstop": "dừng phát\">⏸ stop",
	"mt_cflac": "chuyển flac / wav sang {0}\">flac",
	"mt_caac": "chuyển aac / m4a sang {0}\">aac",
	"mt_coth": "chuyển mọi loại khác (trừ mp3) thành {0}\">oth",
	"mt_c2opus": "lựa chọn tốt nhất cho máy tính, laptop, android\">opus",
	"mt_c2owa": "opus-weba, cho iOS 17.5 trở lên\">owa",
	"mt_c2caf": "opus-caf, cho iOS 11 đến 17\">caf",
	"mt_c2mp3": "dùng trên thiết bị cũ\">mp3",
	"mt_c2flac": "chất lượng âm thanh tốt nhất, nhưng tệp tải xuống lớn\">flac",
	"mt_c2wav": "phát không nén (tệp còn lớn hơn nữa)\">wav",
	"mt_c2ok": "lựa chọn hợp lý",
	"mt_c2nd": "không phải định dạng khuyến nghị cho thiết bị, nhưng hãy thử nếu bạn muốn",
	"mt_c2ng": "thiết bị dường như không hỗ trợ định dạng này, nhưng hãy thử nếu bạn muốn",
	"mt_xowa": "có một vài lỗi trên iOS ngăn phát nền với định dạng này; vui lòng dùng caf hoặc mp3",
	"mt_tint": "mức nền (0-100) trên thanh tiến trình",
	
	"mt_eq": "`bật bộ cân bằng âm thanh và bộ tăng ích;$N$Nboost `0 &nbsp;` = âm lượng chuẩn 100% (không chỉnh)$N$Nwidth `1 &nbsp;` = stereo chuẩn (không chỉnh)$Nwidth `0.5` = 50% pha trái-phải$Nwidth `0 &nbsp;` = mono$N$Nboost `-0.8` &amp; width `10` = loại bỏ lời hát :^)$N$Nbật EQ giúp cho album được phát liền mạch không ngắt quãng, nên giữ các giá trị bằng 0 (trừ width = 1) nếu bạn không muốn thay đổi âm thanh gốc",

	"mt_drc": "bật bộ nén dải động (làm phẳng âm lượng / brickwaller); cũng bật EQ để cân bằng, nên đặt tất cả EQ trừ 'width' = 0 nếu không muốn$N$Ngiảm âm thanh trên THRESHOLD dB; với mỗi RATIO dB vượt THRESHOLD thì có 1 dB đầu ra, ví dụ tresh -24 và ratio 12 => âm lượng không vượt -22 dB, có thể tăng EQ boost lên 0.8 hoặc 1.8 với ATK 0 và RLS lớn 90 (chỉ Firefox; RLS max 1 trên browser khác)$N$NXem Wikipedia để hiểu chi tiết hơn",

	"mt_ss": "`bật bỏ qua im lặng; nhân tốc độ phát với `nh` gần đầu/cuối khi âm lượng dưới `am` và vị trí trong `dau`% đầu hoặc `cuoi`% cuối", //m
	"mt_ssvt": "ngưỡng âm lượng (0-255)\">am", //m
	"mt_ssts": "ngưỡng hoạt động (% bài, đầu)\">dau", //m
	"mt_sste": "ngưỡng hoạt động (% bài, cuối)\">cuoi", //m
	"mt_sssm": "hệ số tốc độ phát\">nh", //m

	"mb_play": "phát",
	"mm_hashplay": "phát bản nhạc này?",
	"mm_m3u": "bấm <code>Enter/OK</code> để phát\nbấm <code>ESC/Cancel</code> để chỉnh sửa",
	"mp_breq": "cần firefox 82+ hoặc chrome 73+ hoặc iOS 15+",
	"mm_bload": "đang tải...",
	"mm_bconv": "đang chuyển đổi sang {0}, vui lòng chờ...",
	"mm_opusen": "trình duyệt không hỗ trợ tệp aac / m4a;\nchuyển sang định dạng opus hiện đã được bật",
	"mm_playerr": "phát lỗi: ",
	"mm_eabrt": "Việc phát nhạc đã bị huỷ",
	"mm_enet": "Kết nối Internet không ổn định",
	"mm_edec": "Tệp này dường như đã bị hỏng??",
	"mm_esupp": "Trình duyệt của bạn không nhận dạng được định dạng tệp này.",
	"mm_eunk": "Lỗi không xác định",
	"mm_e404": "Không thể phát âm thanh; lỗi 404: Không tìm thấy tệp.",
	"mm_e403": "Không thể phát âm thanh; lỗi 403: Từ chối truy cập.\n\nThử nhấn F5 để tải lại, có thể bạn đã đăng xuất",
	"mm_e415": "Không thể phát âm thanh; lỗi 415: Chuyển đổi tệp thất bại; kiểm tra nhật ký máy chủ.", //m
	"mm_e500": "Không thể phát âm thanh; lỗi 500: Kiểm tra nhật ký máy chủ.",
	"mm_e5xx": "Không thể phát âm thanh; lỗi máy chủ ",
	"mm_nof": "không tìm thấy thêm tệp âm thanh nào gần đó",
	"mm_prescan": "Đang tìm bài nhạc tiếp theo để phát...",
	"mm_scank": "Đã tìm thấy bài nhạc tiếp theo:",
	"mm_uncache": "đã xoá bộ nhớ đệm; tất cả bài nhạc sẽ được tải lại khi phát tiếp",
	"mm_hnf": "bài nhạc này không còn tồn tại nữa",

	"im_hnf": "hình ảnh này không còn tồn tại nữa",

	"f_empty": 'thư mục này trống',
	"f_chide": 'ẩn cột «{0}»\n\bạn có thế hiện lại nó trong tuỳ chọn cấu hình',
	"f_bigtxt": "tệp này nặng {0} MiB  -- xác nhận xem dưới dạng văn bản?",
	"f_bigtxt2": "chỉ xem phần cuối của tệp? điều này cũng sẽ bật theo dõi, hiển thị các dòng văn bản mới được thêm vào theo thời gian thực",
	"fbd_more": '<div id="blazy">hiện <code>{0}</code> của <code>{1}</code> tệp; <a href="#" id="bd_more">hiện {2}</a> hoặc <a href="#" id="bd_all">hiện tất cả</a></div>',
	"fbd_all": '<div id="blazy">đang hiện <code>{0}</code> của <code>{1}</code> tệp; <a href="#" id="bd_all">hiện tất cả</a></div>',
	"f_anota": "chỉ {0} trong {1} tệp được chọn;\nđể chọn toàn bộ thư mục, trước tiên hãy kéo xuống cuối",

	"f_dls": 'những đường dẫn đến tệp trong thư mục này\nđã được chuyển thành đường dẫn tải trực tiếp',
	"f_dl_nd": 'bỏ qua thư mục (hãy dùng tải zip/tar thay thế):\n', //m

	"f_partial": "Để tải an toàn một tệp đang được tải lên, hãy bấm vào tệp có cùng tên nhưng *không* có phần mở rộng <code>.PARTIAL</code>. Hãy nhấn CANCEL hoặc Escape để thực hiện.\n\nNếu nhấn OK / Enter, cảnh báo sẽ bị bỏ qua và bạn sẽ tải tệp tạm <code>.PARTIAL</code> thay vào đó, gần như chắc chắn dẫn đến dữ liệu bị hỏng.",

	"ft_paste": "dán {0} mục$NPhím tắt: ctrl-V",
	"fr_eperm": "không thể đổi tên:\nbạn không có quyền “move” trong thư mục này",
	"fd_eperm": "không thể xóa:\nbạn không có quyền “delete” trong thư mục này",
	"fc_eperm": "không thể cắt:\nbạn không có quyền “move” trong thư mục này",
	"fp_eperm": "không thể dán:\nbạn không có quyền “write” trong thư mục này",
	"fr_emore": "hãy chọn ít nhất một mục để đổi tên",
	"fd_emore": "hãy chọn ít nhất một mục để xóa",
	"fc_emore": "hãy chọn ít nhất một mục để cắt",
	"fcp_emore": "hãy chọn ít nhất một mục để sao chép vào bảng nhớ tạm",

	"fs_sc": "chia sẻ thư mục hiện tại",
	"fs_ss": "chia sẻ các tệp đã chọn",
	"fs_just1d": "bạn không thể chọn nhiều hơn một thư mục,\nhoặc trộn tệp và thư mục trong cùng một lựa chọn",
	"fs_abrt": "❌ hủy",
	"fs_rand": "🎲 tên ngẫu nhiên",
	"fs_go": "✅ tạo liên kết chia sẻ",
	"fs_name": "tên",
	"fs_src": "nguồn",
	"fs_pwd": "mật khẩu",
	"fs_exp": "hết hạn",
	"fs_tmin": "phút",
	"fs_thrs": "giờ",
	"fs_tdays": "ngày",
	"fs_never": "vĩnh viễn",
	"fs_pname": "tên liên kết tùy chọn; sẽ dùng tên ngẫu nhiên nếu để trống",
	"fs_tsrc": "tệp hoặc thư mục cần chia sẻ",
	"fs_ppwd": "mật khẩu tùy chọn",
	"fs_w8": "đang tạo liên kết chia sẻ...",
	"fs_ok": "nhấn <code>Enter/OK</code> để chép vào bảng nhớ tạm\nnhấn <code>ESC/Cancel</code> để đóng",

	"frt_dec": "có thể sửa một số trường hợp tên tệp bị lỗi\">url-decode",
	"frt_rst": "khôi phục tên gốc\">↺ reset",
	"frt_abrt": "hủy và đóng cửa sổ này\">❌ cancel",
	"frb_apply": "ÁP DỤNG ĐỔI TÊN",
	"fr_adv": "đổi tên theo lô / metadata / pattern\">advanced",
	"fr_case": "regex phân biệt hoa thường\">case",
	"fr_win": "tên tương thích Windows; thay <code>&lt;&gt;:&quot;\\|?*</code> bằng ký tự fullwidth tiếng Nhật\">win",
	"fr_slash": "thay <code>/</code> bằng ký tự khác để tránh tạo thư mục mới\">no /",
	"fr_re": "`regex áp dụng lên tên gốc; các nhóm bắt có thể được tham chiếu trong trường định dạng bên dưới như `(1)`, `(2)` ...",
	"fr_fmt": "`lấy cảm hứng từ foobar2000:$N`(title)` được thay bằng tên bài hát,$N`[(artist) - ](title)` bỏ qua phần trong ngoặc nếu artist trống,$N`$lpad((tn),2,0)` thêm số 0 để tracknumber đủ 2 chữ số",
	"fr_pdel": "xóa",
	"fr_pnew": "lưu dưới tên mới",
	"fr_pname": "nhập tên cho preset mới",
	"fr_aborted": "đã hủy",
	"fr_lold": "tên cũ",
	"fr_lnew": "tên mới",
	"fr_tags": "tag của các tệp đã chọn (chỉ xem, không chỉnh sửa):",
	"fr_busy": "đang đổi tên {0} mục...\n\n{1}",
	"fr_efail": "đổi tên thất bại:\n",
	"fr_nchg": "{0} tên mới đã bị chỉnh sửa do <code>win</code> và/hoặc <code>no /</code>\n\nTiếp tục với các tên đã chỉnh sửa?",

	"fd_ok": "hoàn tất xoá",
	"fd_err": "xoá gặp lỗi:\n",
	"fd_none": "không xóa được mục nào; có thể bị chặn bởi cấu hình máy chủ (xbd)?",
	"fd_busy": "đang xóa {0} mục...\n\n{1}",
	"fd_warn1": "XÓA {0} mục này?",
	"fd_warn2": "<b>Cảnh báo cuối!</b> Không thể hoàn tác. Xóa?",

	"fc_ok": "đã cắt {0} mục",
	"fc_warn": "đã cắt {0} mục\n\nnhưng: chỉ <b>tab trình duyệt này</b> có thể dán\n(vì lựa chọn quá lớn)",

	"fcc_ok": "đã sao chép {0} mục vào bảng nhớ tạm",
	"fcc_warn": "đã sao chép {0} mục vào bảng nhớ tạm\n\nnhưng: chỉ <b>tab trình duyệt này</b> có thể dán\n(vì lựa chọn quá lớn)",

	"fp_apply": "dùng các tên này",
	"fp_skip": "bỏ qua xung đột", //m
	"fp_ecut": "hãy cắt hoặc sao chép một số tệp / thư mục trước khi dán / di chuyển\n\nlưu ý: bạn có thể cắt / dán giữa các tab trình duyệt khác nhau",
	"fp_ename": "{0} mục không thể được di chuyển vào đây vì tên đã tồn tại. Hãy đặt tên mới bên dưới để tiếp tục, hoặc để trống (\"bỏ qua xung đột\") để bỏ qua:", //m
	"fcp_ename": "{0} mục không thể được sao chép vào đây vì tên đã tồn tại. Hãy đặt tên mới bên dưới để tiếp tục, hoặc để trống (\"bỏ qua xung đột\") để bỏ qua:", //m
	"fp_emore": "vẫn còn xung đột tên tệp cần xử lý",
	"fp_ok": "di chuyển OK",
	"fcp_ok": "sao chép OK",
	"fp_busy": "đang di chuyển {0} mục...\n\n{1}",
	"fcp_busy": "đang sao chép {0} mục...\n\n{1}",
	"fp_abrt": "đang hủy...",
	"fp_err": "di chuyển thất bại:\n",
	"fcp_err": "sao chép thất bại:\n",
	"fp_confirm": "di chuyển {0} mục này vào đây?",
	"fcp_confirm": "sao chép {0} mục này vào đây?",
	"fp_etab": "không đọc được bảng nhớ tạm từ tab trình duyệt khác",
	"fp_name": "đang tải lên tệp từ thiết bị. Hãy đặt tên cho tệp:",
	"fp_both_m": "<h6>chọn thao tác để dán</h6><code>Enter</code> = Di chuyển {0} tệp từ «{1}»\n<code>ESC</code> = Tải lên {2} tệp từ thiết bị",
	"fcp_both_m": "<h6>chọn thao tác để dán</h6><code>Enter</code> = Sao chép {0} tệp từ «{1}»\n<code>ESC</code> = Tải lên {2} tệp từ thiết bị",
	"fp_both_b": "<a href=\"#\" id=\"modal-ok\">Di chuyển</a><a href=\"#\" id=\"modal-ng\">Tải lên</a>",
	"fcp_both_b": "<a href=\"#\" id=\"modal-ok\">Sao chép</a><a href=\"#\" id=\"modal-ng\">Tải lên</a>",

	"mk_noname": "hãy nhập tên vào ô bên trái trước khi thực hiện :p",
	"nmd_i1": "hãy thêm cả phần mở rộng tệp bạn muốn, ví dụ <code>.md</code>",
	"nmd_i2": "bạn chỉ có thể tạo tệp <code>.{0}</code> vì bạn không có quyền xóa",

	"tv_load": "Đang tải tài liệu văn bản:\n\n{0}\n\n{1}% ({2} / {3} MiB)",
	"tv_xe1": "không thể tải tệp văn bản:\n\nlỗi ",
	"tv_xe2": "404, không tìm thấy tệp",
	"tv_lst": "danh sách các tệp văn bản trong",
	"tvt_close": "quay lại chế độ xem thư mục$NPhím tắt: M (hoặc Esc)\">❌ close",
	"tvt_dl": "tải xuống tệp này$NPhím tắt: Y\">💾 download",
	"tvt_prev": "hiển thị tài liệu trước đó$NPhím tắt: I\">⬆ prev",
	"tvt_next": "hiển thị tài liệu kế tiếp$NPhím tắt: K\">⬇ next",
	"tvt_sel": "chọn tệp &nbsp; (để cắt / sao chép / xóa / ...)$NPhím tắt: S\">sel",
	"tvt_j": "chuẩn hóa json$NPhím tắt: shift-J\">j",
	"tvt_edit": "mở tệp trong trình soạn thảo văn bản$NPhím tắt: E\">✏️ edit",
	"tvt_tail": "theo dõi thay đổi của tệp; hiển thị dòng mới theo thời gian thực\">📡 follow",
	"tvt_wrap": "ngắt dòng\">↵",
	"tvt_atail": "khóa cuộn ở cuối trang\">⚓",
	"tvt_ctail": "giải mã màu terminal (ansi escape codes)\">🌈",
	"tvt_ntail": "giới hạn scrollback (số byte văn bản được giữ trong bộ nhớ)",

	"m3u_add1": "đã thêm 1 bài vào danh sách phát m3u",
	"m3u_addn": "đã thêm {0} bài vào danh sách phát m3u",
	"m3u_clip": "danh sách phát m3u đã được chép vào bảng nhớ tạm\n\nbạn nên tạo một tệp văn bản mới tên bất kỳ.m3u rồi dán nội dung danh sách phát vào đó để có thể phát được",

	"gt_vau": "không hiện video, chỉ phát âm thanh\">🎧",
	"gt_msel": "bật chọn nhiều; ctrl-click để ghi đè$N$N&lt;em&gt;khi bật: nhấn đúp để mở tệp / thư mục&lt;/em&gt;$N$NPhím tắt: S\">multiselect",
	"gt_crop": "cắt chính giữa ảnh\">crop",

	"gt_3x": "ảnh độ nét cao\">3x",
	"gt_zoom": "zoom",
	"gt_chop": "chop",
	"gt_sort": "sắp xếp theo",
	"gt_name": "tên",
	"gt_sz": "dung lượng",
	"gt_ts": "ngày",
	"gt_ext": "loại",
	"gt_c1": "rút ngắn tên tệp hơn (hiện ít hơn)",
	"gt_c2": "rút ngắn tên tệp ít hơn (hiện nhiều hơn)",

	"sm_w8": "đang tìm...",
	"sm_prev": "kết quả bên dưới là từ lần tìm trước:\n  ",
	"sl_close": "đóng kết quả tìm kiếm",
	"sl_hits": "hiển thị {0} kết quả",
	"sl_moar": "tải thêm",

	"s_sz": "dung lượng",
	"s_dt": "ngày",
	"s_rd": "đường dẫn",
	"s_fn": "tên",
	"s_ta": "tag",
	"s_ua": "up@",
	"s_ad": "nâng cao",
	"s_s1": "tối thiểu MiB",
	"s_s2": "tối đa MiB",
	"s_d1": "ngày tối thiểu (iso8601)",
	"s_d2": "ngày tối đa (iso8601)",
	"s_u1": "tải lên sau",
	"s_u2": "và/hoặc trước",
	"s_r1": "đường dẫn chứa &nbsp; (cách nhau bằng dấu cách)",
	"s_f1": "tên chứa &nbsp; (thêm -nope để phủ định)",
	"s_t1": "tag chứa &nbsp; (^=bắt đầu, kết thúc=$)",
	"s_a1": "thuộc tính metadata cụ thể",

	"md_eshow": "không thể tải",
	"md_off": "[📜<em>readme</em>] đã tắt trong [⚙️] -- tài liệu bị ẩn",

	"badreply": "Không thể phân tích phản hồi từ máy chủ",

	"xhr403": "403: Access denied\n\nhãy thử nhấn F5, có thể bạn đã bị đăng xuất",
	"xhr0": "không rõ (có thể mất kết nối với máy chủ hoặc máy chủ đang offline)",
	"cf_ok": "rất tiếc, lớp bảo vệ DD" + wah + "oS đã kích hoạt\n\nmọi thứ sẽ tiếp tục sau khoảng 30 giây\n\nnếu không có gì xảy ra, hãy nhấn F5 để tải lại trang",
	"tl_xe1": "không thể liệt kê thư mục con:\n\nlỗi ",
	"tl_xe2": "404: Không tìm thấy thư mục",
	"fl_xe1": "không thể liệt kê tệp trong thư mục:\n\nlỗi ",
	"fl_xe2": "404: Không tìm thấy thư mục",
	"fd_xe1": "không thể tạo thư mục con:\n\nlỗi ",
	"fd_xe2": "404: Không tìm thấy thư mục cha",
	"fsm_xe1": "không thể gửi tin nhắn:\n\nlỗi ",
	"fsm_xe2": "404: Không tìm thấy thư mục cha",
	"fu_xe1": "không tải được danh sách unpost từ máy chủ:\n\nlỗi ",
	"fu_xe2": "404: Không tìm thấy tệp??",

	"fz_tar": "file gnu-tar không nén (linux / mac)",
	"fz_pax": "file tar định dạng pax không nén (chậm hơn)",
	"fz_targz": "gnu-tar với nén gzip mức 3$N$Nthường rất chậm nên$Nhãy dùng tar không nén",
	"fz_tarxz": "gnu-tar với nén xz mức 1$N$Nthường rất chậm nên$Nhãy dùng tar không nén",
	"fz_zip8": "zip với tên tệp utf8 (có thể lỗi trên windows 7 và cũ hơn)",
	"fz_zipd": "zip với tên tệp cp437 truyền thống, dành cho phần mềm rất cũ",
	"fz_zipc": "cp437 với crc32 tính sớm,$Ndành cho MS-DOS PKZIP v2.04g (tháng 10/1993)$N(mất thời gian xử lý lâu hơn trước khi tải xuống bắt đầu)",

	"un_m1": "bạn có thể xóa các lần upload gần đây (hoặc hủy những mục chưa hoàn tất) bên dưới",
	"un_upd": "làm mới",
	"un_m4": "hoặc chia sẻ các tệp hiển thị bên dưới:",
	"un_ulist": "hiện",
	"un_ucopy": "chép",
	"un_flt": "bộ lọc tùy chọn:&nbsp; đường dẫn phải chứa",
	"un_fclr": "xóa bộ lọc",
	"un_derr": "xóa unpost thất bại:\n",
	"un_f5": "có gì đó lỗi rồi, hãy thử tải lại trang hoặc nhấn F5",
	"un_uf5": "xin lỗi nhưng bạn cần tải lại trang (ví dụ nhấn F5 hoặc CTRL-R) trước khi có thể hủy upload này",
	"un_nou": "<b>cảnh báo:</b> máy chủ đang bận nên không thể hiển thị các upload chưa hoàn tất; hãy bấm “làm mới” sau một lúc",
	"un_noc": "<b>cảnh báo:</b> unpost cho các tệp đã upload xong không được bật hoặc không được phép trong cấu hình máy chủ",
	"un_max": "đang hiển thị 2000 tệp đầu tiên (hãy dùng bộ lọc)",
	"un_avail": "có thể xóa {0} tải lên gần đây<br />{1} mục chưa hoàn tất có thể hủy",
	"un_m2": "sắp xếp theo thời gian tải lên; mới nhất ở trên:",
	"un_no1": "không có tải lên nào đủ mới",
	"un_no2": "không có tải lên nào đủ mới khớp với bộ lọc đó",
	"un_next": "xóa {0} tệp kế bên dưới",
	"un_abrt": "hủy",
	"un_del": "xóa",
	"un_m3": "đang tải danh sách tải lên gần đây...",
	"un_busy": "đang xóa {0} tệp...",
	"un_clip": "{0} liên kết đã chép vào bảng nhớ tạm",

	"u_https1": "bạn nên",
	"u_https2": "chuyển sang https",
	"u_https3": "để có hiệu suất tốt hơn",

	"u_ancient": "trình duyệt của bạn quá cũ; bạn có thể <a href=\"#\" onclick=\"goto('bup')\">dùng bup</a> thay thế",
	"u_nowork": "cần Firefox 53+, Chrome 57+ hoặc iOS 11+",
	"tail_2old": "cần Firefox 105+, Chrome 71+ hoặc iOS 14.5+",
	"u_nodrop": "trình duyệt của bạn quá cũ để dùng kéo thả khi tải lên",
	"u_notdir": "đây không phải thư mục\n\ntrình duyệt của bạn quá cũ,\nvui lòng thử dùng dragdrop",

	"u_uri": "để kéo thả ảnh từ cửa sổ trình duyệt khác,\nvui lòng thả lên nút tải lên lớn",

	"u_enpot": "chuyển sang <a href=\"#\">giao diện đơn giản</a> (có thể tăng tốc độ tải lên)",
	"u_depot": "chuyển sang <a href=\"#\">giao diện đầy đủ</a> (có thể giảm tốc độ tải lên)",
	"u_gotpot": "đang chuyển sang giao diện đơn giản để cải thiện tốc độ tải lên\n\nbạn có thể đổi lại bất kỳ lúc nào",

	"u_pott": "<p>tệp: &nbsp; <b>{0}</b> hoàn tất, &nbsp; <b>{1}</b> lỗi, &nbsp; <b>{2}</b> đang chạy, &nbsp; <b>{3}</b> chờ</p>",

	"u_ever": "đây là trình tải lên cơ bản; up2k yêu cầu<br>Chrome 21 // Firefox 13 // Edge 12 // Opera 12 // Safari 5.1 trở lên",
	"u_su2k": "đây là trình tải lên cơ bản; <a href=\"#\" id=\"u2yea\">up2k</a> tốt hơn",

	"u_uput": "tối ưu tốc độ (bỏ qua checksum)",
	"u_ewrite": "bạn không có quyền ghi vào thư mục này",
	"u_eread": "bạn không có quyền đọc thư mục này",
	"u_enoi": "tìm kiếm tệp chưa được bật trong cấu hình máy chủ",
	"u_enoow": "ghi đè không khả dụng; cần quyền Xóa",

	"u_badf": "Đã bỏ qua {0} tệp (trong tổng {1}) có thể do quyền hệ thống tệp:\n\n",
	"u_blankf": "{0} tệp (trong tổng {1}) trống; vẫn tải lên?\n\n",
	"u_applef": "{0} tệp (trong tổng {1}) có thể không cần thiết;\nNhấn <code>OK/Enter</code> để BỎ QUA,\nNhấn <code>Cancel/ESC</code> để giữ lại và tải lên:\n\n",

	"u_just1": "\nCó thể sẽ hoạt động tốt hơn nếu bạn chỉ chọn một tệp",
	"u_ff_many": "nếu bạn dùng <b>Linux / macOS / Android</b> thì số lượng tệp này <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>có thể</em> làm Firefox crash</a>\nnếu xảy ra, vui lòng thử lại hoặc dùng Chrome",

	"u_up_life": "Tệp tải lên sẽ bị xóa khỏi máy chủ\n{0} sau khi hoàn tất",
	"u_asku": "tải {0} tệp này lên <code>{1}</code>",
	"u_unpt": "bạn có thể hoàn tác hoặc xóa lần tải lên này bằng biểu tượng ở góc trên bên trái 🧯",

	"u_bigtab": "sắp hiển thị {0} tệp\n\nviệc này có thể làm trình duyệt treo, bạn có chắc không?",
	"u_scan": "Đang quét tệp...",
	"u_dirstuck": "bộ lặp thư mục bị treo khi truy cập {0} mục sau; sẽ bỏ qua:",
	"u_etadone": "Hoàn tất ({0}, {1} tệp)",
	"u_etaprep": "(đang chuẩn bị tải lên)",
	"u_hashdone": "hash hoàn tất",
	"u_hashing": "hash",
	"u_hs": "đang bắt tay...",
	"u_started": "tệp đang được tải lên; xem biểu tượng [🚀]",
	"u_dupdefer": "bị trùng; sẽ xử lý sau khi hoàn tất các tệp khác",

	"u_actx": "nhấn vào dòng này để tránh giảm hiệu suất khi chuyển cửa sổ hoặc tab",
	"u_fixed": "OK;&nbsp; đã sửa 👍",

	"u_cuerr": "không tải được phần {0}/{1};\ncó thể không nghiêm trọng, tiếp tục\n\ntệp: {2}",
	"u_cuerr2": "máy chủ từ chối phần tải {0}/{1};\nsẽ thử lại sau\n\ntệp: {2}\n\nlỗi ",
	"u_ehstmp": "sẽ thử lại; xem góc dưới bên phải",
	"u_ehsfin": "máy chủ từ chối yêu cầu hoàn tất tải lên; đang thử lại...",
	"u_ehssrch": "máy chủ từ chối yêu cầu tìm kiếm; đang thử lại...",
	"u_ehsinit": "máy chủ từ chối yêu cầu bắt đầu tải lên; đang thử lại...",
	"u_eneths": "lỗi mạng khi thực hiện bắt tay; đang thử lại...",
	"u_enethd": "lỗi mạng khi kiểm tra tồn tại mục tiêu; đang thử lại...",
	"u_cbusy": "chờ máy chủ cho phép tiếp tục sau sự cố mạng...",
	"u_ehsdf": "máy chủ hết dung lượng!\n\nsẽ tiếp tục thử trong trường hợp có ai đó giải phóng dung lượng",

	"u_emtleak1": "có dấu hiệu cho thấy trình duyệt có thể bị rò rỉ bộ nhớ;\nvui lòng",
	"u_emtleak2": " <a href=\"{0}\">chuyển sang https (khuyến nghị)</a> hoặc ",
	"u_emtleak3": " ",
	"u_emtleakc": "thử cách sau:\n<ul><li>nhấn <code>F5</code> để tải lại trang</li><li>sau đó tắt nút &nbsp;<code>mt</code>&nbsp; trong &nbsp;<code>⚙️ cài đặt</code></li><li>và thử tải lại</li></ul>Tốc độ có thể chậm hơn một chút\nXin lỗi vì sự bất tiện\n\nPS: chrome v107 <a href=\"https://bugs.chromium.org/p/chromium/issues/detail?id=1354816\" target=\"_blank\">đã có bản sửa</a>",
	"u_emtleakf": "thử cách sau:\n<ul><li>nhấn <code>F5</code> để tải lại trang</li><li>sau đó bật <code>🥔</code> (potato) trong giao diện tải lên<li>và thử lại</li></ul>\nPS: firefox <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\">hy vọng sẽ có bản sửa</a>",

	"u_s404": "không tìm thấy trên máy chủ",
	"u_expl": "giải thích",
	"u_maxconn": "đa số trình duyệt giới hạn giá trị này ở mức 6, nhưng Firefox cho phép tăng bằng <code>connections-per-server</code> trong <code>about:config</code>",

	"u_tu": "<p class=\"warn\">CẢNH BÁO: turbo đang bật <span>&nbsp;client có thể không nhận diện và tiếp tục tải lại tệp chưa hoàn tất; xem tooltip nút turbo</span></p>",
	"u_ts": "<p class=\"warn\">CẢNH BÁO: turbo đang bật <span>&nbsp;kết quả tìm kiếm có thể không chính xác; xem tooltip nút turbo</span></p>",

	"u_turbo_c": "turbo bị tắt trong cấu hình máy chủ",
	"u_turbo_g": "đang tắt turbo vì bạn không có quyền liệt kê thư mục trong phân vùng này",

	"u_life_cfg": "tự xóa sau <input id=\"lifem\" p=\"60\" /> phút (hoặc <input id=\"lifeh\" p=\"3600\" /> giờ)",
	"u_life_est": "tệp sẽ bị xóa <span id=\"lifew\" tt=\"local time\">---</span>",
	"u_life_max": "thư mục này áp dụng\nthời gian tồn tại tối đa {0}",

	"u_unp_ok": "cho phép unpost trong {0}",
	"u_unp_ng": "không cho phép unpost",

	"ue_ro": "bạn chỉ có quyền đọc thư mục này\n\n",
	"ue_nl": "bạn chưa đăng nhập",
	"ue_la": "bạn đang đăng nhập với tài khoản \"{0}\"",
	"ue_sr": "bạn đang ở chế độ tìm kiếm tệp\n\nhãy chuyển sang chế độ tải lên bằng cách nhấn biểu tượng kính lúp 🔎 (bên cạnh nút SEARCH), rồi thử lại\n\nxin lỗi",
	"ue_ta": "hãy thử tải lên lại; giờ có thể được",
	"ue_ab": "tệp này đang được tải lên ở thư mục khác và cần hoàn tất trước khi có thể tải lên nơi khác.\n\nBạn có thể hủy và quên tiến trình ban đầu bằng biểu tượng ở góc trên bên trái 🧯",

	"ur_1uo": "OK: tệp đã tải lên thành công",
	"ur_auo": "OK: toàn bộ {0} tệp đã tải lên thành công",
	"ur_1so": "OK: đã tìm thấy tệp trên máy chủ",
	"ur_aso": "OK: đã tìm thấy toàn bộ {0} tệp trên máy chủ",

	"ur_1un": "Tải lên thất bại",
	"ur_aun": "{0} lần tải lên đều thất bại",

	"ur_1sn": "KHÔNG tìm thấy tệp trên máy chủ",
	"ur_asn": "{0} tệp KHÔNG tìm thấy trên máy chủ",

	"ur_um": "Hoàn tất\n{0} tải lên thành công,\n{1} tải lên thất bại",
	"ur_sm": "Hoàn tất\n{0} tệp tìm thấy trên máy chủ,\n{1} tệp KHÔNG tìm thấy",

	"rc_opn": "mở", //m
	"rc_ply": "phát", //m
	"rc_pla": "phát dưới dạng âm thanh", //m
	"rc_txt": "mở trong trình xem tệp", //m
	"rc_md": "mở trong trình soạn thảo văn bản", //m
	"rc_dl": "tải xuống", //m
	"rc_zip": "tải xuống dưới dạng gói nén", //m
	"rc_cpl": "sao chép liên kết", //m
	"rc_del": "xóa", //m
	"rc_cut": "cắt", //m
	"rc_cpy": "sao chép", //m
	"rc_pst": "dán", //m
	"rc_rnm": "đổi tên", //m
	"rc_nfo": "thư mục mới", //m
	"rc_nfi": "tệp mới", //m
	"rc_sal": "chọn tất cả", //m
	"rc_sin": "đảo ngược lựa chọn", //m
	"rc_shf": "chia sẻ thư mục này", //m
	"rc_shs": "chia sẻ lựa chọn", //m

	"lang_set": "tải lại trang để áp dụng thay đổi ngôn ngữ",

	"splash": {
		"a1": "tải lại",
		"b1": "xin chào khách &nbsp; <small>(bạn chưa đăng nhập)</small>",
		"c1": "đăng xuất",
		"d1": "ghi lại ngăn xếp",
		"d2": "hiển thị trạng thái của tất cả các luồng đang hoạt động",
		"e1": "tải lại cấu hình",
		"e2": "tải lại các tệp cấu hình (tài khoản/ổ đĩa/cờ ổ đĩa),$Nvà quét lại tất cả các ổ đĩa e2ds$N$Nchú ý: bất kỳ thay đổi nào đối với cài đặt toàn cục$Ncần khởi động lại hoàn toàn để có hiệu lực",
		"f1": "bạn có thể duyệt:",
		"g1": "bạn có thể tải lên:",
		"cc1": "thứ khác:",
		"h1": "vô hiệu hoá k304",
		"i1": "bật k304",
		"j1": "bật k304 sẽ ngắt kết nối client của bạn trên mỗi HTTP 304, tùy chọn này có thể ngăn một số proxy bị lỗi kẹt (đột ngột không tải được trang), <em>nhưng</em> nó cũng sẽ làm mọi thứ chậm hơn",
		"k1": "đặt lại cài đặt client",
		"l1": "đăng nhập để có thêm:",
		"m1": "chào mừng trở lại,",
		"n1": "404 không tìm thấy &nbsp;┐( ´ -`)┌",
		"o1": 'hoặc có thể bạn không có quyền truy cập -- thử mật khẩu hoặc <a href="' + SR + '/?h">về trang chủ</a>',
		"p1": "403 bị cấm &nbsp;~┻━┻",
		"q1": 'sử dụng mật khẩu hoặc <a href="' + SR + '/?h">về trang chủ</a>',
		"r1": "về trang chủ",
		".s1": "quét lại",
		"t1": "hành động",
		"u2": "thời gian kể từ lần ghi máy chủ cuối cùng$N( tải lên / đổi tên / ... )$N$N17d = 17 ngày$N1h23 = 1 giờ 23 phút$N4m56 = 4 phút 56 giây",
		"v1": "kết nối",
		"v2": "sử dụng máy chủ này như một ổ cứng cục bộ",
		"w1": "chuyển sang https",
		"x1": "đổi mật khẩu",
		"y1": "chỉnh sửa chia sẻ",
		"z1": "mở khóa chia sẻ này:",
		"ta1": "điền mật khẩu mới:",
		"ta2": "nhập lại mật khẩu mới:",
		"ta3": "mật khẩu không khớp, xin hãy thử lại",
		"nop": "LỖI: Mật khẩu không được để trống", //m
		"nou": "LỖI: Tên người dùng và/hoặc mật khẩu không được để trống", //m
		"aa1": "tệp đến",
		"ab1": "vô hiệu hóa no304",
		"ac1": "bật no304",
		"ad1": "bật no304 sẽ vô hiệu hóa tất cả bộ nhớ đệm; hãy thử tùy chọn này nếu k304 không đủ. Tùy chọn này sẽ làm lãng phí một lượng lớn lưu lượng mạng!",
		"ae1": "tải xuống đang hoạt động:",
		"af1": "hiển thị các tệp đã tải lên gần đây",
		"ag1": "hiển thị người dùng IdP đã biết", //m
	}
};
