
// //m으로 끝나는 줄은 검증되지 않은 기계 번역입니다

Ls.kor = {
	"tt": "한국어",

	"cols": {
		"c": "작업 버튼",
		"dur": "길이",
		"q": "품질/비트레이트",
		"Ac": "오디오 코덱",
		"Vc": "비디오 코덱",
		"Fmt": "형식/컨테이너",
		"Ahash": "오디오 체크섬",
		"Vhash": "비디오 체크섬",
		"Res": "해상도",
		"T": "파일 유형",
		"aq": "오디오 품질/비트레이트",
		"vq": "비디오 품질/비트레이트",
		"pixfmt": "서브샘플링/픽셀 구조",
		"resw": "가로 해상도",
		"resh": "세로 해상도",
		"chs": "오디오 채널",
		"hz": "샘플레이트",
	},

	"hks": [
		[
			"기타",
			["ESC", "다양한 창 닫기"],

			"파일 관리자",
			["G", "목록/그리드 보기 전환"],
			["T", "썸네일/아이콘 전환"],
			["⇧ A/D", "썸네일 이미지 크기"],
			["ctrl-K", "선택 항목 삭제"],
			["ctrl-X", "선택 항목 잘라내기"],
			["ctrl-C", "선택 항목 복사"],
			["ctrl-V", "여기에 붙여넣기 (이동/복사)"],
			["Y", "선택 항목 다운로드"],
			["F2", "선택 항목 이름 바꾸기"],

			"파일 목록 선택",
			["space", "파일 선택/해제"],
			["↑/↓", "선택 커서 이동"],
			["ctrl ↑/↓", "커서와 뷰포트 동시 이동"],
			["⇧ ↑/↓", "이전/다음 파일 선택"],
			["ctrl-A", "모든 파일/폴더 선택"],
		], [
			"탐색",
			["B", "브레드크럼/탐색창 전환"],
			["I/K", "이전/다음 폴더"],
			["M", "상위 폴더 (또는 현재 항목 닫기)"],
			["V", "탐색창에 폴더/텍스트 파일 표시 전환"],
			["A/D", "탐색창 크기"],
		], [
			"오디오 플레이어",
			["J/L", "이전/다음 곡"],
			["U/O", "10초 뒤로/앞으로 건너뛰기"],
			["0..9", "0%..90% 지점으로 이동"],
			["P", "재생/일시정지 (시작 포함)"],
			["S", "재생 중인 곡 선택"],
			["Y", "곡 다운로드"],
		], [
			"이미지 뷰어",
			["J/L, ←/→", "이전/다음 이미지"],
			["Home/End", "첫/마지막 이미지"],
			["F", "전체 화면"],
			["R", "시계 방향으로 회전"],
			["⇧ R", "반시계 방향으로 회전"],
			["S", "이미지 선택"],
			["Y", "이미지 다운로드"],
		], [
			"비디오 플레이어",
			["U/O", "10초 뒤로/앞으로 건너뛰기"],
			["P/K/Space", "재생/일시정지"],
			["C", "다음 파일 계속 재생"],
			["V", "반복"],
			["M", "음소거"],
			["[ 와 ]", "반복 구간 설정"],
		], [
			"텍스트 파일 뷰어",
			["I/K", "이전/다음 파일"],
			["M", "텍스트 파일 닫기"],
			["E", "텍스트 파일 편집"],
			["S", "파일 선택 (잘라내기/복사/이름 바꾸기용)"],
			["Y", "텍스트 파일 다운로드"], //m
			["⇧ J", "json 미화"], //m
		]
	],

	"m_ok": "확인",
	"m_ng": "취소",

	"enable": "활성화",
	"danger": "위험",
	"clipped": "클립보드에 복사되었습니다",

	"ht_s1": "초",
	"ht_s2": "초",
	"ht_m1": "분",
	"ht_m2": "분",
	"ht_h1": "시간",
	"ht_h2": "시간",
	"ht_d1": "일",
	"ht_d2": "일",
	"ht_and": " ",

	"goh": "제어판",
	"gop": '이전 형제 폴더">이전',
	"gou": '상위 폴더">위로',
	"gon": '다음 폴더">다음',
	"logout": "로그아웃 ",
	"login": "로그인", //m
	"access": " 액세스",
	"ot_close": "하위 메뉴 닫기",
	"ot_search": "`속성, 경로/이름, 음악 태그 또는 이들의 조합으로 파일을 검색합니다.$N$N`foo bar` = «foo»와 «bar»를 모두 포함해야 함,$N`foo -bar` = «foo»는 포함하지만 «bar»는 포함하지 않아야 함,$N`^yana .opus$` = «yana»로 시작하고 «opus» 파일이어야 함$N`&quot;try unite&quot;` = 정확히 «try unite»를 포함해야 함$N$N날짜 형식은 ISO-8601입니다. 예:$N`2009-12-31` 또는 `2020-09-12 23:30:00`",
	"ot_unpost": "주워담기: 최근 업로드한 항목을 삭제하거나 미완료된 업로드를 중단합니다",
	"ot_bup": "bup: 기본 업로더. 넷스케이프 4.0도 지원합니다",
	"ot_mkdir": "mkdir: 새 디렉터리를 만듭니다",
	"ot_md": "new-file: 새 텍스트 파일을 만듭니다", //m
	"ot_msg": "msg: 서버 로그에 메시지를 보냅니다",
	"ot_mp": "미디어 플레이어 옵션",
	"ot_cfg": "구성 옵션",
	"ot_u2i": 'up2k: (쓰기 권한이 있는 경우) 파일을 업로드하거나, 검색 모드로 전환하여 서버 어딘가에 파일이 있는지 확인합니다.$N$N업로드는 재개 가능하고, 멀티스레드로 작동하며, 파일 타임스탬프가 보존되지만, [🎈] (기본 업로더)보다 CPU를 더 많이 사용합니다.<br /><br />업로드 중에는 이 아이콘이 진행률 표시창이 됩니다!',
	"ot_u2w": 'up2k: 이어올리기 기능을 지원하는 파일 업로더입니다 (브라우저를 닫았다가 나중에 동일한 파일을 끌어다 놓으세요).$N$N멀티스레드로 작동하며, 파일 타임스탬프가 보존되지만, [🎈] (기본 업로더)보다 CPU를 더 많이 사용합니다.<br /><br />업로드 중에는 이 아이콘이 진행률 표시창이 됩니다!',
	"ot_noie": 'Chrome / Firefox / Edge를 사용해주세요',

	"ab_mkdir": "디렉터리 만들기",
	"ab_mkdoc": "새 텍스트 파일", //m
	"ab_msg": "서버 로그에 메시지 보내기",

	"ay_path": "폴더로 건너뛰기",
	"ay_files": "파일로 건너뛰기",

	"wt_ren": "선택한 항목 이름 바꾸기$N단축키: F2",
	"wt_del": "선택한 항목 삭제$N단축키: ctrl-K",
	"wt_cut": "선택한 항목 잘라내기 &lt;small&gt;(다른 곳에 붙여넣기용)&lt;/small&gt;$N단축키: ctrl-X",
	"wt_cpy": "선택한 항목 클립보드에 복사$N(다른 곳에 붙여넣기용)$N단축키: ctrl-C",
	"wt_pst": "이전에 잘라내거나 복사한 항목 붙여넣기$N단축키: ctrl-V",
	"wt_selall": "모든 파일 선택$N단축키: ctrl-A (파일에 포커스된 경우)",
	"wt_selinv": "선택 반전",
	"wt_zip1": "이 폴더를 압축 파일로 다운로드",
	"wt_selzip": "선택 항목을 압축 파일로 다운로드",
	"wt_seldl": "선택 항목을 개별 파일로 다운로드$N단축키: Y",
	"wt_npirc": "IRC 형식 트랙 정보 복사",
	"wt_nptxt": "일반 텍스트 트랙 정보 복사",
	"wt_m3ua": "m3u 재생 목록에 추가 (나중에 <code>📻복사</code> 클릭)",
	"wt_m3uc": "m3u 재생 목록을 클립보드에 복사",
	"wt_grid": "그리드/목록 보기 전환$N단축키: G",
	"wt_prev": "이전 트랙$N단축키: J",
	"wt_play": "재생/일시정지$N단축키: P",
	"wt_next": "다음 트랙$N단축키: L",

	"ul_par": "동시 업로드:",
	"ut_rand": "파일명 무작위로 만들기",
	"ut_u2ts": "사용자 파일 시스템의 마지막 수정 타임스탬프를$N서버에 복사\">📅",
	"ut_ow": "서버에 있는 기존 파일을 덮어쓸까요?$N🛡️: 안 함 (대신 새 파일 이름 생성)$N🕒: 서버 파일이 더 오래된 경우 덮어쓰기$N♻️: 파일이 다르면 항상 덮어쓰기$N⏭️: 기존 파일을 모두 무조건 건너뜀", //m
	"ut_mt": "업로드 중 다른 파일 해싱 계속하기$N$NCPU 또는 HDD가 병목 현상을 일으키는 경우 비활성화하세요",
	"ut_ask": '업로드 시작 전 확인 요청">💭',
	"ut_pot": "느린 기기에서 UI를 단순화하여$N업로드 속도 향상",
	"ut_srch": "실제로 업로드하는 대신, 파일이 이미 서버에 있는지 확인합니다$N(읽을 수 있는 모든 폴더를 스캔합니다)",
	"ut_par": "0으로 설정하여 업로드 일시정지$N$N연결이 느리거나 지연 시간이 길면 늘리세요$N$NLAN 환경이거나 서버 HDD가 병목 현상을 일으키면 1로 유지하세요",
	"ul_btn": "파일/폴더를 여기에<br>끌어다 놓거나 클릭하세요",
	"ul_btnu": "업 로 드",
	"ul_btns": "검 색",

	"ul_hash": "해싱",
	"ul_send": "전송",
	"ul_done": "완료",
	"ul_idle1": "대기 중인 업로드가 없습니다",
	"ut_etah": "평균 &lt;em&gt;해싱&lt;/em&gt; 속도 및 예상 완료 시간",
	"ut_etau": "평균 &lt;em&gt;업로드&lt;/em&gt; 속도 및 예상 완료 시간",
	"ut_etat": "평균 &lt;em&gt;총&lt;/em&gt; 속도 및 예상 완료 시간",

	"uct_ok": "성공적으로 완료됨",
	"uct_ng": "문제 발생: 실패/거부/찾을 수 없음",
	"uct_done": "완료됨 (성공 및 문제 발생 포함)",
	"uct_bz": "해싱 또는 업로드 중",
	"uct_q": "대기 중, 보류 중",

	"utl_name": "파일명",
	"utl_ulist": "목록",
	"utl_ucopy": "복사",
	"utl_links": "링크",
	"utl_stat": "상태",
	"utl_prog": "진행률",

	// keep short:
	"utl_404": "404",
	"utl_err": "오류",
	"utl_oserr": "OS 오류",
	"utl_found": "찾음",
	"utl_defer": "보류",
	"utl_yolo": "YOLO",
	"utl_done": "완료",

	"ul_flagblk": "파일이 대기열에 추가되었습니다.</b><br>하지만 다른 브라우저 탭에서 up2k가 실행 중이므로,<br>해당 작업이 끝날 때까지 기다립니다.",
	"ul_btnlk": "서버 구성에서 이 스위치를 현재 상태로 잠갔습니다.",

	"udt_up": "업로드",
	"udt_srch": "검색",
	"udt_drop": "여기에 놓으세요",

	"u_nav_m": '<h6>자, 갖고 있는 게 무엇인가?</h6><code>Enter</code> = 파일 (하나 이상)\n<code>ESC</code> = 폴더 하나 (하위 폴더 포함)',
	"u_nav_b": '<a href="#" id="modal-ok">파일</a><a href="#" id="modal-ng">폴더 하나</a>',

	"cl_opts": "스위치",
	"cl_hfsz": "파일 크기", //m
	"cl_themes": "테마",
	"cl_langs": "언어",
	"cl_ziptype": "폴더 다운로드",
	"cl_uopts": "up2k 스위치",
	"cl_favico": "파비콘",
	"cl_bigdir": "큰 디렉터리",
	"cl_hsort": "#sort",
	"cl_keytype": "조성 표기법",
	"cl_hiddenc": "숨겨진 열",
	"cl_hidec": "숨기기",
	"cl_reset": "초기화",
	"cl_hpick": "아래 테이블에서 숨기고 싶은 열의 헤더를 탭하세요",
	"cl_hcancel": "열 숨기기가 중단되었습니다",
	"cl_rcm": "우클릭 메뉴", //m
	"cl_gauto": "자동 田", //m

	"ct_grid": "田 그리드",
	"ct_ttips": '◔ ◡ ◔">ℹ️ 도움말',
	"ct_thumb": '그리드 보기에서 아이콘 또는 미리보기 이미지 전환$N단축키: T">🖼️ 미리보기',
	"ct_csel": '그리드 보기에서 CTRL과 SHIFT를 사용하여 파일 선택">선택',
	"ct_dsel": '그리드 보기에서 드래그 선택 사용">드래그', //m
	"ct_dl": '파일을 클릭하면 다운로드를 강제로 수행 (인라인으로 표시하지 않음)">dl', //m
	"ct_ihop": '이미지 뷰어를 닫으면 마지막으로 본 파일로 스크롤">g⮯',
	"ct_dots": '숨김 파일 표시 (서버가 허용하는 경우)">숨김파일',
	"ct_qdel": '파일 삭제 시 한 번만 확인 요청">빠른삭제',
	"ct_dir1st": '폴더를 파일보다 먼저 정렬">📁 먼저',
	"ct_nsort": '자연어 정렬 (파일명의 숫자를 인식)">자연어정렬',
	"ct_utc": '모든 날짜/시간을 UTC로 표시">UTC',
	"ct_readme": '폴더 목록에 README.md 표시">📜 readme',
	"ct_idxh": '폴더 목록 대신 index.html 표시">htm',
	"ct_sbars": '스크롤바 표시">⟊',

	"cut_umod": '파일이 서버에 이미 있는 경우, 서버의 마지막 수정 타임스탬프를 로컬 파일과 일치하도록 업데이트합니다 (쓰기+삭제 권한 필요).\">re📅',

	"cut_turbo": 'YOLO 버튼. 아마 활성화하고 싶지 않으실 겁니다.$N$N대량의 파일을 업로드하다가 어떤 이유로 재시작해야 할 때, 최대한 빨리 업로드를 계속하고 싶을 때 사용하세요.$N$N이 옵션은 해시 확인을 단순히 <em>&quot;서버에 동일한 파일 크기를 가진 파일이 있는가?&quot;</em>로 대체하므로, 파일 내용만 다를 경우 업로드되지 않습니다.$N$N업로드가 끝나면 이 옵션을 끄고, 동일한 파일을 다시 \"업로드\"하여 클라이언트가 검증하도록 해야 합니다.\">turbo',

	"cut_datechk": '터보 버튼이 활성화되어 있지 않으면 효과가 없습니다.$N$NYOLO의 위험성을 약간 줄여줍니다. 서버의 파일 타임스탬프가 사용자의 것과 일치하는지 확인합니다.$N$N<em>이론적으로는</em> 대부분의 미완료/손상된 업로드를 잡아내지만, 터보를 비활성화하고 검증 과정을 거치는 것을 대체할 수는 없습니다.\">날짜확인',

	"cut_u2sz": "각 업로드 청크의 크기 (MiB)입니다. 큰 값은 태평양을 건너는 데 더 유리합니다. 매우 불안정한 연결에서는 낮은 값을 시도해보세요.",

	"cut_flag": '한 번에 하나의 탭만 업로드하도록 보장합니다.$N-- 다른 탭도 이 옵션을 활성화해야 합니다.$N-- 동일한 도메인의 탭에만 영향을 미칩니다.',

	"cut_az": '가장 작은 파일 우선이 아닌 알파벳 순서로 파일을 업로드합니다.$N$N알파벳 순서는 서버에서 문제가 발생했는지 눈으로 확인하기 쉽게 해주지만, 광랜/LAN 환경에서는 업로드 속도가 약간 느려집니다.',

	"cut_nag": '업로드 완료 시 OS 알림$N(브라우저나 탭이 활성화되지 않은 경우에만)',
	"cut_sfx": '업로드 완료 시 소리 알림$N(브라우저나 탭이 활성화되지 않은 경우에만)',

	"cut_mt": '멀티스레딩을 사용하여 파일 해싱 속도를 높입니다.$N$N이 기능은 웹 워커를 사용하며$N더 많은 RAM이 필요합니다 (추가적으로 최대 512 MiB).$N$Nhttps는 30% 더 빠르게, http는 4.5배 더 빠르게 만듭니다.\">mt',

	"cut_wasm": '브라우저 내장 해셔 대신 wasm을 사용합니다. 크롬 기반 브라우저에서 속도를 향상시키지만 CPU 부하를 증가시키며, 많은 구버전 크롬에는 이 기능을 활성화하면 모든 RAM을 소모하고 충돌하는 버그가 있습니다.\">wasm',

	"cft_text": "파비콘 텍스트 (비워두고 새로고침하면 비활성화됨)",
	"cft_fg": "전경색",
	"cft_bg": "배경색",

	"cdt_lim": "폴더에 표시할 최대 파일 수",
	"cdt_ask": "맨 아래로 스크롤할 때$N더 많은 파일을 불러오는 대신$N무엇을 할지 묻기",
	"cdt_hsort": "`미디어 URL에 포함할 정렬 규칙 (`,sorthref`)의 수. 0으로 설정하면 미디어 링크를 클릭할 때 포함된 정렬 규칙도 무시됩니다.",
	"cdt_ren": "사용자 지정 우클릭 메뉴를 활성화합니다. shift 키를 누른 채 우클릭하면 기본 메뉴를 사용할 수 있습니다\">활성화", //m
	"cdt_rdb": "사용자 정의 우클릭 메뉴가 이미 열려 있을 때 다시 우클릭하면 기본 메뉴 표시\">x2", //m

	"tt_entree": "탐색 창 (디렉터리 트리 사이드바) 표시$N단축키: B",
	"tt_detree": "이동 경로 표시$N단축키: B",
	"tt_visdir": "선택한 폴더로 스크롤하기",
	"tt_ftree": "폴더 트리/텍스트 파일 전환$N단축키: V",
	"tt_pdock": "상위 폴더를 상단에 고정된 창에 표시",
	"tt_dynt": "트리가 확장될 때 자동으로 너비 증가",
	"tt_wrap": "자동 줄 바꿈",
	"tt_hover": "마우스를 올리면 넘어가는 줄 표시$N(마우스 커서가 왼쪽 여백에$N&nbsp; 있지 않으면 스크롤이 깨짐)",
	"tt_gauto": "폴더 내용에 따라 그리드 또는 목록으로 표시", //m
	"tt_gathr": "파일 중 이 비율이 이미지/동영상이면 그리드 사용", //m

	"ml_pmode": "폴더 끝에서...",
	"ml_btns": "명령",
	"ml_tcode": "트랜스코딩",
	"ml_tcode2": "다음으로 트랜스코딩",
	"ml_tint": "틴트",
	"ml_eq": "오디오 이퀄라이저",
	"ml_drc": "다이내믹 레인지 압축기",
	"ml_ss": "무음 건너뛰기", //m

	"mt_loop": "한 곡 반복 재생\">🔁",
	"mt_one": "한 곡 재생 후 중지\">1️⃣",
	"mt_shuf": "각 폴더의 곡을 무작위 재생\">🔀",
	"mt_aplay": "서버에 접속한 링크에 곡 ID가 있으면 자동 재생$N$N이것을 비활성화하면 음악 재생 시 페이지 URL이 곡 ID로 업데이트되지 않아, 이 설정이 손실되고 URL이 남아있을 경우 자동 재생되는 것을 방지합니다.\">a▶",
	"mt_preload": "끊김 없는 재생을 위해 다음 곡을 미리 불러오기 시작\">미리로드",
	"mt_prescan": "마지막 곡이 끝나기 전에 다음 폴더로 이동하여$N웹브라우저가 재생을 멈추지 않도록 합니다.\">탐색",
	"mt_fullpre": "전체 곡을 미리 불러오기 시도;$N✅ <b>불안정한</b> 연결에서 활성화,$N❌ <b>느린</b> 연결에서는 아마도 비활성화\">전체",
	"mt_fau": "폰에서 다음 곡이 충분히 빨리 미리 불러오지 않아 음악이 멈추는 것을 방지합니다 (태그 표시가 불안정해질 수 있음).\">☕️",
	"mt_waves": "파형 탐색 바:$N탐색 바에 오디오 진폭 표시\">~s",
	"mt_npclip": "현재 재생 중인 곡을 클립보드에 복사하는 버튼 표시\">/np",
	"mt_m3u_c": "선택한 곡을 m3u8 재생 목록 항목으로$N클립보드에 복사하는 버튼 표시\">📻",
	"mt_octl": "OS 통합 (미디어 단축키/OSD)\">os-ctl",
	"mt_oseek": "OS 통합을 통해 탐색 허용$N$N참고: 일부 기기 (iPhone)에서는$N이것이 다음 곡 버튼을 대체합니다.\">탐색",
	"mt_oscv": "OSD에 앨범 커버 표시\">아트",
	"mt_follow": "재생 중인 트랙이 보이도록 스크롤 유지\">🎯",
	"mt_compact": "컴팩트 컨트롤\">⟎",
	"mt_uncache": "캐시 지우기 (브라우저가 곡의 깨진 사본을 캐시하여$N재생이 안되는 경우 시도해보세요)\">캐시삭제",
	"mt_mloop": "열린 폴더 반복\">🔁 반복",
	"mt_mnext": "다음 폴더 불러오고 계속\">📂 다음",
	"mt_mstop": "재생 중지\">⏸ 중지",
	"mt_cflac": "flac/wav를 {0}로 변환\">flac",
	"mt_caac": "aac/m4a를 {0}로 변환\">aac",
	"mt_coth": "다른 모든 것 (mp3 제외)을 {0}로 변환\">기타",
	"mt_c2opus": "데스크톱, 노트북, 안드로이드 환경에 최적\">opus",
	"mt_c2owa": "iOS 17.5 이상용 opus-weba\">owa",
	"mt_c2caf": "iOS 11부터 17까지용 opus-caf\">caf",
	"mt_c2mp3": "매우 오래된 기기에서 사용\">mp3",
	"mt_c2flac": "최고 음질이지만 다운로드 용량이 큼\">flac",
	"mt_c2wav": "비압축 재생 (더 큼)\">wav",
	"mt_c2ok": "네, 좋은 선택입니다",
	"mt_c2nd": "기기에 권장되는 출력 형식이 아니지만 괜찮습니다",
	"mt_c2ng": "기기가 이 출력 형식을 지원하지 않는 것 같지만, 시도해 보겠습니다",
	"mt_xowa": "iOS에서 이 형식의 백그라운드 재생이 안되는 버그가 있습니다. 대신 caf나 mp3를 사용해주세요.",
	"mt_tint": "탐색 바의 배경 레벨 (0-100)$N버퍼링이 덜 눈시리게 만듦",
	"mt_eq": "`이퀄라이저 및 게인 제어 활성화;$N$Nboost `0` = 표준 100% 볼륨 (수정 없음)$N$Nwidth `1 &nbsp;` = 표준 스테레오 (수정 없음)$Nwidth `0.5` = 50% 좌우 크로스피드$Nwidth `0 &nbsp;` = 모노$N$Nboost `-0.8` &amp; width `10` = 보컬 제거 :^)$N$N이퀄라이저를 활성화하면 끊김 없는 앨범이 온전히 끊김 없이 재생되므로, 그 점이 중요하다면 모든 값을 0으로 두고 (width=1 제외) 켜두세요.",
	"mt_drc": "다이내믹 레인지 컴프레서(볼륨 평탄화/벽돌화)를 활성화합니다. 스파게티의 균형을 맞추기 위해 EQ도 활성화되므로, 원하지 않으면 'width'를 제외한 모든 EQ 필드를 0으로 설정하세요.$N$NTHRESHOLD dB 이상의 오디오 볼륨을 낮춥니다. THRESHOLD를 초과하는 모든 RATIO dB에 대해 1dB의 출력이 있으므로, 기본값인 tresh -24 및 ratio 12는 볼륨이 -22dB보다 커지지 않음을 의미하며, 이퀄라이저 부스트를 0.8 또는 ATK 0과 큰 RLS (예: 90)를 사용하여 1.8까지 안전하게 높일 수 있습니다 (firefox에서만 작동, 다른 브라우저에서는 RLS 최대 1).$N$N(위키백과를 참조하세요, 훨씬 더 잘 설명되어 있습니다)",
	"mt_ss": "`무음 건너뛰기 활성화; 볼륨이 `음` 미만이고 위치가 처음 `시`% 또는 마지막 `끝`% 이내일 때 시작/끝 근처에서 재생 속도를 `고` 배로 합니다", //m
	"mt_ssvt": "볼륨 임계값 (0-255)\">음", //m
	"mt_ssts": "활성 임계값 (% 트랙, 시작)\">시", //m
	"mt_sste": "활성 임계값 (% 트랙, 끝)\">끝", //m
	"mt_sssm": "재생 속도 배율\">고", //m

	"mb_play": "재생",
	"mm_hashplay": "이 오디오 파일을 재생할까요?",
	"mm_m3u": "<code>Enter/확인</code>을 눌러 재생\n<code>ESC/취소</code>를 눌러 편집",
	"mp_breq": "Firefox 82+, Chrome 73+ 또는 iOS 15+ 필요",
	"mm_bload": "불러오는 중...",
	"mm_bconv": "{0}(으)로 변환 중, 잠시만 기다려주세요...",
	"mm_opusen": "브라우저가 aac/m4a 파일을 재생할 수 없습니다.\nopus로의 트랜스코딩이 활성화되었습니다.",
	"mm_playerr": "재생 실패: ",
	"mm_eabrt": "재생 시도가 취소되었습니다",
	"mm_enet": "인터넷 연결이 불안정합니다",
	"mm_edec": "이 파일이 손상된 것 같습니다??",
	"mm_esupp": "브라우저가 이 오디오 형식을 이해하지 못합니다",
	"mm_eunk": "알 수 없는 오류",
	"mm_e404": "오디오를 재생할 수 없습니다; 오류 404: 파일을 찾을 수 없습니다.",
	"mm_e403": "오디오를 재생할 수 없습니다; 오류 403: 접근이 거부되었습니다.\n\nF5를 눌러 새로고침 해보세요, 로그아웃되었을 수 있습니다",
	"mm_e415": "오디오를 재생할 수 없습니다; 오류 415: 파일 변환에 실패했습니다; 서버 로그를 확인하세요.", //m
	"mm_e500": "오디오를 재생할 수 없습니다; 오류 500: 서버 로그를 확인하세요.",
	"mm_e5xx": "오디오를 재생할 수 없습니다; 서버 오류 ",
	"mm_nof": "주변에서 더 이상 오디오 파일을 찾을 수 없습니다",
	"mm_prescan": "다음에 재생할 음악을 찾는 중...",
	"mm_scank": "다음 곡을 찾았습니다:",
	"mm_uncache": "캐시가 지워졌습니다. 모든 곡은 다음 재생 시 다시 다운로드됩니다.",
	"mm_hnf": "그 곡이 더 이상 존재하지 않습니다",

	"im_hnf": "그 이미지가 더 이상 존재하지 않습니다",

	"f_empty": '이 폴더는 비어 있습니다',
	"f_chide": '«{0}» 열을 숨깁니다.\n\n설정 탭에서 열을 다시 표시할 수 있습니다.',
	"f_bigtxt": "이 파일은 {0} MiB입니다 -- 정말 텍스트로 보시겠습니까?",
	"f_bigtxt2": "대신 파일의 끝부분만 보시겠습니까? 이렇게 하면 실시간으로 새로 추가되는 텍스트 줄을 보여주는 팔로잉/테일링 기능도 활성화됩니다.",
	"fbd_more": '<div id="blazy"><code>{1}</code>개 파일 중 <code>{0}</code>개 표시 중; <a href="#" id="bd_more">{2}개 더 보기</a> 또는 <a href="#" id="bd_all">모두 보기</a></div>',
	"fbd_all": '<div id="blazy"><code>{1}</code>개 파일 중 <code>{0}</code>개 표시 중; <a href="#" id="bd_all">모두 보기</a></div>',
	"f_anota": "{1}개 항목 중 {0}개만 선택되었습니다.\n전체 폴더를 선택하려면 먼저 맨 아래로 스크롤하세요.",

	"f_dls": '현재 폴더의 파일 링크가\n다운로드 링크로 변경되었습니다',
	"f_dl_nd": '폴더를 건너뜁니다 (대신 zip/tar 다운로드를 사용하세요):\n', //m

	"f_partial": "현재 업로드 중인 파일을 안전하게 다운로드하려면, 파일 이름이 같지만 <code>.PARTIAL</code> 확장자가 없는 파일을 클릭하세요. 이 경고를 무시하려면 \"취소\" 또는 ESC를 누르세요.\n\n\"확인\"/Enter를 누르면 이 경고를 무시하고 <code>.PARTIAL</code> 임시 파일을 계속 다운로드하며, 이 경우 거의 확실히 손상된 데이터를 받게 됩니다.",

	"ft_paste": "{0}개 항목 붙여넣기$N단축키: ctrl-V",
	"fr_eperm": "이름을 바꿀 수 없습니다:\n이 폴더에 \"이동\" 권한이 없습니다",
	"fd_eperm": "삭제할 수 없습니다:\n이 폴더에 \"삭제\" 권한이 없습니다",
	"fc_eperm": "잘라낼 수 없습니다:\n이 폴더에 \"이동\" 권한이 없습니다",
	"fp_eperm": "붙여넣을 수 없습니다\n이 폴더에 \"쓰기\" 권한이 없습니다",
	"fr_emore": "이름을 바꿀 항목을 하나 이상 선택하세요",
	"fd_emore": "삭제할 항목을 하나 이상 선택하세요",
	"fc_emore": "잘라낼 항목을 하나 이상 선택하세요",
	"fcp_emore": "클립보드에 복사할 항목을 하나 이상 선택하세요",

	"fs_sc": "현재 폴더 공유",
	"fs_ss": "선택한 파일 공유",
	"fs_just1d": "하나 이상의 폴더를 선택하거나,\n파일과 폴더를 한 번에 섞어 선택할 수 없습니다",
	"fs_abrt": "❌ 중단",
	"fs_rand": "🎲 무작위 이름",
	"fs_go": "✅ 공유 생성",
	"fs_name": "이름",
	"fs_src": "소스",
	"fs_pwd": "비밀번호",
	"fs_exp": "만료",
	"fs_tmin": "분",
	"fs_thrs": "시간",
	"fs_tdays": "일",
	"fs_never": "영원",
	"fs_pname": "선택적 링크 이름; 비워두면 무작위로 생성",
	"fs_tsrc": "공유할 파일 또는 폴더",
	"fs_ppwd": "비밀번호 (선택사항)",
	"fs_w8": "공유 생성 중...",
	"fs_ok": "<code>Enter/OK</code>를 눌러 클립보드에 복사\n<code>ESC/Cancel</code>를 눌러 닫기",

	"frt_dec": "깨진 파일 이름의 일부 경우를 수정할 수 있습니다\">url-디코드",
	"frt_rst": "수정된 파일 이름을 원래대로 되돌립니다\">↺ 초기화",
	"frt_abrt": "이 창을 중단하고 닫습니다\">❌ 취소",
	"frb_apply": "이름 바꾸기 적용",
	"fr_adv": "배치/메타데이터/패턴 이름 바꾸기\">고급",
	"fr_case": "대소문자 구분 정규식\">대소문자",
	"fr_win": "Windows 안전 이름; <code>&lt;&gt;:&quot;\\|?*</code>를 일본어 전각 문자로 바꿉니다\">win",
	"fr_slash": "<code>/</code>를 새 폴더를 만들지 않는 문자로 바꿉니다\">/ 없음",
	"fr_re": "`원본 파일 이름에 적용할 정규식 검색 패턴; 캡처링 그룹은 아래 형식 필드에서 `(1)`, `(2)` 등으로 참조할 수 있습니다",
	"fr_fmt": "`foobar2000에서 영감을 받음:$N`(title)`은(는) 곡 제목으로 대체됨,$N`[(artist) - ](title)`은(는) 아티스트가 비어 있으면 [이] 부분을 건너뜀$N`$lpad((tn),2,0)`은(는) 트랙 번호를 2자리로 채움",
	"fr_pdel": "삭제",
	"fr_pnew": "다른 이름으로 저장",
	"fr_pname": "새 프리셋의 이름을 입력하세요",
	"fr_aborted": "중단됨",
	"fr_lold": "이전 이름",
	"fr_lnew": "새 이름",
	"fr_tags": "선택한 파일의 태그 (읽기 전용, 참조용):",
	"fr_busy": "{0}개 항목 이름 바꾸는 중...\n\n{1}",
	"fr_efail": "이름 바꾸기 실패:\n",
	"fr_nchg": "<code>win</code> 및/또는 <code>/ 없음</code>으로 인해 새 이름 중 {0}개가 변경되었습니다.\n\n이 변경된 새 이름으로 계속하시겠습니까?",

	"fd_ok": "삭제 확인",
	"fd_err": "삭제 실패:\n",
	"fd_none": "아무것도 삭제되지 않았습니다. 서버 구성 (xbd)에 의해 차단되었을 수 있습니다.",
	"fd_busy": "삭제 중 {0}개 항목...\n\n{1}",
	"fd_warn1": "이 {0}개 항목을 삭제하시겠습니까?",
	"fd_warn2": "<b>마지막 기회입니다!</b> 되돌릴 수 없습니다. 삭제하시겠습니까?",

	"fc_ok": "{0}개 항목 잘라내기 완료",
	"fc_warn": "{0}개 항목 잘라내기 완료\n\n하지만: 선택 항목이 너무 커서 <b>이</b> 브라우저 탭에서만 붙여넣을 수 있습니다",

	"fcc_ok": "{0}개 항목을 클립보드에 복사했습니다",
	"fcc_warn": "{0}개 항목을 클립보드에 복사했습니다\n\n하지만: 선택 항목이 너무 커서 <b>이</b> 브라우저 탭에서만 붙여넣을 수 있습니다",

	"fp_apply": "이 이름 사용",
	"fp_skip": "충돌 건너뛰기", //m
	"fp_ecut": "붙여넣거나 이동하려면 먼저 파일/폴더를 잘라내거나 복사하세요\n\n참고: 다른 브라우저 탭 간에 잘라내기/붙여넣기를 할 수 있습니다",
	"fp_ename": "이름이 이미 사용 중이므로 {0}개 항목을 여기로 이동할 수 없습니다. 계속하려면 아래에 새 이름을 지정하거나, 이름을 비워두면 (\"충돌 건너뛰기\") 건너뜁니다:", //m
	"fcp_ename": "이름이 이미 사용 중이므로 {0}개 항목을 여기로 복사할 수 없습니다. 계속하려면 아래에 새 이름을 지정하거나, 이름을 비워두면 (\"충돌 건너뛰기\") 건너뜁니다:", //m
	"fp_emore": "아직 해결해야 할 파일 이름 충돌이 남아 있습니다",
	"fp_ok": "이동 완료",
	"fcp_ok": "복사 완료",
	"fp_busy": "{0}개 항목 이동 중...\n\n{1}",
	"fcp_busy": "{0}개 항목 복사 중...\n\n{1}",
	"fp_abrt": "취소 중...",
	"fp_err": "이동 실패:\n",
	"fcp_err": "복사 실패:\n",
	"fp_confirm": "이 {0}개 항목을 여기로 이동하시겠습니까?",
	"fcp_confirm": "이 {0}개 항목을 여기로 복사하시겠습니까?",
	"fp_etab": '다른 브라우저 탭에서 클립보드를 읽지 못했습니다',
	"fp_name": "기기에서 파일을 업로드합니다. 이름을 지정하세요:",
	"fp_both_m": '<h6>붙여넣을 항목 선택</h6><code>Enter</code> = «{1}»에서 파일 {0}개 이동\n<code>ESC</code> = 기기에서 파일 {2}개 업로드',
	"fcp_both_m": '<h6>붙여넣을 항목 선택</h6><code>Enter</code> = «{1}»에서 파일 {0}개 복사\n<code>ESC</code> = 기기에서 파일 {2}개 업로드',
	"fp_both_b": '<a href="#" id="modal-ok">이동</a><a href="#" id="modal-ng">업로드</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">복사</a><a href="#" id="modal-ng">업로드</a>',

	"mk_noname": "왼쪽 텍스트 필드에 이름을 먼저 입력해주세요 :p",
	"nmd_i1": "원하는 파일 확장자를 추가할 수 있습니다. 예: <code>.md</code>", //m
	"nmd_i2": "삭제 권한이 없어서 <code>.{0}</code> 파일만 만들 수 있습니다", //m

	"tv_load": "텍스트 문서 불러오는 중:\n\n{0}\n\n{1}% ({3} MiB 중 {2} MiB 로드됨)",
	"tv_xe1": "텍스트 파일을 불러올 수 없습니다:\n\n오류 ",
	"tv_xe2": "404, 파일을 찾을 수 없음",
	"tv_lst": "텍스트 파일 목록",
	"tvt_close": "폴더 보기로 돌아가기$N단축키: M (또는 Esc)\">❌ 닫기",
	"tvt_dl": "이 파일 다운로드$N단축키: Y\">💾 다운로드",
	"tvt_prev": "이전 문서 보기$N단축키: i\">⬆ 이전",
	"tvt_next": "다음 문서 보기$N단축키: K\">⬇ 다음",
	"tvt_sel": "파일 선택 &nbsp; (잘라내기/복사/삭제/...용)$N단축키: S\">선택",
	"tvt_j": "json 미화$N단축키: shift-J\">j", //m
	"tvt_edit": "텍스트 편집기에서 파일 열기$N단축키: E\">✏️ 편집",
	"tvt_tail": "파일 변경 사항 모니터링; 실시간으로 새 줄 표시\">📡 팔로우",
	"tvt_wrap": "자동 줄 바꿈\">↵",
	"tvt_atail": "페이지 하단으로 스크롤 고정\">⚓",
	"tvt_ctail": "터미널 색상 디코딩 (ANSI 이스케이프 코드)\">🌈",
	"tvt_ntail": "스크롤백 제한 (불러온 상태로 유지할 텍스트 바이트 수)",

	"m3u_add1": "m3u 재생 목록에 곡이 추가되었습니다",
	"m3u_addn": "{0}개의 곡이 m3u 재생 목록에 추가되었습니다",
	"m3u_clip": "m3u 재생 목록이 클립보드에 복사되었습니다\n\n something.m3u와 같은 이름의 새 텍스트 파일을 만들고 그 문서에 재생 목록을 붙여넣으면 재생할 수 있습니다.",

	"gt_vau": "비디오를 표시하지 않고 오디오만 재생\">🎧",
	"gt_msel": "파일 선택 활성화; ctrl-클릭하여 파일 재정의$N$N&lt;em&gt;활성 시: 파일/폴더를 두 번 클릭하여 열기&lt;/em&gt;$N$N단축키: S\">다중선택",
	"gt_crop": "썸네일 중앙 자르기\">자르기",
	"gt_3x": "고해상도 썸네일\">3x",
	"gt_zoom": "확대/축소",
	"gt_chop": "자르기",
	"gt_sort": "정렬 기준",
	"gt_name": "이름",
	"gt_sz": "크기",
	"gt_ts": "날짜",
	"gt_ext": "유형",
	"gt_c1": "파일명 더 많이 생략하기 (더 적게 표시)",
	"gt_c2": "파일명 덜 생략하기 (더 많이 표시)",

	"sm_w8": "검색 중...",
	"sm_prev": "아래 검색 결과는 이전 검색어에 대한 결과입니다:\n  ",
	"sl_close": "검색 결과 닫기",
	"sl_hits": "{0}개 결과 표시 중",
	"sl_moar": "더 불러오기",

	"s_sz": "크기",
	"s_dt": "날짜",
	"s_rd": "경로",
	"s_fn": "이름",
	"s_ta": "태그",
	"s_ua": "업로드 시점",
	"s_ad": "고급",
	"s_s1": "최소 MiB",
	"s_s2": "최대 MiB",
	"s_d1": "최소 ISO-8601",
	"s_d2": "최대 ISO-8601",
	"s_u1": "이후",
	"s_u2": "이전",
	"s_r1": "경로에 포함 &nbsp; (공백으로 구분)",
	"s_f1": "이름에 포함 &nbsp; (-로 제외)",
	"s_t1": "태그에 포함 &nbsp; (^=시작, 끝=$)",
	"s_a1": "특정 메타데이터 속성",

	"md_eshow": "렌더링할 수 없음 ",
	"md_off": "[📜<em>readme</em>]가 [⚙️]에서 비활성화됨 -- 문서 숨김",

	"badreply": "서버로부터의 응답을 구문 분석하지 못했습니다",

	"xhr403": "403: 접근 거부됨\n\nF5를 눌러보세요, 로그아웃되었을 수 있습니다",
	"xhr0": "알 수 없음 (서버와의 연결이 끊겼거나 서버가 오프라인일 수 있습니다)",
	"cf_ok": "죄송합니다 -- DD" + wah + "oS 보호 기능이 작동했습니다\n\n약 30초 후에 다시 정상적으로 작동할 것입니다\n\n아무 일도 일어나지 않으면 F5를 눌러 페이지를 새로고침하세요",
	"tl_xe1": "하위 폴더를 나열할 수 없습니다:\n\n오류 ",
	"tl_xe2": "404: 폴더를 찾을 수 없음",
	"fl_xe1": "폴더의 파일을 나열할 수 없습니다:\n\n오류 ",
	"fl_xe2": "404: 폴더를 찾을 수 없음",
	"fd_xe1": "하위 폴더를 만들 수 없습니다:\n\n오류 ",
	"fd_xe2": "404: 상위 폴더를 찾을 수 없음",
	"fsm_xe1": "메시지를 보낼 수 없습니다:\n\n오류 ",
	"fsm_xe2": "404: 상위 폴더를 찾을 수 없음",
	"fu_xe1": "서버에서 주워담기 목록을 불러오지 못했습니다:\n\n오류 ",
	"fu_xe2": "404: 파일을 찾을 수 없음??",

	"fz_tar": "압축되지 않은 gnu-tar 파일 (linux / mac)",
	"fz_pax": "압축되지 않은 pax 형식 tar (느림)",
	"fz_targz": "gzip 레벨 3 압축이 적용된 gnu-tar$N$N이것은 보통 매우 느리므로$N압축되지 않은 tar를 대신 사용하세요",
	"fz_tarxz": "xz 레벨 1 압축이 적용된 gnu-tar$N$N이것은 보통 매우 느리므로$N압축되지 않은 tar를 대신 사용하세요",
	"fz_zip8": "utf8 파일 이름이 포함된 zip (windows 7 및 이전 버전에서 문제가 있을 수 있음)",
	"fz_zipd": "정말 오래된 소프트웨어를 위한 전통적인 cp437 파일 이름이 포함된 zip",
	"fz_zipc": "MS-DOS PKZIP v2.04g (1993년 10월)용으로$Ncrc32가 미리 계산된 cp437$N(다운로드 시작 전 처리 시간이 더 걸림)",

	"un_m1": "아래에서 최근 업로드를 삭제하거나 미완료된 업로드를 중단할 수 있습니다",
	"un_upd": "새로고침",
	"un_m4": "또는 아래에 보이는 파일을 공유할 수 있습니다:",
	"un_ulist": "보기",
	"un_ucopy": "복사",
	"un_flt": "선택적 필터:&nbsp; URL에 포함되어야 함",
	"un_fclr": "필터 지우기",
	"un_derr": '주워담기-삭제 실패:\n',
	"un_f5": '문제가 발생했습니다, 새로고침하거나 F5를 눌러보세요',
	"un_uf5": "죄송하지만, 이 업로드를 중단하기 전에 페이지를 새로고침해야 합니다 (예: F5 또는 CTRL-R 누르기).",
	"un_nou": '<b>경고:</b> 서버가 너무 바빠서 미완료 업로드를 표시할 수 없습니다; 잠시 후 "새로고침" 링크를 클릭하세요',
	"un_noc": '<b>경고:</b> 완전히 업로드된 파일의 주워담기가 서버 구성에서 활성화/허용되지 않았습니다',
	"un_max": "처음 2000개 파일을 표시합니다 (필터를 사용하세요)",
	"un_avail": "{0}개의 최근 업로드를 삭제할 수 있습니다<br />{1}개의 미완료 업로드를 중단할 수 있습니다",
	"un_m2": "업로드 시간순으로 정렬됨. 가장 최근 항목이 먼저 표시:",
	"un_no1": "아쉽다! 충분히 최근인 업로드가 없습니다.",
	"un_no2": "아쉽다! 해당 필터와 일치하는 최근 업로드가 없습니다.",
	"un_next": "아래의 다음 {0}개 파일 삭제",
	"un_abrt": "중단",
	"un_del": "삭제",
	"un_m3": "최근 업로드 로드 중...",
	"un_busy": "{0}개 파일 삭제 중...",
	"un_clip": "{0}개의 링크가 클립보드에 복사되었습니다",

	"u_https1": "더 나은 성능을 위해",
	"u_https2": "https로 전환",
	"u_https3": "하는 것이 좋습니다",
	"u_ancient": '브라우저가 정말 오래되었네요 -- 아마도 <a href="#" onclick="goto(\'bup\')">bup을 대신 사용</a>해야 할 것 같습니다',
	"u_nowork": "Firefox 53+, Chrome 57+ 또는 iOS 11+가 필요합니다",
	"tail_2old": "Firefox 105+, Chrome 71+ 또는 iOS 14.5+가 필요합니다",
	"u_nodrop": '브라우저가 너무 오래되어 드래그 앤 드롭 업로드를 지원하지 않습니다',
	"u_notdir": '폴더가 아닙니다!\n\n브라우저가 너무 오래되었습니다,\n대신 드래그드롭을 시도해보세요',
	"u_uri": '다른 브라우저 창에서 이미지를 드래그드롭하려면,\n큰 업로드 버튼 위로 떨어뜨려주세요',
	"u_enpot": '<a href="#">단순 UI로 전환</a> (업로드 속도가 향상될 수 있음)',
	"u_depot": '<a href="#">화려한 UI로 전환</a> (업로드 속도가 감소할 수 있음)',
	"u_gotpot": '업로드 속도 향상을 위해 단순 UI로 전환합니다,\n\n언제든지 다시 전환하셔도 좋습니다!',
	"u_pott": "<p>파일: &nbsp; <b>{0}</b> 완료, &nbsp; <b>{1}</b> 실패, &nbsp; <b>{2}</b> 처리 중, &nbsp; <b>{3}</b> 대기 중</p>",
	"u_ever": "이것은 기본 업로더입니다. up2k는 최소한 다음 버전이 필요합니다:<br>Chrome 21 // Firefox 13 // Edge 12 // Opera 12 // Safari 5.1",
	"u_su2k": '이것은 기본 업로더입니다. <a href="#" id="u2yea">up2k</a>가 더 좋습니다',
	"u_uput": '속도 최적화 (체크섬 건너뛰기)',
	"u_ewrite": '이 폴더에 쓰기 권한이 없습니다',
	"u_eread": '이 폴더에 읽기 권한이 없습니다',
	"u_enoi": '파일 검색이 서버 구성에서 활성화되지 않았습니다',
	"u_enoow": '여기서는 덮어쓰기가 작동하지 않습니다. 삭제 권한이 필요합니다',
	"u_badf": '총 {1}개 중 다음 {0}개의 파일은 파일 시스템 권한 문제 등으로 건너뛰었습니다:\n\n',
	"u_blankf": '총 {1}개 중 다음 {0}개의 파일은 비어있습니다. 그래도 업로드하시겠습니까?\n\n',
	"u_applef": '총 {1}개 중 다음 {0}개의 파일은 아마도 불필요한 파일일 것입니다.\n다음 파일을 건너뛰려면 <code>확인/Enter</code>를 누르세요,\n해당 파일도 업로드하려면 <code>취소/ESC</code>를 누르세요:\n\n',
	"u_just1": '\n파일을 하나만 선택하면 더 잘 작동할 수 있습니다',
	"u_ff_many": '<b>리눅스/macOS/안드로이드</b>를 사용 중이라면, 이 정도의 파일 수는 <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">Firefox를 <em>충돌시킬 수 있습니다!</em></a>\n만약 그런 일이 발생하면 다시 시도하거나 Chrome을 사용해주세요.',
	"u_up_life": '이 업로드는 완료 후 {0} 뒤에\n서버에서 삭제됩니다',
	"u_asku": '이 {0}개의 파일을 <code>{1}</code>(으)로 업로드하시겠습니까?',
	"u_unpt": '왼쪽 상단의 🧯를 사용하여 이 업로드를 취소/삭제할 수 있습니다',
	"u_bigtab": '{0}개의 파일을 표시하려고 합니다\n\n브라우저가 충돌할 수 있습니다, 계속 진행합니까?',
	"u_scan": '파일 스캔 중...',
	"u_dirstuck": '디렉터리 반복자가 다음 {0}개 항목에 접근하는 데 실패하여 건너뜁니다:',
	"u_etadone": '완료 ({0}, {1}개 파일)',
	"u_etaprep": '(업로드 준비 중)',
	"u_hashdone": '해싱 완료',
	"u_hashing": '해시',
	"u_hs": '핸드셰이킹 중...',
	"u_started": '파일이 현재 업로드 중입니다. [🚀] 참조',
	"u_dupdefer": '중복됨. 다른 모든 파일 처리 후 처리됩니다',
	"u_actx": "다른 창/탭으로 전환 시 성능 저하를<br />방지하려면 이 텍스트를 클릭하세요",
	"u_fixed": "OK!&nbsp; 해결됐습니다 👍",
	"u_cuerr": "{1} 중 청크 {0} 업로드 실패;\n아마 문제 없을 겁니다. 계속 진행합니다\n\n파일: {2}",
	"u_cuerr2": "서버가 업로드를 거부했습니다 (청크 {0}/{1});\n나중에 다시 시도합니다\n\n파일: {2}\n\n오류 ",
	"u_ehstmp": "다시 시도합니다; 오른쪽 하단 참조",
	"u_ehsfin": "서버가 업로드 완료 요청을 거부했습니다. 재시도 중...",
	"u_ehssrch": "서버가 검색 수행 요청을 거부했습니다. 재시도 중...",
	"u_ehsinit": "서버가 업로드 시작 요청을 거부했습니다. 재시도 중...",
	"u_eneths": "업로드 핸드셰이크 중 네트워크 오류 발생. 재시도 중...",
	"u_enethd": "대상 존재 여부 테스트 중 네트워크 오류 발생; 재시도 중...",
	"u_cbusy": '네트워크 문제 후 서버가 다시 우리를 신뢰할 때까지 기다리는 중...',
	"u_ehsdf": '서버 디스크 공간이 부족합니다!\n\n누군가 계속할 수 있을 만큼의 공간을\n비워줄 경우를 대비해 계속 재시도합니다',
	"u_emtleak1": "웹 브라우저에 메모리 누수가 있는 것 같습니다.\n",
	"u_emtleak2": ' <a href="{0}">https로 전환 (권장)</a>하거나 ',
	"u_emtleak3": ' ',
	"u_emtleakc": '다음을 시도해보세요:\n<ul><li><code>F5</code>를 눌러 페이지를 새로고침하세요</li><li>그런 다음 <code>⚙️ 설정</code>에서 &nbsp;<code>mt</code>&nbsp; 버튼을 비활성화하세요</li><li>그리고 다시 그 업로드를 시도해보세요</li></ul>업로드가 조금 느려지겠지만, 어쩔 수 없죠.\n불편을 드려 죄송합니다!\n\nPS: 이 버그는 Chrome v107에서 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">수정되었습니다</a>.',
	"u_emtleakf": '다음을 시도해보세요:\n<ul><li><code>F5</code>를 눌러 페이지를 새로고침하세요</li><li>그런 다음 업로드 UI에서 <code>🥔</code>(단순 UI)를 활성화하세요<li>그리고 다시 그 업로드를 시도해보세요</li></ul>\nPS: Firefox에서 <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">언젠가 이 버그가 수정될 거라 믿습니다</a>.',
	"u_s404": '서버에서 찾을 수 없음',
	"u_expl": '설명',
	"u_maxconn": "대부분의 브라우저는 이를 6으로 제한하지만, Firefox에서는 <code>about:config</code>에서 <code>connections-per-server</code> 설정값으로 높일 수 있습니다.",
	"u_tu": '<p class="warn">경고: 터보가 활성화되어 <span>클라이언트가 불완전한 업로드를 감지하고 재개하지 못할 수 있습니다. 터보 버튼의 툴팁을 참조하세요</span></p>',
	"u_ts": '<p class="warn">경고: 터보가 활성화되어 <span>검색 결과가 부정확할 수 있습니다. 터보 버튼의 툴팁을 참조하세요</span></p>',
	"u_turbo_c": "터보가 서버 구성에서 비활성화되었습니다",
	"u_turbo_g": '이 볼륨 내에서 디렉터리 목록 권한이 없으므로\n터보를 비활성화합니다',
	"u_life_cfg": '자동 삭제 시간 <input id="lifem" p="60" /> 분 (또는 <input id="lifeh" p="3600" /> 시간)',
	"u_life_est": '업로드가 <span id="lifew" tt="현지 시간">---</span>에 삭제됩니다',
	"u_life_max": '이 폴더는 최대 수명을\n{0}(으)로 강제합니다',
	"u_unp_ok": '주워담기는 {0} 동안 허용됩니다',
	"u_unp_ng": '주워담기는 허용되지 않습니다',
	"ue_ro": '이 폴더에 대한 접근은 읽기 전용입니다\n\n',
	"ue_nl": '현재 로그인되어 있지 않습니다',
	"ue_la": '현재 \'{0}\'(으)로 로그인되어 있습니다',
	"ue_sr": '현재 파일 검색 모드입니다\n\n큰 "검색" 버튼 옆의 돋보기 🔎를 클릭하여 업로드 모드로 전환한 후 다시 업로드해보세요\n\n죄송합니다',
	"ue_ta": '다시 업로드해보세요, 이제 작동할 겁니다',
	"ue_ab": '이 파일은 이미 다른 폴더로 업로드 중이며, 파일이 다른 곳에 업로드되기 전에 해당 업로드가 완료되어야 합니다.\n\n왼쪽 상단의 🧯를 사용하여 초기 업로드를 중단하고 잊을 수 있습니다.',
	"ur_1uo": "OK: 파일이 성공적으로 업로드되었습니다",
	"ur_auo": "OK: 모든 {0}개의 파일이 성공적으로 업로드되었습니다",
	"ur_1so": "OK: 서버에서 파일을 찾았습니다",
	"ur_aso": "OK: 서버에서 모든 {0}개의 파일을 찾았습니다",
	"ur_1un": "업로드에 실패했습니다, 죄송",
	"ur_aun": "모든 {0}개의 업로드에 실패했습니다, 죄송",
	"ur_1sn": "서버에서 파일을 찾지 못했습니다",
	"ur_asn": "서버에서 {0}개의 파일을 찾지 못했습니다",
	"ur_um": "완료;\n{0}개 업로드 성공,\n{1}개 업로드 실패, 죄송",
	"ur_sm": "완료;\n서버에서 {0}개 파일 찾음,\n서버에서 {1}개 파일 찾지 못함",

	"rc_opn": "열기", //m
	"rc_ply": "재생", //m
	"rc_pla": "오디오로 재생", //m
	"rc_txt": "파일 뷰어에서 열기", //m
	"rc_md": "텍스트 편집기에서 열기", //m
	"rc_dl": "다운로드", //m
	"rc_zip": "압축 파일로 다운로드", //m
	"rc_cpl": "링크 복사", //m
	"rc_del": "삭제", //m
	"rc_cut": "잘라내기", //m
	"rc_cpy": "복사", //m
	"rc_pst": "붙여넣기", //m
	"rc_rnm": "이름 변경", //m
	"rc_nfo": "새 폴더", //m
	"rc_nfi": "새 파일", //m
	"rc_sal": "모두 선택", //m
	"rc_sin": "선택 반전", //m
	"rc_shf": "이 폴더 공유", //m
	"rc_shs": "선택 항목 공유", //m

	"lang_set": '변경 사항을 적용하기 위해 새로고침하시겠습니까?',

	"splash": {
		"a1": "새로고침",
		"b1": "어이 친구! 처음 보는 얼굴인데? &nbsp; <small>(로그인되어 있지 않습니다)</small>",
		"c1": "로그아웃",
		"d1": "스택 덤프하기",
		"d2": "모든 활성 스레드의 상태를 표시합니다",
		"e1": "설정 다시 불러오기",
		"e2": "설정 파일(계정/볼륨/볼륨 플래그)을 다시 불러오고,$N모든 e2ds 볼륨을 다시 스캔합니다$N$N참고: 전역 설정에 대한 변경 사항은$N적용하려면 전체 재시작이 필요합니다",
		"f1": "탐색 가능한 곳:",
		"g1": "업로드 가능한 곳:",
		"cc1": "기타 항목:",
		"h1": "k304 비활성화",
		"i1": "k304 활성화",
		"j1": "k304를 활성화하면 모든 HTTP 304 응답 시 클라이언트 연결이 끊어집니다. 이는 일부 프록시가 멈추는 현상(갑자기 페이지가 로드되지 않음)을 방지할 수 있지만, <em>대신 전반적인 속도는 느려집니다.</em>",
		"k1": "클라이언트 설정 초기화",
		"l1": "로그인하기:",
		"ls3": "로그인", //m
		"lu4": "사용자 이름", //m
		"lp4": "비밀번호", //m
		"lo3": "{0}을(를) 모든 곳에서 로그아웃", //m
		"lo2": "이 작업은 모든 브라우저에서 세션을 종료합니다", //m
		"m1": "또 오셨네요,",
		"n1": "404 찾을 수 없음 &nbsp;┐( ´ -`)┌",
		"o1": "또는 접근 권한이 없을 수 있습니다. 비밀번호를 입력하거나 <a href=\"' + SR + '/?h\">홈으로 이동</a>하세요",
		"p1": "403 접근 금지 &nbsp;~┻━┻",
		"q1": "비밀번호를 입력하거나 <a href=\"' + SR + '/?h\">홈으로 이동</a>하세요",
		"r1": "홈으로 이동",
		".s1": "다시 스캔",
		"t1": "작업",
		"u2": "서버에 마지막으로 쓰기 작업을 한 후 경과된 시간$N(업로드 / 이름 변경 / 등등...)$N$N17d = 17일$N1h23 = 1시간 23분$N4m56 = 4분 56초",
		"v1": "연결",
		"v2": "이 서버를 로컬 하드디스크처럼 사용하기",
		"w1": "HTTPS로 전환",
		"x1": "비밀번호 변경",
		"y1": "공유 설정",
		"z1": "이 공유 잠금해제:",
		"ta1": "새 비밀번호를 먼저 입력하세요",
		"ta2": "새 비밀번호 확인을 위해 다시 입력하세요:",
		"ta3": "오타가 있습니다. 다시 시도해주세요",
		"nop": "오류: 비밀번호를 비워 둘 수 없습니다", //m
		"nou": "오류: 사용자 이름 및/또는 비밀번호를 비워 둘 수 없습니다", //m
		"aa1": "수신 중인 파일:",
		"ab1": "no304 비활성화",
		"ac1": "no304 활성화",
		"ad1": "no304를 활성화하면 모든 캐싱이 비활성화됩니다. k304로 충분하지 않은 경우 시도해보세요. 네트워크 트래픽이 대량으로 낭비됩니다!",
		"ae1": "활성 다운로드:",
		"af1": "최근 업로드 보기",
		"ag1": "IdP 캐시 보기",
	}
};
