
// Οι γραμμές που τελειώνουν με //m είναι μη επαληθευμένες μηχανικές μεταφράσεις

Ls.grc = {
	"tt": "Ελληνικά",

	"cols": {
		"c": "κουμπιά ενεργειών",
		"dur": "διάρκεια",
		"q": "ποιότητα / bitrate",
		"Ac": "κωδικοποιητής ήχου",
		"Vc": "κωδικοποιητής βίντεο",
		"Fmt": "μορφή / container",
		"Ahash": "checksum ήχου",
		"Vhash": "checksum βίντεο",
		"Res": "ανάλυση",
		"T": "τύπος αρχείου",
		"aq": "ποιότητα ήχου / bitrate",
		"vq": "ποιότητα βίντεο / bitrate",
		"pixfmt": "subsampling / δομή εικονοστοιχείων",
		"resw": "οριζόντια ανάλυση",
		"resh": "κάθετη ανάλυση",
		"chs": "κανάλια ήχου",
		"hz": "συχνότητα δειγματοληψίας",
	},

	"hks": [
		[
			"διάφορα",
			["ESC", "κλείσιμο διαφόρων λειτουργιών"],

			"διαχειριστής αρχείων",
			["G", "εναλλαγή λίστας / πλέγματος"],
			["T", "εναλλαγή μικρογραφιών / εικονιδίων"],
			["⇧ A/D", "μέγεθος μικρογραφιών"],
			["ctrl-K", "διαγραφή επιλεγμένων"],
			["ctrl-X", "αποκοπή επιλογής στο πρόχειρο"],
			["ctrl-C", "αντιγραφή επιλογής στο πρόχειρο"],
			["ctrl-V", "επικόλληση (μετακίνηση/αντιγραφή) εδώ"],
			["Y", "λήψη επιλεγμένων"],
			["F2", "μετονομασία επιλεγμένων"],

			"λίστα αρχείων",
			["space", "εναλλαγή επιλογής αρχείου"],
			["↑/↓", "μετακίνηση δείκτη επιλογής"],
			["ctrl ↑/↓", "μετακίνηση δείκτη και προβολής"],
			["⇧ ↑/↓", "επιλογή προηγούμενου/επόμενου αρχείου"],
			["ctrl-A", "επιλογή όλων των αρχείων / φακέλων"]
		], [
			"πλοήγηση",
			["B", "εναλλαγή σε καρτέλες διαδρομών / δέντρο διαδρομών"],
			["I/K", "προηγούμενος/επόμενος φάκελος"],
			["M", "γονικός φάκελος (ή σμίκρυνση τρέχοντος)"],
			["V", "εναλλαγή φακέλων / δέντρο αρχείων κειμένου"],
			["A/D", "μέγεθος πίνακα πλοήγησης"]
		], [
			"μουσική",
			["J/L", "προηγούμενο/επόμενο τραγούδι"],
			["U/O", "μετάβαση 10δευτ πίσω/μπροστά"],
			["0..9", "μετάβαση στο 0%..90%"],
			["P", "αναπαραγωγή/παύση (ξεκινάει κιόλας)"],
			["S", "επιλογή αναπαραγόμενου τραγουδιού"],
			["Y", "λήψη τραγουδιού"]
		], [
			"εικόνες",
			["J/L, ←/→", "προηγούμενη/επόμενη εικόνα"],
			["Home/End", "πρώτη/τελευταία εικόνα"],
			["F", "πλήρης οθόνη"],
			["R", "περιστροφή δεξιόστροφα"],
			["⇧ R", "περιστροφή αριστερόστροφα"],
			["S", "επιλογή εικόνας"],
			["Y", "λήψη εικόνας"]
		], [
			"βίντεο",
			["U/O", "μετάβαση 10δευτ πίσω/μπροστά"],
			["P/K/Space", "αναπαραγωγή/παύση"],
			["C", "συνέχεια στο επόμενο"],
			["V", "επανάληψη"],
			["M", "σίγαση"],
			["[ και ]", "ορισμός διαστήματος επανάληψης"]
		], [
			"αρχεία κειμένου",
			["I/K", "προηγούμενο/επόμενο αρχείο"],
			["M", "κλείσιμο αρχείου"],
			["E", "επεξεργασία αρχείου"],
			["S", "επιλογή αρχείου (για αποκοπή/αντιγραφή/μετονομασία)"],
			["Y", "λήψη αρχείου κειμένου"], //m
			["⇧ J", "ομορφοποίηση json"], //m
		]
	],

	"m_ok": "Εντάξει",
	"m_ng": "Άκυρο",

	"enable": "Ενεργοποίηση",
	"danger": "ΚΙΝΔΥΝΟΣ",
	"clipped": "αντιγράφηκε στο πρόχειρο",

	"ht_s1": "δευτερόλεπτο",
	"ht_s2": "δευτερόλεπτα",
	"ht_m1": "λεπτό",
	"ht_m2": "λεπτά",
	"ht_h1": "ώρα",
	"ht_h2": "ώρες",
	"ht_d1": "μέρα",
	"ht_d2": "μέρες",
	"ht_and": " και ",

	"goh": "πίνακας ελέγχου",
	"gop": 'προηγούμενος φάκελος στο ίδιο επίπεδο">προηγούμενο',
	"gou": 'γονικός φάκελος">πάνω',
	"gon": 'επόμενος φάκελος">επόμενο',
	"logout": "Αποσύνδεση ",
	"login": "Σύνδεση", //m
	"access": " πρόσβαση",
	"ot_close": "κλείσιμο υπομενού",
	"ot_search": "`αναζήτηση αρχείων με βάση χαρακτηριστικά, διαδρομή / όνομα, μουσικά tags ή οποιονδήποτε συνδυασμό$N$N`foo bar` = πρέπει να περιέχει και τα «foo» και «bar»,$N`foo -bar` = πρέπει να περιέχει το «foo» αλλά όχι το «bar»,$N`^yana .opus$` = να ξεκινά με «yana» και να είναι αρχείο «opus»$N`&quot;try unite&quot;` = να περιέχει ακριβώς «try unite»$N$Nη μορφή ημερομηνίας είναι iso-8601, όπως$N`2009-12-31` ή `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: διαγραφή πρόσφατων μεταφορτώσεων ή ακύρωση ανολοκλήρωτων",
	"ot_bup": "bup: βασικός uploader, υποστηρίζει μέχρι και netscape 4.0",
	"ot_mkdir": "mkdir: δημιουργία νέου φακέλου",
	"ot_md": "new-file: δημιουργία νέου αρχείου κειμένου", //m
	"ot_msg": "msg: αποστολή μηνύματος στο server log",
	"ot_mp": "επιλογές media player",
	"ot_cfg": "επιλογές ρυθμίσεων",
	"ot_u2i": 'up2k: ανέβασε αρχεία (αν έχεις δικαίωμα εγγραφής) ή ενεργοποίησε τη λειτουργία αναζήτησης για να δεις αν υπάρχουν ήδη στο server$N$Nοι μεταφορτώσεις συνεχίζονται αν διακοπούν, είναι πολυνηματικές και διατηρούν τις χρονοσφραγίδες, αλλά καταναλώνουν περισσότερο CPU από τον [🎈]&nbsp; (βασικός uploader)<br /><br />κατά τη διάρκεια της μεταφόρτωσης, αυτό το εικονίδιο δείχνει την πρόοδό της!',
	"ot_u2w": 'up2k: ανέβασε αρχεία με υποστήριξη συνέχισης (κλείσε τον browser και ρίξε τα ίδια αρχεία ξανά μετά)$N$Nπολυνηματικό, διατηρεί τις χρονοσφραγίδες, αλλά καταναλώνει περισσότερο CPU από τον [🎈]&nbsp; (βασικός uploader)<br /><br />κατά τη διάρκεια της μεταφόρτωσης, αυτό το εικονίδιο δείχνει την πρόοδό της!',
	"ot_noie": 'Χρησιμοποίησε Chrome / Firefox / Edge',

	"ab_mkdir": "δημιουργία φακέλου",
	"ab_mkdoc": "νέο αρχείο κειμένου", //m
	"ab_msg": "στείλε μήνυμα στο server log",

	"ay_path": "πήγαινε σε φακέλους",
	"ay_files": "πήγαινε σε αρχεία",

	"wt_ren": "μετονομασία επιλεγμένων$NΣυντόμευση: F2",
	"wt_del": "διαγραφή επιλεγμένων$NΣυντόμευση: ctrl-K",
	"wt_cut": "αποκοπή επιλεγμένων &lt;small&gt;(και επικόλληση αλλού)&lt;/small&gt;$NΣυντόμευση: ctrl-X",
	"wt_cpy": "αντιγραφή επιλεγμένων στο πρόχειρο$N(για επικόλληση αλλού)$NΣυντόμευση: ctrl-C",
	"wt_pst": "επικόλληση αποκομμένων / αντεγραμμένων$NΣυντόμευση: ctrl-V",
	"wt_selall": "επιλογή όλων$NΣυντόμευση: ctrl-A (με το αρχείο επιλεγμένο)",
	"wt_selinv": "αντιστροφή επιλογής",
	"wt_zip1": "κατέβασμα φακέλου ως συμπιεσμένο αρχείο",
	"wt_selzip": "κατέβασμα επιλογής ως συμπιεσμένο αρχείο",
	"wt_seldl": "κατέβασμα επιλογής ως μεμονωμένα αρχεία$NΣυντόμευση: Y",
	"wt_npirc": "αντιγραφή πληροφοριών τραγουδιού σε μορφή irc",
	"wt_nptxt": "αντιγραφή πληροφοριών τραγουδιού ως κείμενο",
	"wt_m3ua": "προσθήκη σε m3u λίστα αναπαραγωγής (μετά πάτησε <code>📻αντιγραφή</code>)",
	"wt_m3uc": "αντιγραφή m3u λίστας αναπαραγωγής στο πρόχειρο",
	"wt_grid": "εναλλαγή πλέγματος / λίστας$NΣυντόμευση: G",
	"wt_prev": "προηγούμενο κομμάτι$NΣυντόμευση: J",
	"wt_play": "αναπαραγωγή / παύση$NΣυντόμευση: P",
	"wt_next": "επόμενο κομμάτι$NΣυντόμευση: L",

	"ul_par": "παράλληλες μεταφορτώσεις:",
	"ut_rand": "τυχαιοποίηση ονομάτων αρχείων",
	"ut_u2ts": "αντιγραφή της τελευταίας τροποποιημένης χρονοσφραγίδας αλλαγής$Nαπό το σύστημά σου στον server\">📅",
	"ut_ow": "αντικατάσταση σε ήδη υπάρχοντα αρχεία του server?$N🛡️: ποτέ (θα δημιουργηθεί νέο όνομα)$N🕒: αν το αρχείο του server είναι παλαιότερο$N♻️: πάντα να αντικαθίστανται αν διαφέρουν$N⏭️: παράλειψη όλων των υπαρχόντων αρχείων χωρίς όρους", //m
	"ut_mt": "συνέχιση υπολογισμού hash για άλλα αρχεία κατά τη μεταφόρτωση$N$Nαπενεργοποίησέ το αν η CPU ή ο δίσκος σου ζορίζονται",
	"ut_ask": 'επιβεβαίωση πριν ξεκινήσει η μεταφόρτωση">💭',
	"ut_pot": "βελτίωση ταχύτητας μεταφόρτωσης σε αργές συσκευές$Nμε απλοποίηση του UI",
	"ut_srch": "μην ανεβάζεις, έλεγξε αν τα αρχεία$Nυπάρχουν ήδη στον server (ψάχνει σε όλους τους φακέλους που έχεις πρόσβαση)",
	"ut_par": "κάνε παύση στις μεταφορτώσεις βάζοντάς το 0$N$Nαύξησε το αν έχεις αργή/μεγάλη καθυστέρηση σύνδεσης$N$Nκράτα το 1 σε LAN ή αν ο server έχει αργό δίσκο",
	"ul_btn": "ρίξε αρχεία / φακέλους<br>εδώ (ή κάνε κλικ σε μένα)",
	"ul_btnu": "Μ Ε Τ Α Φ Ο Ρ Τ Ω Σ Η",
	"ul_btns": "Α Ν Α Ζ Η Τ Η Σ Η",

	"ul_hash": "υπολογισμός hash",
	"ul_send": "αποστολή",
	"ul_done": "ολοκληρώθηκε",
	"ul_idle1": "καμία μεταφόρτωση στην ουρά για την ώρα",
	"ut_etah": "μέση ταχύτητα &lt;em&gt;υπολογισμού hash&lt;/em&gt; και εκτίμηση χρόνου μέχρι την ολοκλήρωση",
	"ut_etau": "μέση ταχύτητα &lt;em&gt;μεταφόρτωσης&lt;/em&gt; και εκτίμηση χρόνου μέχρι την ολοκλήρωση",
	"ut_etat": "μέση &lt;em&gt;συνολική&lt;/em&gt; ταχύτητα και εκτίμηση χρόνου μέχρι την ολοκλήρωση",

	"uct_ok": "ολοκληρώθηκε επιτυχώς",
	"uct_ng": "no-good: απέτυχε / απορρίφθηκε / δεν βρέθηκε",
	"uct_done": "ολοκληρωμένα και αποτυχημένα",
	"uct_bz": "κάνει hash ή μεταφορτώνει",
	"uct_q": "σε αναμονή, εκκρεμεί",

	"utl_name": "όνομα αρχείου",
	"utl_ulist": "λίστα",
	"utl_ucopy": "αντιγραφή",
	"utl_links": "σύνδεσμοι",
	"utl_stat": "κατάσταση",
	"utl_prog": "πρόοδος",

	// keep short:
	"utl_404": "404",
	"utl_err": "ΣΦΑΛΜΑ",
	"utl_oserr": "ΣΦ-ΛΕ",
	"utl_found": "βρέθηκε",
	"utl_defer": "αναβολή",
	"utl_yolo": "YOLO",
	"utl_done": "έγινε",

	"ul_flagblk": "τα αρχεία προστέθηκαν στην ουρά</b><br>αλλά υπάρχει άλλη ενεργή μεταφόρτωση σε άλλη καρτέλα,<br>οπότε περίμενε να τελειώσει αυτό πρώτα",
	"ul_btnlk": "ο διακομιστής έχει κλειδώσει αυτήν την επιλογή σε αυτήν την κατάσταση",

	"udt_up": "Μεταφόρτωση",
	"udt_srch": "Αναζήτηση",
	"udt_drop": "ρίξ' το εδώ",

	"u_nav_m": '<h6>οκ, τι έχουμε εδώ;</h6><code>Enter</code> = Αρχεία (ένα ή περισσότερα)\n<code>ESC</code> = Ένας φάκελος (μαζί με υποφακέλους)',
	"u_nav_b": '<a href="#" id="modal-ok">Αρχεία</a><a href="#" id="modal-ng">Ένας φάκελος</a>',

	"cl_opts": "διακόπτες",
	"cl_hfsz": "μέγεθος αρχείου", //m
	"cl_themes": "θέμα",
	"cl_langs": "γλώσσα",
	"cl_ziptype": "λήψη φακέλου",
	"cl_uopts": "διακόπτες μεταφόρτωσης",
	"cl_favico": "favicon",
	"cl_bigdir": "μεγάλοι φάκελοι",
	"cl_hsort": "#ταξινόμηση",
	"cl_keytype": "σημείωση πλήκτρων",
	"cl_hiddenc": "κρυφές στήλες",
	"cl_hidec": "κρύψε",
	"cl_reset": "επανεκκίνηση",
	"cl_hpick": "πάτησε στις κεφαλίδες στηλών για να τις κρύψεις στον πίνακα παρακάτω",
	"cl_hcancel": "η απόκρυψη στηλών ακυρώθηκε",
	"cl_rcm": "μενού δεξιού κλικ", //m
	"cl_gauto": "αυτόματο田", //m

	"ct_grid": '田 το πλέγμα',
	"ct_ttips": '◔ ◡ ◔">ℹ️ συμβουλές εργαλείων',
	"ct_thumb": 'σε προβολή πλέγματος, εναλλαγή εικονιδίων ή μικρογραφιών$NΠλήκτρο συντόμευσης: T">🖼️ μικρογραφίες',
	"ct_csel": 'χρησιμοποίησε CTRL και SHIFT για επιλογή αρχείων σε προβολή πλέγματος">επιλογή',
	"ct_dsel": 'χρησιμοποίησε επιλογή με σύρσιμο σε προβολή πλέγματος">σύρσιμο', //m
	"ct_dl": 'εξαναγκασμός λήψης (να μην εμφανίζεται ενσωματωμένα) όταν γίνεται κλικ σε ένα αρχείο">dl', //m
	"ct_ihop": 'όταν η προβολή εικόνων κλείνει, κάνε scroll στο τελευταίο προβαλλόμενο αρχείο">g⮯',
	"ct_dots": 'εμφάνιση κρυφών αρχείων (αν το επιτρέπει ο server)">dotfiles',
	"ct_qdel": 'όταν διαγράφεις αρχεία, ζήτα επιβεβαίωση μόνο μία φορά">γρήγορη διαγραφή',
	"ct_dir1st": 'ταξινόμηση φακέλων πριν από τα αρχεία">📁 πρώτα',
	"ct_nsort": 'φυσική ταξινόμηση (για ονόματα αρχείων με αριθμούς στην αρχή)">φυσική ταξινόμηση',
	"ct_utc": 'εμφάνιση όλων των ημερομηνιών σε UTC">UTC',
	"ct_readme": 'εμφάνιση README.md στις λίστες φακέλων">📜 πληροφορίες',
	"ct_idxh": 'εμφάνιση index.html αντί για λίστα φακέλων">html',
	"ct_sbars": 'εμφάνιση μπαρών κύλισης">⟊',

	"cut_umod": "αν το αρχείο υπάρχει ήδη στον server, ενημέρωσέ το με την τελευταία χρονοσφραγίδα τροποποίησης για να ταιριάζει με το τοπικό αρχείο (απαιτεί δικαιώματα εγγραφής+διαγραφής)\">re📅",

	"cut_turbo": "το κουμπί yolo, πιθανόν να ΜΗΝ ΘΕΛΕΙΣ να το ενεργοποιήσεις:$N$Nχρησιμοποίησέ το αν μεταφορτώνεις πολλά αρχεία και χρειάστηκε να ξαναρχίσεις, και θες να συνεχίσεις τη μεταφότρωση όσο το δυνατόν πιο γρήγορα$N$Nαντικαθιστά τον έλεγχο hash με απλό <em>&quot;έχει το ίδιο μέγεθος αρχείου στον server?&quot;</em> οπότε αν το περιεχόμενο είναι διαφορετικό, ΔΕΝ θα ανέβει$N$Nπρέπει να το κλείσεις όταν τελειώσει η μεταφόρτωση και μετά να &quot;μεταφορτώσεις&quot; πάλι τα ίδια αρχεία για να τα επιβεβαιώσει το τοπικό σου πρόγραμμα\">turbo",

	"cut_datechk": "δεν επηρεάζει τίποτα εκτός αν το turbo είναι ενεργοποιημένο$N$Nμειώνει λίγο τον παράγοντα yolo; ελέγχει αν οι χρονοσφραγίδες στο διακομιστή ταιριάζουν με τα δικά σου$N$Nπιάνει <em>θεωρητικά</em> τις περισσότερες μισοτελειωμένες/κατεστραμμένες μεταφορτώσεις, αλλά δεν αντικαθιστά τον έλεγχο με το turbo απενεργοποιημένο μετέπειτα\">έλεγχος ημερομηνίας",

	"cut_u2sz": "μέγεθος (σε MiB) κάθε κομματιού μεταφόρτωσης; μεγάλες τιμές λειτουργούν καλύτερα σε μεγαλύτερες αποστάσεις διακομιστή-πελάτη. Δοκίμασε μικρές τιμές σε πολύ άστατες συνδέσεις",

	"cut_flag": "εξασφαλίζει ότι μόνο μία καρτέλα μεταφορτώνει κάθε φορά $N -- οι άλλες καρτέλες πρέπει να το έχουν κι αυτές ενεργό $N -- επηρεάζει μόνο τις καρτέλες που βρίσκονται στο ίδιο διεύθυνση",

	"cut_az": "μεταφόρτωσε τα αρχεία αλφαβητικά, αντί για το μικρότερο αρχείο, πρώτα$N$Nη αλφαβητική σειρά βοηθά να καταλάβεις αν κάτι χάλασε στο διακομιστή αλλά κάνει το ανέβασμα λίγο πιο αργό σε fiber / LAN",

	"cut_nag": "ειδοποίηση λειτουργικού συστήματος όταν τελειώσει η μεταφόρτωση$N(μόνο αν ο browser ή η καρτέλα δεν είναι ενεργά)",
	"cut_sfx": "ηχητική ειδοποίηση όταν τελειώσει η μεταφόρτωση$N(μόνο αν ο browser ή η καρτέλα δεν είναι ενεργά)",

	"cut_mt": "χρησιμοποίησε multithreading για να επιταχύνεις το hashing των αρχείων$N$Nχρησιμοποιεί web-workers και χρειάζεται$Nπερισσότερη RAM (μέχρι 512 MiB επιπλέον)$N$Nκάνει το https 30% πιο γρήγορο, το http 4.5x πιο γρήγορο\">mt",

	"cut_wasm": "χρησιμοποίησε wasm αντί για τον ενσωματωμένο hasher του browser; βελτιώνει την ταχύτητα σε chrome-based browsers αλλά αυξάνει το φορτίο της CPU, και παλιές εκδόσεις chrome έχουν bugs που κάνουν το browser να τρώει όλη τη RAM και να κρασάρει αν ενεργοποιηθεί\">wasm",

	"cft_text": "κείμενο favicon (κενό και ανανέωση για απενεργοποίηση)",
	"cft_fg": "χρώμα προσκηνίου",
	"cft_bg": "χρώμα παρασκηνίου",

	"cdt_lim": "μέγιστος αριθμός αρχείων προς εμφάνιση σε ένα φάκελο",
	"cdt_ask": "όταν φτάνεις στο τέλος,$Nαντί να φορτώσει περισσότερα αρχεία,$Nρωτά τι να κάνει",
	"cdt_hsort": "`πόσους κανόνες ταξινόμησης (`,sorthref`) να συμπεριλάβει σε URLs πολυμέσων. Αν το βάλεις 0 αγνοεί και κανόνες ταξινόμησης στους συνδέσμους πολυμέσων",
	"cdt_ren": "ενεργοποίηση προσαρμοσμένου μενού δεξιού κλικ, το κανονικό μενού είναι προσβάσιμο με shift + δεξί κλικ\">ενεργοποίηση", //m
	"cdt_rdb": "εμφάνιση του κανονικού μενού δεξιού κλικ όταν το προσαρμοσμένο είναι ήδη ανοιχτό και γίνεται ξανά δεξί κλικ\">x2", //m

	"tt_entree": "εμφάνιση navpane (δέντρο διαδρομών)$NΠλήκτρο συντόμευσης: B",
	"tt_detree": "εμφάνιση breadcrumbs (καρτέλες διαδρομών)$NΠλήκτρο συντόμευσης: B",
	"tt_visdir": "κύλιση στον επιλεγμένο φάκελο",
	"tt_ftree": "εναλλαγή δέντρου διαδρομών / αρχείων κειμένου$NΠλήκτρο συντόμευσης: V",
	"tt_pdock": "εμφάνιση γονικών φακέλων σε σταθερή μπάρα επάνω",
	"tt_dynt": "αυτόματη επέκταση καθώς επεκτείνεται το δέντρο διαδρομών",
	"tt_wrap": "αναδίπλωση λέξεων",
	"tt_hover": "αποκάλυψη των γραμμών που ξεπερνούν το πλάτος με το ποντίκι πάνω τους$N( σπάει το scroll εκτός αν το ποντίκι $N&nbsp; είναι στην αριστερή στήλη )",
	"tt_gauto": "εμφάνιση ως πλέγμα ή λίστα ανάλογα με τα περιεχόμενα του φακέλου", //m
	"tt_gathr": "χρήση πλέγματος αν αυτό το ποσοστό αρχείων είναι εικόνες/βίντεο", //m

	"ml_pmode": "στο τέλος του φακέλου...",
	"ml_btns": "εντολές",
	"ml_tcode": "μετακωδικοποίηση",
	"ml_tcode2": "μετακωδικοποίηση σε",
	"ml_tint": "φίλτρο χρώματος",
	"ml_eq": "ισοσταθμιστής ήχου",
	"ml_drc": "συμπιεστής δυναμικής εμβέλειας",
	"ml_ss": "παράβλεψη σιωπής", //m

	"mt_loop": "επανάληψη ενός τραγουδιού\">🔁",
	"mt_one": "σταμάτα μετά από ένα τραγούδι\">1️⃣",
	"mt_shuf": "τυχαία σειρά τραγουδιών σε κάθε φάκελο\">🔀",
	"mt_aplay": "αυτόματη αναπαραγωγή αν υπάρχει song-ID στη διεύθυνση που μπήκες στο διακομιστή$N$Nη απενεργοποίηση αυτού, σταματά το URL από το να ενημερώνεται με τα song-ID ενώ παίζει η μουσική για να αποτραπεί η αυτόματη αναπαραγωγή αν χαθούν αυτές οι ρυθμίσεις αλλά το URL παραμείνει το ίδιο\">a▶",
	"mt_preload": "ξεκίνα  τη φόρτωση του επόμενου τραγουδιού κοντά στο τέλος για συνεχόμενη ακρόαση\">προφόρτωση",
	"mt_prescan": "πήγαινε στον επόμενο φάκελο πριν τελειώσει το τελευταίο τραγούδι$Nγια να μη σταματήσει το πρόγραμμα περιήγησης να παίζει μουσική\">nav",
	"mt_fullpre": "προσπάθησε να προφορτώσεις ολόκληρο το τραγούδι;$N✅ ενεργό σε <b>αναξιόπιστες</b> συνδέσεις,$N❌ πιθανότατα απενεργοποιημένο σε αργές συνδέσεις\">πλήρες",
	"mt_fau": "σε κινητά, πρόλαβε να μην σταματήσει η μουσική αν το επόμενο τραγούδι δεν προφορτώθηκε γρήγορα (μπορεί να προκαλέσει πρόβλημα στην εμφάνιση των ετικετών)\">☕️",
	"mt_waves": "γραμμή αναζήτησης κυματομορφής:$Nεμφάνιση έντασης ήχου στην μπάρα αναζήτησης\">~s",
	"mt_npclip": "εμφάνισε κουμπιά για αντιγραφή του τρέχοντος τραγουδιού\">/np",
	"mt_m3u_c": "εμφάνισε κουμπιά για αντιγραφή των$Nεπιλεγμένων τραγουδιών ως καταχωρήσεις λίστας m3u8\">📻",
	"mt_octl": "ενσωμάτωση στο λειτουργικό σύστημα (σηντομεύσεις πλήκτρων πολυμέσων / osd)\">έλεγχος-OS",
	"mt_oseek": "επιτρέπει την αναζήτηση μέσω ενσωμάτωσης του λειτουργικού συστήματος$N$Nσημείωση: σε μερικές συσκευές (iPhones),$Nαντικαθιστά το κουμπί επόμενου τραγουδιού\">αναζήτηση",
	"mt_oscv": "εμφάνιση εξωφύλλου άλμπουμ σε osd\">εξώφυλλο",
	"mt_follow": "κρατά το τρέχον κομμάτι ορατό κατά την κύλιση\">🎯",
	"mt_compact": "συμπαγή κουμπιά ελέγχου\">⟎",
	"mt_uncache": "καθάρισε την προσωρινή μνήμη &nbsp;(δοκίμασε αυτό αν ο browser έχει αποθηκεύσει$Nχαλασμένο αντίγραφο τραγουδιού και αρνείται να παίξει)\">εκκαθάριση",
	"mt_mloop": "τυχαία αναπαραγωγή στον ανοικτό φάκελο\">🔁 τυχαία αναπαραγωγή",
	"mt_mnext": "φόρτωση επόμενου φακέλου και συνέχιση\">📂 επόμενο",
	"mt_mstop": "σταμάτησε την αναπαραγωγή\">⏸ σταμάτημα",
	"mt_cflac": "μετατροπή flac / wav σε {0}\">flac",
	"mt_caac": "μετατροπή aac / m4a σε {0}\">aac",
	"mt_coth": "μετατροπή όλων των άλλων (εκτός των mp3) σε {0}\">άλλο",
	"mt_c2opus": "καλύτερη επιλογή για desktop, laptop, android\">opus",
	"mt_c2owa": "opus-weba, για iOS 17.5 και νεότερα\">owa",
	"mt_c2caf": "opus-caf, για iOS 11 έως 17\">caf",
	"mt_c2mp3": "χρησιμοποίησε αυτό σε πολύ παλιές συσκευές\">mp3",
	"mt_c2flac": "βέλτιστη ποιότητα ήχου αλλά τεράστιο αρχείο για μεταφόρτωση\">flac",
	"mt_c2wav": "ασυμπίεστη αναπαραγωγή (ακόμα μεγαλύτερο αρχείο)\">wav",
	"mt_c2ok": "μια χαρά, σοφή επιλογή",
	"mt_c2nd": "δεν είναι η προτεινόμενη μορφή εξόδου για τη συσκευή σου, αλλά αυτό είναι ok",
	"mt_c2ng": "η συσκευή σου φαίνεται να μην υποστηρίζει αυτήν τη μορφή εξόδου, αλλά ας το δοκιμάσουμε ούτως ή άλλως",
	"mt_xowa": "υπάρχουν bugs σε iOS που εμποδίζουν την αναπαραγωγή στο παρασκήνιο με αυτήν τη μορφή· χρησιμοποίησε caf ή mp3 αντ’ αυτού",
	"mt_tint": "επίπεδο φόντου (0-100) στην μπάρα αναζήτησης$Nγια να κάνεις το buffering λιγότερο ενοχλητικό",
	"mt_eq": "`ενεργοποιεί τον ισοσταθμιστή και τον έλεγχο ενίσχυσης;$N$Nενίσχυση `0` = στάνταρ 100% ένταση (απαράλλαχτη)$N$Nεύρος `1 &nbsp;` = στάνταρ στερεοφωνικό (απαράλλαχτο)$Nεύρος `0.5` = 50% αριστερά-δεξιά μίξη ήχου$Nεύρος `0 &nbsp;` = μονοφωνικό$N$Nενίσχυση `-0.8` &amp; εύρος `10` = αφαίρεση φωνής :^)$N$Nη ενεργοποίηση του ισοσταθμιστή κάνει τα άλμπουμ χωρίς κενά, να παίζουν χωρίς καθόλου κενά, οπότε άφησέ το ενεργό με όλες τις τιμές στο μηδέν (εκτός από εύρος = 1) αν σε νοιάζει",
	"mt_drc": "ενεργοποιεί τον συμπιεστή δυναμικής εμβέλειας (εξομάλυνση έντασης / ακραία συμπίεση έντασης); θα ενεργοποιήσει και τον ισοσταθμιστή για να ισορροπήσει τον ήχο, οπότε βάλε όλα τα πεδία ισοσταθμιστή εκτός από το 'εύρος' στο 0 αν δεν το θες$N$Nχαμηλώνει την ένταση του ήχου πάνω από το όριο (THRESHOLD) dB; για κάθε RATIO dB πέρα από το όριο υπάρχει 1 dB εξόδου, οπότε οι προεπιλεγμένες τιμές όριο -24 και 'λόγος' 12 σημαίνουν ότι δεν θα ξεπεράσει ποτέ τα -22 dB και είναι ασφαλές να αυξήσεις την ενίσχυση ισοσταθμιστή σε 0.8, ή και 1.8 με ATK 0 και μεγάλο RLS όπως 90 (δουλεύει μόνο σε firefox· το RLS είναι max 1 σε άλλους browsers)$N$N(δες wikipedia, το εξηγούν καλύτερα)",
	"mt_ss": "`ἐνεργοποιεῖ τὴν παράλειψιν σιγῆς· πολλαπλασιάζει τὴν ταχύτητα διὰ `ταχ` πλησίον ἀρχῆς/τέλους, ὅταν ἡ φωνὴ ὑπὸ `φων` καὶ ἡ θέσις ἐν τοῖς πρώτοις `ἀρχ`% ἢ τελευταίοις `τελ`%", //m
	"mt_ssvt": "ὅριον φωνῆς (0-255)\">φων", //m
	"mt_ssts": "ἐνεργὸν ὅριον (% τροχιᾶς, ἀρχή)\">ἀρχ", //m
	"mt_sste": "ἐνεργὸν ὅριον (% τροχιᾶς, τέλος)\">τελ", //m
	"mt_sssm": "πολλαπλασιαστὴς ταχύτητος\">ταχ", //m

	"mb_play": "παίξε",
	"mm_hashplay": "να παίξω αυτό το αρχείο ήχου;",
	"mm_m3u": "πάτα <code>Enter/Εντάξει</code> για Αναπαραγωγή\nπάτα <code>ESC/Άκυρο</code> για Επεξεργασία",
	"mp_breq": "χρειάζεται firefox 82+ ή chrome 73+ ή iOS 15+",
	"mm_bload": "φορτώνει...",
	"mm_bconv": "μετατροπή σε {0}, περίμενε...",
	"mm_opusen": "ο browser σου δεν παίζει αρχεία aac / m4a;\nη μετατροπή σε opus είναι τώρα ενεργή",
	"mm_playerr": "η αναπαραγωγή, απέτυχε: ",
	"mm_eabrt": "Η προσπάθεια αναπαραγωγής ακυρώθηκε",
	"mm_enet": "Η σύνδεση του ίντερνέτ σου είναι χάλια",
	"mm_edec": "Το αρχείο αυτό είναι μάλλον κατεστραμμένο;;",
	"mm_esupp": "Ο browser σου δεν καταλαβαίνει αυτή τη μορφή ήχου",
	"mm_eunk": "Άγνωστο σφάλμα",
	"mm_e404": "Αδύνατη η αναπαραγωγή ήχου; σφάλμα 404: Το αρχείο δεν βρέθηκε.",
	"mm_e403": "Αδύνατη η αναπαραγωγή ήχου; σφάλμα 403: Άρνηση πρόσβασης.\n\nΔοκίμασε F5 για επαναφόρτωση, ίσως να έχεις αποσυνδεθεί",
	"mm_e415": "Αδύνατη η αναπαραγωγή ήχου; σφάλμα 415: Απέτυχε η μετατροπή αρχείου; έλεγξε τα logs του διακομιστή.", //m
	"mm_e500": "Αδύνατη η αναπαραγωγή ήχου; σφάλμα 500: Έλεγξε τα logs του διακομιστή.",
	"mm_e5xx": "Αδύνατη η αναπαραγωγή ήχου; σφάλμα διακομιστή",
	"mm_nof": "δεν βρέθηκαν άλλα αρχεία ήχου τριγύρω",
	"mm_prescan": "Αναζήτηση μουσικής για επόμενο τραγούδι...",
	"mm_scank": "Βρέθηκε το επόμενο τραγούδι:",
	"mm_uncache": "κρυφή μνήμη καθαρίστηκε· όλα τα τραγούδια θα ξανακατεβούν στην επόμενη αναπαραγωγή",
	"mm_hnf": "το τραγούδι αυτό πλέον δεν υπάρχει",

	"im_hnf": "η εικόνα αυτή πλέον δεν υπάρχει",

	"f_empty": "αυτός ο φάκελος είναι άδειος",
	"f_chide": "αυτό θα κρύψει τη στήλη «{0}»\n\nμπορείς να εμφανίσεις τις στήλες από τις ρυθμίσεις",
	"f_bigtxt": "αυτό το αρχείο είναι {0} MiB σε μέγεθος — σίγουρα θέλεις να το δεις ως κείμενο;",
	"f_bigtxt2": "να δεις μόνο το τέλος του αρχείου αντί για όλο; αυτό ενεργοποιεί και το following/tailing, που δείχνει νέες γραμμές που προστίθενται ζωντανά",
	"fbd_more": '<div id="blazy">εμφανίζονται <code>{0}</code> από <code>{1}</code> αρχεία; <a href="#" id="bd_more">δείξε {2}</a> ή <a href="#" id="bd_all">δείξε τα όλα</a></div>',
	"fbd_all": '<div id="blazy">εμφανίζονται <code>{0}</code> από <code>{1}</code> αρχεία; <a href="#" id="bd_all">δείξε όλα</a></div>',
	"f_anota": "μόνο {0} από τα {1} αντικείμενα επιλέχθηκαν;\nγια να επιλέξεις ολόκληρο το φάκελο, κύλησε πρώτα μέχρι κάτω",

	"f_dls": 'οι σύνδεσμοι αρχείων στον τρέχοντα φάκελο έχουν\nμετατραπεί σε συνδέσμους λήψης',
	"f_dl_nd": 'παράλειψη φακέλου (χρησιμοποιήστε λήψη zip/tar αντί γι’ αυτό):\n', //m

	"f_partial": "Για να κατεβάσεις με ασφάλεια ένα αρχείο που ανεβαίνει, κλίκαρε το αρχείο με το ίδιο όνομα, αλλά χωρίς την κατάληξη <code>.PARTIAL</code>. Πάτα Άκυρο ή Escape για να σταματήσεις.\n\nΠάτα Εντάξει / Enter αν αγνοείς την προειδοποίηση και κατέβασε το <code>.PARTIAL</code> αρχείο, που σχεδόν σίγουρα θα είναι κατεστραμμένο.",

	"ft_paste": "επικόλλησε {0} αντικείμενα$NΠλήκτρο συντόμευσης: ctrl-V",
	"fr_eperm": 'δεν μπορεί να μετονομαστεί:\nδεν έχεις δικαίωμα “μετακίνησης” σε αυτόν το φάκελο',
	"fd_eperm": 'δεν μπορεί να διαγραφεί:\nδεν έχεις δικαίωμα “διαγραφής” σε αυτόν το φάκελο',
	"fc_eperm": 'δεν μπορεί να κοπεί:\nδεν έχεις δικαίωμα “μετακίνησης” σε αυτόν το φάκελο',
	"fp_eperm": 'δεν μπορεί να επικολληθεί:\nδεν έχεις δικαίωμα “εγγραφής” σε αυτόν το φάκελο',
	"fr_emore": "επίλεξε τουλάχιστον ένα αντικείμενο για μετονομασία",
	"fd_emore": "επίλεξε τουλάχιστον ένα αντικείμενο για διαγραφή",
	"fc_emore": "επίλεξε τουλάχιστον ένα αντικείμενο για αποκοπή",
	"fcp_emore": "επίλεξε τουλάχιστον ένα αντικείμενο για αντιγραφή στο πρόχειρο",

	"fs_sc": "μοιράσου το φάκελο που βρίσκεσαι",
	"fs_ss": "μοιράσου τα επιλεγμένα αρχεία",
	"fs_just1d": "δεν μπορείς να επιλέξεις περισσότερους από έναν φακέλους,\nή να αναμείξεις αρχεία και φακέλους στην ίδια επιλογή",
	"fs_abrt": "❌ ακύρωση",
	"fs_rand": "🎲 τυχαίο όνομα",
	"fs_go": "✅ δημιούργησε κοινή χρήση",
	"fs_name": "όνομα",
	"fs_src": "πηγή",
	"fs_pwd": "κωδικός",
	"fs_exp": "λήξη",
	"fs_tmin": "λεπτά",
	"fs_thrs": "ώρες",
	"fs_tdays": "ημέρες",
	"fs_never": "αιώνιο",
	"fs_pname": "προαιρετικό όνομα συνδέσμου; αν είναι κενό, θα είναι τυχαίο",
	"fs_tsrc": "το αρχείο ή ο φάκελος προς κοινή χρήση",
	"fs_ppwd": "προαιρετικός κωδικός",
	"fs_w8": "δημιουργία κοινής χρήσης...",
	"fs_ok": "πάτα <code>Enter/Εντάξει</code> για Πρόχειρο\nπάτα <code>ESC/Άκυρο</code> για Κλείσιμο",

	"frt_dec": "μπορεί να διορθώσει μερικές περιπτώσεις κατεστραμμένων ονομάτων αρχείων\">αποκωδικοποίηση url",
	"frt_rst": "επανέφερε τα ονόματα αρχείων στα αρχικά τους\">↺ επαναφορά",
	"frt_abrt": "ακύρωσε και κλείσε αυτό το παράθυρο\">❌ ακύρωση",
	"frb_apply": "ΕΦΑΡΜΟΓΗ ΜΕΤΟΝΟΜΑΣΙΑΣ",
	"fr_adv": "μαζική / μεταδεδομένα / μετονομασία με πρότυπα\">προχωρημένη",
	"fr_case": "regex με διάκριση πεζών/κεφαλαίων\">case",
	"fr_win": "ασφαλή ονόματα για windows; αντικαθιστά <code>&lt;&gt;:&quot;\\|?*</code> με ιαπωνικούς χαρακτήρες πλήρους πλάτους\">win",
	"fr_slash": "αντικαθίσταται <code>/</code> με χαρακτήρα που δεν δημιουργεί νέους φακέλους\">όχι /",
	"fr_re": "`μοτίβα αναζήτησης (regex) για αναζήτηση στα αρχικά ονόματα; τα καταγραφόμενα groups μπορούν να χρησιμοποιηθούν στο πεδίο μορφοποίησης παρακάτω όπως `(1)` και `(2)` και ούτω καθεξής",
	"fr_fmt": "`εμπνευσμένο από foobar2000:$N`(title)` αντικαθίσταται από τίτλο τραγουδιού,$N`[(artist) - ](title)` παραλείπει το [this] αν το artist είναι κενό$N`$lpad((tn),2,0)` γεμίζει τον αριθμό κομματιού σε 2 ψηφία",
	"fr_pdel": "διαγραφή",
	"fr_pnew": "αποθήκευση ως",
	"fr_pname": "δώσε όνομα για τη νέα προεπιλογή",
	"fr_aborted": "ακυρώθηκε",
	"fr_lold": "παλιό όνομα",
	"fr_lnew": "νέο όνομα",
	"fr_tags": "ετικέτες για τα επιλεγμένα αρχεία (μόνο για ανάγνωση):",
	"fr_busy": "μετονομασία {0} αντικειμένων...\n\n{1}",
	"fr_efail": "αποτυχία μετονομασίας:\n",
	"fr_nchg": "{0} από τα νέα ονόματα άλλαξαν λόγω <code>win</code> και/ή <code>όχι /</code>\n\nΕίναι ΟΚ να συνεχίσουμε με αυτά τα ονόματα;",

	"fd_ok": "διαγραφή OK",
	"fd_err": "αποτυχία διαγραφής:\n",
	"fd_none": "δεν διαγράφηκε τίποτα; ίσως μπλοκαρισμένο από τις ρυθμίσεις του διακομιστή (xbd);",
	"fd_busy": "διαγραφή {0} αντικειμένων...\n\n{1}",
	"fd_warn1": "ΔΙΑΓΡΑΦΗ αυτών των {0} αντικειμένων;",
	"fd_warn2": "<b>Τελευταία ευκαιρία!</b> Δεν υπάρχει αναίρεση. Διαγραφή;",

	"fc_ok": "αποκοπή {0} αντικειμένων",
	"fc_warn": 'αποκοπή {0} αντικειμένων\n\nαλλά: μόνο <b>αυτή</b> η καρτέλα browser μπορεί να τα επικολλήσει\n(λόγω πολύ μεγάλης επιλογής)',

	"fcc_ok": "αντιγράφηκαν {0} αντικείμενα στο πρόχειρο",
	"fcc_warn": "αντιγράφηκαν {0} αντικείμενα στο πρόχειρο\n\nαλλά: μόνο <b>αυτή</b> η καρτέλα browser μπορεί να τα επικολλήσει\n(λόγω πολύ μεγάλης επιλογής)",

	"fp_apply": "χρησιμοποίησε αυτά τα ονόματα",
	"fp_skip": "αγνόησε συγκρούσεις", //m
	"fp_ecut": "πρώτα κάνε αποκοπή ή αντιγραφή κάποιων αρχείων / φακέλων για επικόλληση / μετακίνηση\n\nσημείωση: μπορείς να αποκόπτεις / επικολλάς ανάμεσα σε διαφορετικές καρτέλες browser",
	"fp_ename": "τα {0} αντικείμενα δεν μπορούν να μετακινηθούν εδώ γιατί τα ονόματα υπάρχουν ήδη. Δώσε νέα ονόματα παρακάτω για να συνεχίσεις, ή άφησε κενό (\"αγνόησε συγκρούσεις\") για να τα αγνοήσεις:", //m
	"fcp_ename": "τα {0} αντικείμενα δεν μπορούν να αντιγραφούν εδώ γιατί τα ονόματα υπάρχουν ήδη. Δώσε νέα ονόματα παρακάτω για να συνεχίσεις, ή άφησε κενό (\"αγνόησε συγκρούσεις\") για να τα αγνοήσεις:", //m
	"fp_emore": "υπάρχουν ακόμα συγκρούσεις ονομάτων που πρέπει να διορθωθούν",
	"fp_ok": "μετακίνηση OK",
	"fcp_ok": "αντιγραφή OK",
	"fp_busy": "μετακίνηση {0} αντικειμένων...\n\n{1}",
	"fcp_busy": "αντιγραφή {0} αντικειμένων...\n\n{1}",
	"fp_abrt": "γίνεται ακύρωση...", //m
	"fp_err": "αποτυχία μετακίνησης:\n",
	"fcp_err": "αποτυχία αντιγραφής:\n",
	"fp_confirm": "να μετακινηθούν αυτά τα {0} αντικείμενα εδώ;",
	"fcp_confirm": "να αντιγραφούν αυτά τα {0} αντικείμενα εδώ;",
	"fp_etab": "αποτυχία ανάγνωσης πρόχειρου από άλλη καρτέλα browser",
	"fp_name": "μεταφόρτωση αρχείου από τη συσκευή σου. Δώσε του όνομα:",
	"fp_both_m": '<h6>διάλεξε τι θα επικολλήσεις</h6><code>Enter</code> = Μετακίνηση {0} αρχείων από «{1}»\n<code>ESC</code> = Μεταφόρτωση {2} αρχείων από τη συσκευή σου',
	"fcp_both_m": '<h6>διάλεξε τι θα επικολλήσεις</h6><code>Enter</code> = Αντιγραφή {0} αρχείων από «{1}»\n<code>ESC</code> = Μεταφόρτωση {2} αρχείων από τη συσκευή σου',
	"fp_both_b": '<a href="#" id="modal-ok">Μετακίνηση</a><a href="#" id="modal-ng">Μεταφόρτωση</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Αντιγραφή</a><a href="#" id="modal-ng">Μεταφόρτωση</a>',

	"mk_noname": "γράψε ένα όνομα στο πεδίο κειμένου αριστερά πριν το κάνεις :p",
	"nmd_i1": "μπορείτε επίσης να προσθέσετε την κατάληξη που θέλετε, όπως <code>.md</code>", //m
	"nmd_i2": "μπορείτε να δημιουργήσετε μόνο αρχεία <code>.{0}</code> επειδή δεν έχετε δικαίωμα διαγραφής", //m

	"tv_load": "Φόρτωση αρχείου κειμένου:\n\n{0}\n\n{1}% ({2} από {3} MiB φορτωμένα)",
	"tv_xe1": "αδυναμία φόρτωσης αρχείου κειμένου:\n\nσφάλμα ",
	"tv_xe2": "404, αρχείο δεν βρέθηκε",
	"tv_lst": "λίστα αρχείων κειμένου σε",
	"tvt_close": "επιστροφή στην προβολή φακέλου$NΣυντόμευση: M (ή Esc)\">❌ κλείσιμο",
	"tvt_dl": "κατέβασε αυτό το αρχείο$NΣυντόμευση: Y\">💾 λήψη",
	"tvt_prev": "προβολή προηγούμενου εγγράφου$NΣυντόμευση: i\">⬆ προηγούμενο",
	"tvt_next": "προβολή επόμενου εγγράφου$NΣυντόμευση: K\">⬇ επόμενο",
	"tvt_sel": "επέλεξε αρχείο &nbsp; (για αποκοπή / αντιγραφή / διαγραφή / ...)$NΣυντόμευση: S\">επιλογή",
	"tvt_j": "ομορφοποίηση json$NΣυντόμευση: shift-J\">j", //m
	"tvt_edit": "άνοιγμα αρχείου στον επεξεργαστή κειμένου$NΣυντόμευση: E\">✏️ επεξεργασία",
	"tvt_tail": "παρακολούθηση αρχείου για αλλαγές; εμφάνιση νέων γραμμών σε πραγματικό χρόνο\">📡 παρακολούθηση",
	"tvt_wrap": "αναδίπλωση λέξεων\">↵",
	"tvt_atail": "κλείδωμα κύλισης στο κάτω μέρος\">⚓",
	"tvt_ctail": "αποκωδικοποίηση χρωμάτων τερματικού (ansi escape codes)\">🌈",
	"tvt_ntail": "όριο κύλισης (πόσα bytes κειμένου να κρατούνται φορτωμένα)",

	"m3u_add1": "το τραγούδι προστέθηκε στη λίστα m3u",
	"m3u_addn": "προστέθηκαν {0} τραγούδια στη λίστα m3u",
	"m3u_clip": "η λίστα m3u αντιγράφηκε στο πρόχειρο\n\nπρέπει να φτιάξεις ένα νέο αρχείο κειμένου με όνομα η_λίστα_μου.m3u και να επικολλήσεις τη λίστα μέσα· αυτό θα το καταστήσει αναπαράξιμο",

	"gt_vau": "μην δείχνεις το βίντεο, παίξε μόνο τον ήχο\">🎧",
	"gt_msel": "ενεργοποίηση επιλογής αρχείων; ctrl-κλικ σε αρχείο για παράκαμψη$N$N&lt;em&gt;όταν είναι ενεργό: διπλό κλικ σε αρχείο / φάκελο το ανοίγει&lt;/em&gt;$N$NΣυντόμευση: S\">πολλαπλή επιλογή",
	"gt_crop": "κεντραρισμένη περικοπή μικρογραφιών\">περικοπή",
	"gt_3x": "μικρογραφίες υψηλής ανάλυσης\">3x",
	"gt_zoom": "ζουμ",
	"gt_chop": "κόψε",
	"gt_sort": "ταξινόμηση κατά",
	"gt_name": "όνομα",
	"gt_sz": "μέγεθος",
	"gt_ts": "ημερομηνία",
	"gt_ext": "τύπος",
	"gt_c1": "μεγαλύτερη περικοπή ονομάτων αρχείων (δείξε λιγότερα)",
	"gt_c2": "μικρότερη περικοπή ονομάτων αρχείων (δείξε περισσότερα)",

	"sm_w8": "αναζήτηση...",
	"sm_prev": "τα παρακάτω αποτελέσματα αναζήτησης προέρχονται από προηγούμενη αναζήτηση:\n  ",
	"sl_close": "κλείσιμο αποτελεσμάτων αναζήτησης",
	"sl_hits": "εμφανίζονται {0} αποτελέσματα",
	"sl_moar": "φόρτωσε περισσότερα",

	"s_sz": "μέγεθος",
	"s_dt": "ημερομηνία",
	"s_rd": "μονοπάτι",
	"s_fn": "όνομα",
	"s_ta": "ετικέτες",
	"s_ua": "ανέβηκε@",
	"s_ad": "προχωρ.",
	"s_s1": "ελάχιστο σε MiB",
	"s_s2": "μέγιστο σε MiB",
	"s_d1": "ελάχιστο iso8601",
	"s_d2": "μέγιστο iso8601",
	"s_u1": "μεταφορτώθηκε αργότερα",
	"s_u2": "και/ή πριν",
	"s_r1": "το μονοπάτι περιέχει &nbsp; (χωρισμένα με κενό)",
	"s_f1": "το όνομα περιέχει &nbsp; (άρνηση με -nope)",
	"s_t1": "οι ετικέτες περιέχουν &nbsp; (^=αρχή, τέλος=$)",
	"s_a1": "συγκεκριμένες ιδιότητες μεταδεδομένων",

	"md_eshow": "δεν μπορεί να εμφανιστεί ",
	"md_off": "[📜<em>readme</em>] απενεργοποιημένο στο [⚙️] -- κρυμμένο έγγραφο",

	"badreply": "Αποτυχία ανάλυσης απάντησης από το διακομιστή",

	"xhr403": "403: Πρόσβαση αρνήθηκε\n\nδοκίμασε το F5, ίσως αποσυνδέθηκες",
	"xhr0": "άγνωστο (πιθανόν αποσύνδεση από το διακομιστή ή ο διακομιστής είναι εκτός σύνδεσης)",
	"cf_ok": "συγγνώμη γι' αυτό -- η προστασία DD" + wah + "oS ενεργοποιήθηκε\n\nοι διαδικασίες θα συνεχιστούν σε περίπου 30 δευτερόλεπτα\n\nαν δεν γίνει τίποτα, πάτα F5 για επαναφόρτωση",
	"tl_xe1": "αδύνατη η λίστα υποφακέλων:\n\nσφάλμα ",
	"tl_xe2": "404: Ο φάκελος δεν βρέθηκε",
	"fl_xe1": "αδύνατη η λίστα αρχείων σε φάκελο:\n\nσφάλμα ",
	"fl_xe2": "404: Ο φάκελος δεν βρέθηκε",
	"fd_xe1": "αδύνατη η δημιουργία υποφακέλου:\n\nσφάλμα ",
	"fd_xe2": "404: Ο γονικός φάκελος δεν βρέθηκε",
	"fsm_xe1": "αδύνατη η αποστολή μηνύματος:\n\nσφάλμα ",
	"fsm_xe2": "404: Ο γονικός φάκελος δεν βρέθηκε",
	"fu_xe1": "αποτυχία φόρτωσης λίστας unpost από το διακομιστή:\n\nσφάλμα ",
	"fu_xe2": "404: Το αρχείο δεν βρέθηκε??",

	"fz_tar": "μη συμπιεσμένο αρχείο gnu-tar (linux / mac)",
	"fz_pax": "μη συμπιεσμένο pax-format tar (πιο αργό)",
	"fz_targz": "gnu-tar με συμπίεση gzip επίπεδο 3$N$Nσυνήθως πολύ αργό, οπότε$Nχρησιμοποίησε καλύτερα μη συμπιεσμένο tar",
	"fz_tarxz": "gnu-tar με συμπίεση xz επίπεδο 1$N$Nσυνήθως πολύ αργό, οπότε$Nχρησιμοποίησε καλύτερα μη συμπιεσμένο tar",
	"fz_zip8": "zip με ονόματα αρχείων utf8 (ίσως να κολλάει σε windows 7 και παλιότερα)",
	"fz_zipd": "zip με παραδοσιακά ονόματα cp437, για πολύ παλιό λογισμικό",
	"fz_zipc": "cp437 με crc32 υπολογισμένο νωρίτερα,$Nγια MS-DOS PKZIP v2.04g (οκτώβριος 1993)$N(παίρνει παραπάνω χρόνο πριν ξεκινήσει η μεταφόρτωση)",

	"un_m1": "μπορείς να διαγράψεις τα πρόσφατα αρχεία που μεταφόρτωσες (ή να ακυρώσεις τα μισοτελειωμένα) παρακάτω",
	"un_upd": "ανανέωση",
	"un_m4": "ή μοιράσου τα αρχεία που βλέπεις παρακάτω:",
	"un_ulist": "εμφάνιση",
	"un_ucopy": "αντιγραφή",
	"un_flt": "προαιρετικό φίλτρο:&nbsp; η διεύθυνση πρέπει να περιέχει",
	"un_fclr": "καθαρισμός φίλτρου",
	"un_derr": "αποτυχία διαγραφής unpost:\n",
	"un_f5": "κάτι χάλασε, δοκίμασε την ανανέωση ή πάτα F5",
	"un_uf5": "συγγνώμη αλλά πρέπει να ανανεώσεις τη σελίδα (πχ με F5 ή CTRL-R) πριν ακυρώσεις αυτήν την αποστολή",
	"un_nou": "<b>προσοχή:</b> ο διακομιστής είναι πολύ φορτωμένος για να δείξει μισοτελειωμένες αποστολές· πάτα την ανανέωση, σε λίγο",
	"un_noc": "<b>προσοχή:</b> το unpost των ολοκληρωμένων αρχείων δεν επιτρέπεται από τη ρύθμιση του διακομιστή",
	"un_max": "εμφανίζονται τα πρώτα 2000 αρχεία (χρησιμοποίησε φίλτρο)",
	"un_avail": "μπορείς να διαγράψεις {0} πρόσφατα αρχεία<br />μπορείς να ακυρώσεις {1} μισοτελειωμένες αποστολές",
	"un_m2": "ταξινομημένα κατά χρόνο μεταφόρτωσης; τα πιο πρόσφατα πρώτα:",
	"un_no1": "άκυρο! καμία μεταφόρτωση δεν είναι αρκετά πρόσφατη",
	"un_no2": "άκυρο! καμία μεταφόρτωση με αυτό το φίλτρο δεν είναι αρκετά πρόσφατη",
	"un_next": "διάγραψε τα επόμενα {0} αρχεία παρακάτω",
	"un_abrt": "άκυρο",
	"un_del": "διαγραφή",
	"un_m3": "φορτώνω τις πρόσφατες μεταφορτώσεις σου...",
	"un_busy": "διαγράφω {0} αρχεία...",
	"un_clip": "αντιγράφηκαν {0} σύνδεσμοι στο πρόχειρο",

	"u_https1": "πρέπει",
	"u_https2": "μετάβαση σε https",
	"u_https3": "για καλύτερη απόδοση",
	"u_ancient": 'ο browser σου είναι εντυπωσιακά απαρχαιωμένος — ίσως να <a href="#" onclick="goto(\'bup\')">χρησιμοποιήσεις το bup αντί γι\' αυτό</a>',
	"u_nowork": "χρειάζεται firefox 53+ ή chrome 57+ ή iOS 11+",
	"tail_2old": "χρειάζεται firefox 105+ ή chrome 71+ ή iOS 14.5+",
	"u_nodrop": "ο browser σου είναι πολύ παλιός για drag&amp;drop μεταφορτώσεις",
	"u_notdir": "αυτός δεν είναι φάκελος!\n\nο browser σου είναι πολύ παλιός,\nδοκίμασε drag&amp;drop αντ' αυτού",
	"u_uri": "για να κάνεις drag&amp;drop εικόνων από άλλα παράθυρα browser,\nρίξ' τες πάνω στο μεγάλο κουμπί μεταφόρτωσης",
	"u_enpot": 'άλλαξε στο <a href="#">potato UI</a> (ίσως ανεβάζει πιο γρήγορα)',
	"u_depot": 'άλλαξε στο <a href="#">fancy UI</a> (ίσως ανεβάζει πιο αργά)',
	"u_gotpot": "αλλάζω στο potato UI για πιο γρήγορη μεταφόρτωση,\n\nμπορείς να το αλλάξεις πάλι αν θες!",
	"u_pott": "<p>αρχεία: &nbsp; <b>{0}</b> ολοκληρωμένα, &nbsp; <b>{1}</b> αποτυχημένα, &nbsp; <b>{2}</b> σε εξέλιξη, &nbsp; <b>{3}</b> σε ουρά</p>",
	"u_ever": "αυτός είναι ο βασικός uploader; το up2k θέλει τουλάχιστον<br>chrome 21 // firefox 13 // edge 12 // opera 12 // safari 5.1",
	"u_su2k": 'αυτός είναι ο βασικός uploader; το <a href="#" id="u2yea">up2k</a> είναι καλύτερο',
	"u_uput": "βελτιστοποίηση για ταχύτητα (παράλειψη ελέγχου ακεραιότητας)",
	"u_ewrite": "δεν έχεις δικαίωμα εγγραφής σε αυτόν τον φάκελο",
	"u_eread": "δεν έχεις δικαίωμα ανάγνωσης σε αυτόν τον φάκελο",
	"u_enoi": "η αναζήτηση αρχείων δεν είναι ενεργοποιημένη στο αρχείο ρυθμίσεων του διακομιστή",
	"u_enoow": "δεν μπορείς να κάνεις αντικατάσταση εδώ· χρειάζεται δικαίωμα Διαγραφής",
	"u_badf": "Αυτά τα {0} αρχεία (από {1} συνολικά) παραλείφθηκαν, πιθανώς λόγω δικαιωμάτων συστήματος αρχείων:\n\n",
	"u_blankf": "Αυτά τα {0} αρχεία (από {1} συνολικά) είναι άδεια / κενά· να τα μεταφορτώσω έτσι κι αλλιώς;\n\n",
	"u_applef": "Αυτά τα {0} αρχεία (από {1} συνολικά) πιθανώς δεν είναι επιθυμητά;\nΠάτα <code>Εντάξει/Enter</code> για ΝΑ ΑΓΝΟΗΘΟΥΝ τα παρακάτω αρχεία,\nΠάτα <code>Άκυρο/ESC</code> για ΝΑ ΜΗΝ ΑΠΟΚΛΕΙΣΤΟΥΝ και να ΜΕΤΑΦΟΡΤΩΘΟΎΝ κι αυτά:\n\n",
	"u_just1": "\nΊσως δουλέψει καλύτερα αν επιλέξεις μόνο ένα αρχείο",
	"u_ff_many": "αν χρησιμοποιείς <b>Linux / MacOS / Android,</b> τότε τόσα αρχεία <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>μπορεί</em> να κατάρρευση του Firefox!</a>\nαν γίνει αυτό, δοκίμασε ξανά (ή χρησιμοποίησε τον Chrome).",
	"u_up_life": "Αυτή η μεταφόρτωση θα διαγραφεί από το διακομιστή\n{0} μετά την ολοκλήρωσή της",
	"u_asku": "μεταφόρτωση αυτών των {0} αρχείων στο <code>{1}</code>",
	"u_unpt": "μπορείς να αναιρέσεις / διαγράψεις αυτήν τη μεταφόρτωση χρησιμοποιώντας το 🧯, πάνω αριστερά",
	"u_bigtab": "θα εμφανιστούν {0} αρχεία\n\nαυτό μπορεί να κάνει τον browser σου να κολλήσει, είσαι σίγουρος;",
	"u_scan": "Σάρωση αρχείων...",
	"u_dirstuck": "ο επεξεργαστής φακέλων κόλλησε προσπαθώντας να προσπελάσει τα εξής {0} αντικείμενα· θα τα παραλείψει:",
	"u_etadone": "Ολοκληρώθηκε ({0}, {1} αρχεία)",
	"u_etaprep": "(προετοιμασία για μεταφόρτωση)",
	"u_hashdone": "το hashing ολοκληρώθηκε",
	"u_hashing": "υπολογισμός hash",
	"u_hs": "handshaking...",
	"u_started": "τα αρχεία ανεβαίνουν τώρα· δες τα στο [🚀]",
	"u_dupdefer": "διπλότυπο; θα επεξεργαστεί μετά από όλα τα άλλα αρχεία",
	"u_actx": "πάτα αυτό το κείμενο για να μην χάσεις<br />απόδοση όταν αλλάζεις παράθυρα/καρτέλες",
	"u_fixed": "ΟΚ!&nbsp; Το διόρθωσα 👍",
	"u_cuerr": "αποτυχία μεταφόρτωσης τμήματοςς {0} από {1};\nπιθανώς ακίνδυνο, συνεχίζω\n\nαρχείο: {2}",
	"u_cuerr2": "ο διακομιστής απέρριψε τη μεταφόρτωση (τμήμα {0} από {1});\nθα ξαναδοκιμάσει αργότερα\n\nαρχείο: {2}\n\nσφάλμα ",
	"u_ehstmp": "θα ξαναδοκιμάσει; δες κάτω δεξιά",
	"u_ehsfin": "ο διακομιστής απέρριψε το αίτημα ολοκλήρωσης της μεταφόρτωσης; ξαναδοκιμάζει...",
	"u_ehssrch": "ο διακομιστής απέρριψε το αίτημα αναζήτησης; ξαναδοκιμάζει...",
	"u_ehsinit": "ο διακομιστής απέρριψε το αίτημα για εκκίνηση μεταφόρτωσης; ξαναδοκιμάζει...",
	"u_eneths": "σφάλμα δικτύου κατά το handshake μεταφόρτωσης; ξαναδοκιμάζει...",
	"u_enethd": "σφάλμα δικτύου κατά τον έλεγχο ύπαρξης στόχου; ξαναδοκιμάζει...",
	"u_cbusy": "ο διακομιστής περιμένει να μας εμπιστευτεί ξανά μετά από πρόβλημα δικτύου...",
	"u_ehsdf": "ο διακομιστής έμεινε από χώρο στο δίσκο!\n\nθα συνεχίσει να ξαναδοκιμάζει,\nσε περίπτωση που κάποιος\nελευθερώσει αρκετό χώρο για συνέχεια",
	"u_emtleak1": "φαίνεται πως ο browser σου έχει διαρροή μνήμης;\nπαρακαλώ",
	"u_emtleak2": ' <a href="{0}">αλλαγή σε https (συνιστάται)</a> ή ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'δοκίμασε τα εξής:\n<ul><li>πάτα <code>F5</code> για ανανέωση σελίδας</li><li>μετά απενεργοποίησε το &nbsp;<code>mt</code>&nbsp; κουμπί στις &nbsp;<code>⚙️ ρυθμίσεις</code></li><li>και δοκίμασε ξανά τη μεταφόρτωση</li></ul>Οι μεταφορτώσιες θα είναι λίγο πιο αργές, αλλά ok.\nΣυγγνώμη για την ταλαιπωρία!\n\nPS: το chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">έχει διόρθωση γι\' αυτό</a>',
	"u_emtleakf": 'δοκίμασε τα εξής:\n<ul><li>πάτα <code>F5</code> για ανανέωση σελίδας</li><li>μετά άνοιξε το <code>🥔</code> (potato) στο UI μεταφόρτωσης<li>και δοκίμασε ξανά τη μεταφόρτωση</li></ul>\nPS: ο firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">ελπίζει να φτιάξει αυτό το bug</a> κάποια στιγμή',
	"u_s404": "δεν βρέθηκε στο διακομιστή",
	"u_expl": "επεξήγηση",
	"u_maxconn": "οι περισσότεροι browser το περιορίζουν στα 6, αλλά ο firefox σου επιτρέπει να το αυξήσεις με <code>connections-per-server</code> στο <code>about:config</code>",
	"u_tu": '<p class="warn">ΠΡΟΕΙΔΟΠΟΙΗΣΗ: το turbo είναι ενεργοποιημένο, <span>&nbsp;το πρόγραμμα πελάτη ίσως να μην ανιχνεύσει και να μην ξαναεκκινήσει μισοτελειωμένες μεταφορτώσεις; δες τα tooltip του κουμπιού turbo</span></p>',
	"u_ts": '<p class="warn">ΠΡΟΕΙΔΟΠΟΙΗΣΗ: το turbo είναι ενεργοποιημένο, <span>&nbsp;τα αποτελέσματα αναζήτησης μπορεί να είναι λάθος; δες τα tooltip του κουμπιού turbo</span></p>',
	"u_turbo_c": "το turbo είναι απενεργοποιημένο στο αρχείο ρυθμίσεων του διακομιστή",
	"u_turbo_g": "απενεργοποιώ το turbo επειδή δεν έχεις δικαίωμα\nγια τη λίστα φακέλων σε αυτόν τον τόμο",
	"u_life_cfg": 'αυτόματη διαγραφή μετά από <input id="lifem" p="60" /> λεπτά (ή <input id="lifeh" p="3600" /> ώρες)',
	"u_life_est": 'η μεταφόρτωση θα διαγραφεί <span id="lifew" tt="τοπική ώρα">---</span>',
	"u_life_max": 'αυτός ο φάκελος επιβάλλει\nμέγιστη διάρκεια ζωής {0}',
	"u_unp_ok": "επιτρέπεται το unpost για {0}",
	"u_unp_ng": "δεν επιτρέπεται το unpost",
	"ue_ro": "έχεις μόνο δικαίωμα ανάγνωσης σε αυτόν το φάκελο\n\n",
	"ue_nl": "δεν είσαι συνδεδεμένος τώρα",
	"ue_la": 'είσαι συνδεδεμένος ως "{0}"',
	"ue_sr": "είσαι σε λειτουργία αναζήτησης αρχείων\n\nπήγαινε σε λειτουργία μεταφόρτωσης πατώντας το 🔎 (δίπλα στο μεγάλο κουμπί ΑΝΑΖΗΤΗΣΗΣ) και δοκίμασε πάλι\n\nσυγγνώμη",
	"ue_ta": "δοκίμασε να μεταφορτώσεις εκ νέου, θα πρέπει να δουλέψει τώρα",
	"ue_ab": "αυτό το αρχείο ανεβαίνει σε άλλο φάκελο και η μεταφόρτωση πρέπει να ολοκληρωθεί πριν ανέβει αλλού.\n\nΜπορείς να ακυρώσεις και να ξεχάσεις την αρχική μεταφόρτωση με το κουμπί 🧯 πάνω αριστερά",
	"ur_1uo": "ΟΚ: Το αρχείο ανέβηκε επιτυχώς",
	"ur_auo": "ΟΚ: Και τα {0} αρχεία ανέβηκαν επιτυχώς",
	"ur_1so": "ΟΚ: Το αρχείο βρέθηκε στο διακομιστή",
	"ur_aso": "ΟΚ: Και τα {0} αρχεία βρέθηκαν στο διακομιστή",
	"ur_1un": "Η μεταφόρτωση απέτυχε, συγγνώμη",
	"ur_aun": "Και οι {0} μεταφορτώσεις απέτυχαν, συγγνώμη",
	"ur_1sn": "Το αρχείο ΔΕΝ βρέθηκε στο διακομιστή",
	"ur_asn": "Τα {0} αρχεία ΔΕΝ βρέθηκαν στο διακομιστή",
	"ur_um": "Ολοκληρώθηκε;\n{0} μεταφορτώσεις είναι OK,\n{1} μεταφορτώσεις απέτυχαν, συγγνώμη",
	"ur_sm": "Ολοκληρώθηκε;\n{0} αρχεία βρέθηκαν στο διακομιστή,\n{1} αρχεία ΔΕΝ βρέθηκαν στο διακομιστή",

	"rc_opn": "άνοιγμα", //m
	"rc_ply": "αναπαραγωγή", //m
	"rc_pla": "αναπαραγωγή ως ήχος", //m
	"rc_txt": "άνοιγμα στον προβολέα αρχείων", //m
	"rc_md": "άνοιγμα στον επεξεργαστή κειμένου", //m
	"rc_dl": "λήψη", //m
	"rc_zip": "λήψη ως αρχείο", //m
	"rc_cpl": "ἀντίγραφε σύνδεσμον", //m
	"rc_del": "διαγραφή", //m
	"rc_cut": "αποκοπή", //m
	"rc_cpy": "αντιγραφή", //m
	"rc_pst": "επικόλληση", //m
	"rc_rnm": "μετονομασία", //m
	"rc_nfo": "νέος φάκελος", //m
	"rc_nfi": "νέο αρχείο", //m
	"rc_sal": "επιλογή όλων", //m
	"rc_sin": "αντιστροφή επιλογής", //m
	"rc_shf": "κοινή χρήση αυτού του φακέλου", //m
	"rc_shs": "κοινή χρήση επιλογής", //m

	"lang_set": "ανανέωση σελίδας για εφαρμογή της αλλαγής;",

	"splash": {
		"a1": "ανανέωση",
		"b1": "γεια σου ξένε! &nbsp; <small>(δεν είσαι συνδεδεμένος)</small>",
		"c1": "αποσύνδεση",
		"d1": "λίστα διεργασιών",
		"d2": "εμφανίζει την κατάσταση όλων των ενεργών διεργασιών",
		"e1": "επαναφόρτωση του cfg",
		"e2": "φορτώνει ξανά τα αρχεία ρυθμίσεων (λογαριασμοί/τόμοι/volflags),$Nκαι κάνει επανεξέταση όλων των τόμων e2ds$N$Nσημείωση: οποιαδήποτε αλλαγή στις καθολικές ρυθμίσεις$Nαπαιτεί πλήρη επανεκκίνηση για να εφαρμοστεί",
		"f1": "μπορείς να περιηγηθείς:",
		"g1": "μπορείς να εκτελέσεις μεταφόρτωση σε:",
		"cc1": "άλλα πράγματα:",
		"h1": "απενεργοποίση k304",
		"i1": "ενεργοποίηση k304",
		"j1": "η ενεργοποίηση του k304 θα αποσυνδέσει το πρόγραμμα πελάτη σου σε κάθε HTTP 304, κάτι που μπορεί να αποτρέψει κάποια προβληματικά proxies από το να κολλάνε (να μην φορτώνουν ξαφνικά σελίδες), <em>αλλά</em> θα κάνει τα πράγματα, γενικά πιο αργά",
		"k1": "επαναφορά ρυθμίσεων στο πρόγραμμα πελάτη",
		"l1": "συνδέσου για περισσότερα:",
		"ls3": "σύνδεση", //m
		"lu4": "όνομα χρήστη", //m
		"lp4": "κωδικός πρόσβασης", //m
		"lo3": "αποσύνδεση του “{0}” από παντού", //m
		"lo2": "αυτό θα τερματίσει τη συνεδρία σε όλους τους περιηγητές", //m
		"m1": "καλώς ήρθες,",
		"n1": "404 δεν βρέθηκε &nbsp;┐( ´ -`)┌",
		"o1": '´η μήπως δεν έχεις πρόσβαση -- δοκίμασε έναν κωδικό <a href="' + SR + '/?h">πήγαινε στην αρχική</a>',
		"p1": "403 απαγορευμένο &nbsp;~┻━┻",
		"q1": 'δοκίμασε έναν κωδικό <a href="' + SR + '/?h">πήγαινε στην αρχική</a>',
		"r1": "πίσω στην αρχική",
		".s1": "επανάληψη σάρωσης",
		"t1": "ενέργεια",
		"u2": "χρόνος από την τελευταία εγγραφή του διακομιστή$N( μεταφόρτωση / μετονομασία / ... )$N$N17d = 17 days$N1ω23 = 1 ώρα 23 λεπτά$N4λ56 = 4 λεπτά 56 δευτερόλεπτα",
		"v1": "σύνδεση",
		"v2": "χρησιμοποίησε αυτόν το διακομιστή σαν τοπικό δίσκο",
		"w1": "εναλλαγή σε https",
		"x1": "αλλαγή κωδικού",
		"y1": "επεξεργασία κοινόχρηστων φακέλων",
		"z1": "ξεκλείδωμα αυτού του κοινόχρηστου φακέλου:",
		"ta1": "συμπλήρωσε πρώτα το νέο σου κωδικό",
		"ta2": "επανέλαβε για να επιβεβαιώσεις το νέο κωδικό:",
		"ta3": "βρέθηκε τυπογραφικό λάθος· δοκίμασε ξανά",
		"nop": "ΣΦΑΛΜΑ: Ο κωδικός πρόσβασης δεν μπορεί να είναι κενός", //m
		"nou": "ΣΦΑΛΜΑ: Το όνομα χρήστη και/ή ο κωδικός πρόσβασης δεν μπορεί να είναι κενό", //m
		"aa1": "εισερχόμενα αρχεία:",
		"ab1": "απενεργοποίηση no304",
		"ac1": "ενεργοποίηση no304",
		"ad1": "η ενεργοποίηση του no304 θα απενεργοποιήσει όλη την προσωρινή αποθήκευση· δοκίμασέ το αν το k304 δεν ήταν αρκετό. Προσοχή, θα σπαταλήσει τεράστιο όγκο δικτυακής κίνησης!",
		"ae1": "ενεργές μεταφορτώσεις:",
		"af1": "προβολή πρόσφατων μεταφορτώσεων",
		"ag1": "εμφάνιση γνωστών χρηστών IdP", //m
	}
};
