
// Zeilen, die mit //m enden, sind nicht verifizierte maschinelle Übersetzungen

Ls.deu = {
	"tt": "Deutsch",

	"cols": {
		"c": "Aktionen",
		"dur": "Dauer",
		"q": "Qualität / Bitrate",
		"Ac": "Audiocodec",
		"Vc": "Videocodec",
		"Fmt": "Format / Container",
		"Ahash": "Audio Checksumme",
		"Vhash": "Video Checksumme",
		"Res": "Auflösung",
		"T": "Dateityp",
		"aq": "Audioqualität / Bitrate",
		"vq": "Videoqualität / Bitrate",
		"pixfmt": "Subsampling / Pixelstruktur",
		"resw": "horizontale Auflösung",
		"resh": "vertikale Auflösung",
		"chs": "Audiokanäle",
		"hz": "Abtastrate",
	},

	"hks": [
		[
			"misc",
			["ESC", "Dinge schliessen"],

			"file-manager",
			["G", "zwischen Liste und Gitter wechseln"],
			["T", "zwischen Vorschaubildern und Symbolen wechseln"],
			["⇧ A/D", "Vorschaubildergrösse ändern"],
			["STRG-K", "Auswahl löschen"],
			["STRG-X", "Auswahl ausschneiden"],
			["STRG-C", "Auswahl in Zwischenablage kopieren"],
			["STRG-V", "Zwischenablage hier einfügen"],
			["Y", "Auswahl herunterladen"],
			["F2", "Auswahl umbenennen"],

			"file-list-sel",
			["LEER", "Dateiauswahl aktivieren"],
			["↑/↓", "Cursor verschieben"],
			["STRG ↑/↓", "Cursor und Bildschirm verschieben"],
			["⇧ ↑/↓", "Vorherige / nächste Datei auswählen"],
			["STRG-A", "Alle Dateien / Ordner auswählen"],
		], [
			"navigation",
			["B", "Zwischen Brotkrumen und Navpane wechseln"],
			["I/K", "vorheriger / nächster Ordner"],
			["M", "übergeordneter Ordner (oder Vorherigen einklappen)"],
			["V", "Zwischen Textdateien und Navpane wechseln"],
			["A/D", "Grösse der Navpane ändern"],
		], [
			"audio-player",
			["J/L", "Vorheriger / nächster Song"],
			["U/O", "10 Sek. vor- / zurückspringen"],
			["0..9", "zu 0%..90% springen"],
			["P", "Wiedergabe / Pause"],
			["S", "aktuell abgespielten Song auswählen"],
			["Y", "Song herunterladen"],
		], [
			"image-viewer",
			["J/L, ←/→", "vorheriges / nächstes Bild"],
			["Pos1/Ende", "erstes / letztes Bild"],
			["F", "Vollbild"],
			["R", "im Uhrzeigersinn drehen"],
			["⇧ R", "gegen den Uhrzeigensinn drehen"],
			["S", "Bild auswählen"],
			["Y", "Bild herunterladen"],
		], [
			"video-player",
			["U/O", "10 Sek. vor- / zurückspringen"],
			["P/K/LEER", "Wiedergabe / Pause"],
			["C", "continue playing next"],
			["V", "Wiederholungs-Wiedergabe (Loop)"],
			["M", "Stummschalten"],
			["[ und ]", "Loop-Interval einstellen"],
		], [
			"textfile-viewer",
			["I/K", "vorherige / nächste Datei"],
			["M", "Textdatei schliessen"],
			["E", "Textdatei bearbeiten"],
			["S", "Textdatei auswählen (für Ausschneiden / Kopieren / Umbenennen)"],
			["Y", "Textdatei herunterladen"],
			["⇧ J", "json verschönern"],
		]
	],

	"m_ok": "OK",
	"m_ng": "Abbrechen",

	"enable": "Aktivieren",
	"danger": "ACHTUNG",
	"clipped": "in Zwischenablage kopiert",

	"ht_s1": "Sekunde",
	"ht_s2": "Sekunden",
	"ht_m1": "Minute",
	"ht_m2": "Minuten",
	"ht_h1": "Stunde",
	"ht_h2": "Stunden",
	"ht_d1": "Tag",
	"ht_d2": "Tage",
	"ht_and": " und ",

	"goh": "Einstellungen",
	"gop": 'zum vorherigen Ordner springen">vorh.',
	"gou": 'zum übergeordneter Ordner springen">hoch',
	"gon": 'zum nächsten Ordner springen">nächst.',
	"logout": "Abmelden ",
	"login": "Anmelden",
	"access": " Zugriff",
	"ot_close": "Submenu schliessen",
	"ot_search": "`Dateien nach Attributen, Pfad/Name, Musiktags oder beliebiger Kombination suchen$N$N`foo bar` = muss «foo» und «bar» enthalten,$N`foo -bar` = muss «foo» aber nicht «bar» enthalten,$N`^yana .opus$` = beginnt mit «yana» und ist «opus»-Datei$N`&quot;try unite&quot;` = genau «try unite» enthalten$N$NDatumsformat ist iso-8601, z.B.$N`2009-12-31` oder `2020-09-12 23:30:00`",
	"ot_unpost": "unpost: lösche deine letzten Uploads oder breche unvollständige ab",
	"ot_bup": "bup: Basic Uploader, unterstützt sogar Neuheiten wie Netscape 4.0",
	"ot_mkdir": "mkdir: neuen Ordner erstellen",
	"ot_md": "new-file: neue Textdatei erstellen",
	"ot_msg": "msg: eine Nachricht an das Server-Log schicken",
	"ot_mp": "Media Player-Optionen",
	"ot_cfg": "Konfigurationsoptionen",
	"ot_u2i": 'up2k: Dateien hochladen (wenn du Schreibrechte hast) oder in den Suchmodus wechseln, um zu prüfen, ob sie bereits auf dem Server existieren$N$NUploads sind fortsetzbar, multithreaded und behalten Dateizeitstempel, verbrauchen aber mehr CPU als [🎈]&nbsp; (der einfache Uploader)<br /><br />während Uploads wird dieses Symbol zu einem Fortschrittsanzeiger!',
	"ot_u2w": 'up2k: Dateien mit Wiederaufnahme-Unterstützung hochladen (Browser schließen und später dieselben Dateien erneut hochladen)$N$Nmultithreaded, behält Dateizeitstempel, verbraucht aber mehr CPU als [🎈]&nbsp; (der einfache Uploader)<br /><br />während Uploads wird dieses Symbol zu einem Fortschrittsanzeiger!',
	"ot_noie": 'Bitte benutze Chrome / Firefox / Edge',

	"ab_mkdir": "Ordner erstellen",
	"ab_mkdoc": "Textdatei erstellen",
	"ab_msg": "Nachricht an Server Log senden",

	"ay_path": "zu Ordnern springen",
	"ay_files": "zu Dateien springen",

	"wt_ren": "ausgewählte Elemente umbenennen$NHotkey: F2",
	"wt_del": "ausgewählte Elemente löschen$NHotkey: STRG-K",
	"wt_cut": "ausgewählte Elemente ausschneiden &lt;small&gt;(um sie dann irgendwo anders einzufügen)&lt;/small&gt;$NHotkey: STRG-X",
	"wt_cpy": "ausgewählte Elemente in Zwischenablage kopieren$N(um sie dann irgendwo anders einzufügen)$NHotkey: ctrl-C",
	"wt_pst": "zuvor ausgeschnittenen / kopierte Elemente einfügen$NHotkey: STRG-V",
	"wt_selall": "alle Dateien auswählen$NHotkey: STRG-A (wenn Datei fokusiert)",
	"wt_selinv": "Auswahl invertieren",
	"wt_zip1": "Diesen Ordner als Archiv herunterladen",
	"wt_selzip": "Auswahl als Archiv herunterladen",
	"wt_seldl": "Auswahl als separate Dateien herunterladen$NHotkey: Y",
	"wt_npirc": "kopiere Titelinfo als IRC-formattierten Text",
	"wt_nptxt": "kopiere Titelinfo als Text",
	"wt_m3ua": "Zu M3U-Wiedergabeliste hinzufügen (wähle später <code>📻copy</code>)",
	"wt_m3uc": "M3U-Wiedergabeliste in Zwischenablage kopieren",
	"wt_grid": "Zwischen Gitter und Liste wechseln$NHotkey: G",
	"wt_prev": "Vorheriger Titel$NHotkey: J",
	"wt_play": "Wiedergabe / Pause$NHotkey: P",
	"wt_next": "Nächster Titel$NHotkey: L",

	"ul_par": "Parallele Uploads:",
	"ut_rand": "Zufällige Dateinamen",
	"ut_u2ts": "Zuletzt geändert-Zeitstempel von$Ndeinem Dateisystem auf den Server übertragen\">📅",
	"ut_ow": "Existierende Dateien auf dem Server überschreiben?$N🛡️: Nie (generiert einen neuen Dateinamen)$N🕒: Überschreiben, wenn Server-Datei älter ist als meine$N♻️: Überschreiben, wenn der Dateiinhalt anders ist$N⏭️: Vorhandene Dateien immer überspringen",
	"ut_mt": "Andere Dateien während des Uploads hashen$N$Nsolltest du deaktivieren, falls deine CPU oder Festplatte zum Flaschenhals werden könnte",
	"ut_ask": 'Vor dem Upload nach Bestätigung fragen">💭',
	"ut_pot": "Verbessert Upload-Geschwindigkeit$Nindem das UI weniger komplex gemacht wird",
	"ut_srch": "nicht wirklich hochladen, stattdessen prüfen ob Datei bereits auf dem Server existiert (scannt alle Ordner, die du lesen kannst)",
	"ut_par": "setze auf 0 zum Pausieren$N$Nerhöhe, wenn deine Verbindung langsam / instabil ist$N$lass auf 1 im LAN oder wenn die Festplatte auf dem Server ein Flaschenhals ist",
	"ul_btn": "Dateien / Ordner hier<br>ablegen (oder klick mich)",
	"ul_btnu": "U P L O A D",
	"ul_btns": "S U C H E N",

	"ul_hash": "hash",
	"ul_send": "senden",
	"ul_done": "fertig",
	"ul_idle1": "keine Uploads in der Warteschlange",
	"ut_etah": "durchschnittl. &lt;em&gt;hashing&lt;/em&gt; Geschw. &amp; gesch. Restzeit",
	"ut_etau": "durchschnittl. &lt;em&gt;upload&lt;/em&gt; Geschw. &amp; gesch. Restzeit",
	"ut_etat": "durchschnittl. &lt;em&gt;total&lt;/em&gt; Geschw. &amp; gesch. Restzeit",

	"uct_ok": "Erfolgreich abgeschlossen",
	"uct_ng": "no-good: fehlgeschlagen / abgelehnt / nicht gefunden",
	"uct_done": "ok and ng zusammen",
	"uct_bz": "wird gehasht oder hochgeladen",
	"uct_q": "ausstehend",

	"utl_name": "Dateiname",
	"utl_ulist": "Liste",
	"utl_ucopy": "kopieren",
	"utl_links": "Links",
	"utl_stat": "Status",
	"utl_prog": "Fortschritt",

	// keep short:
	"utl_404": "404",
	"utl_err": "Fehler",
	"utl_oserr": "OS-Fehler",
	"utl_found": "gefunden",
	"utl_defer": "zurückstellen",
	"utl_yolo": "YOLO",
	"utl_done": "fertig",

	"ul_flagblk": "Die Dateien wurden zur Warteschlange hinzugefügt</b><br>jedoch ist up2k gerade in einem anderen Browsertab aktiv.<br>Ich warte, bis der Upload abgeschlossen ist.",
	"ul_btnlk": "Die Serverkonfiguration hat diese Einstellung gesperrt",

	"udt_up": "Upload",
	"udt_srch": "Suchen",
	"udt_drop": "hier ablegen",

	"u_nav_m": '<h6>okay, was gibts??</h6><code>Eingabe</code> = Dateien (1 oder mehr)\n<code>ESC</code> = 1 Ordner (inkl. Unterordner)',
	"u_nav_b": '<a href="#" id="modal-ok">Dateien</a><a href="#" id="modal-ng">1 Ordner</a>',

	"cl_opts": "Schalter",
	"cl_hfsz": "Dateigröße",
	"cl_themes": "Themes",
	"cl_langs": "Sprache",
	"cl_ziptype": "Ordner Download",
	"cl_uopts": "up2k Schalter",
	"cl_favico": "Favicon",
	"cl_bigdir": "grosse Ordner",
	"cl_hsort": "#sort",
	"cl_keytype": "Schlüsselnotation",
	"cl_hiddenc": "Spalten verstecken",
	"cl_hidec": "verstecken",
	"cl_reset": "zurücksetzen",
	"cl_hpick": "zum Verstecken, tippe auf Spaltenüberschriften in der Tabelle unten",
	"cl_hcancel": "Spaltenbearbeitung abgebrochen",
	"cl_rcm": "Rechtsklick-Menü",
	"cl_gauto": "auto-raster", //m

	"ct_grid": '田 Das Raster&trade;',
	"ct_ttips": '◔ ◡ ◔">ℹ️ Tooltips',
	"ct_thumb": 'In Raster-Ansicht, zwischen Icons und Vorschau wechseln$NHotkey: T">🖼️ Vorschaubilder',
	"ct_csel": 'Benutze STRG und UMSCHALT für Dateiauswahl in Raster-Ansicht">sel',
	"ct_dsel": 'Ziehauswahl in Raster-Ansicht verwenden">ziehen', //m
	"ct_dl": 'Beim Klick auf Dateien sie immer herunterladen (nicht einbetten)">dl',
	"ct_ihop": 'Wenn die Bildanzeige geschlossen ist, scrolle runter zu den zuletzt angesehenen Dateien">g⮯',
	"ct_dots": 'Verstecke Dateien anzeigen (wenn durch den Server erlaubt)">dotfiles',
	"ct_qdel": 'Nur einmal fragen, wenn mehrere Dateien gelöscht werden">qdel',
	"ct_dir1st": 'Ordner vor Dateien sortieren">📁 zuerst',
	"ct_nsort": 'Natürliche Sortierung (für Dateinamen mit führenden Ziffern)">nsort',
	"ct_utc": 'Für alle Zeitangaben UTC verwenden">UTC',
	"ct_readme": 'README.md in Dateiliste anzeigen">📜 readme',
	"ct_idxh": 'index.html anstelle von Dateiliste anzeigen">htm',
	"ct_sbars": 'Scrollbars zeigen">⟊',

	"cut_umod": "Sollte die Datei bereits auf dem Server existieren, den 'Zuletzt geändert'-Zeitstempel an deine lokale Datei anpassen (benötigt Lese- und Löschrechte)\">re📅",

	"cut_turbo": "der YOLO-Knopf, den du wahrscheinlich NICHT aktivieren willst:$N$NBenutze ihn, falls du ne Menge Zeug hochladen wolltest und aus irgendeinem Grund neustarten musstest und du so schnell wie möglich weitermachen willst.$N$Ndies ersetzt den Hash-Check mit einem einfachen <em>&quot;Ist die Datei auf dem Server gleich gross?&quot;</em>, wenn die Datei also anderen Inhalt hat, wird sie NICHT nochmal hochgeladen!$N$NDu solltest dieses Feature ausschalten, sobald der Upload fertig ist und dann die gleichen Dateien nochmal &quot;hochladen&quot;, damit der Client sie verifizieren kann.\">turbo",

	"cut_datechk": "Funktioniert nur in kombination mit dem Turbo-Knopf$N$NReduziert den YOLO-Faktor ein bisschen; prüft, ob der Zeitstempel deiner Datei mit dem auf dem Server übereinstimmt$N$Nsollte <em>theoretisch</em> die meisten unfertigen / korrupten Uploads erwischen, ist aber nicht zu gebrauchen, um einen Prüfdurchgang nach einem Turbo-Upload zu machen\">date-chk",

	"cut_u2sz": "Grösse (in MiB) für jeden Upload-Chunk; mit grossen Werten fliegen die Bits besser über den Atlantik. Versuche kleine Werte, wenn du eine schlechte Verbindung hast (z.B. du benutzt mobile Daten in Deutschland)",

	"cut_flag": "Stelle sicher, dass nur ein Tab auf einmal Dateien hochlädt$N -- andere Tabs müssen diese Funktion auch aktiviert haben $N -- funktioniert nur bei Tabs mit der gleichen Domäne",

	"cut_az": "Lädt Dateien in alphabetischer Reihenfolge hoch, anstatt nach Dateigrösse$N$NAlphabethische Reihenfolge kann es einfacher machen, Server-Fehler mit naktem Auge zu erkennen, macht aber Uploads über Glassfaser / LAN etwas langsamer",

	"cut_nag": "Benachrichtigung über das Betriebssystem abgeben, wenn Upload fertig ist$N(nur wenn Browser oder Tab nicht im Vordergrund ist)",
	"cut_sfx": "Spielt ein Ton ab, wenn Upload fertig ist$N(nur wenn Browser oder Tab nicht im Vordergrund ist)",

	"cut_mt": "Multithreading benutzen um Datei-Hashing zu beschleunigen$N$NDies nutzt Web-Workers und benötigt$Nmehr RAM (bis zu 512 MiB extra)$N$Nbeschleunigt HTTPS 30% schneller, HTTP um 4.5x\">mt",

	"cut_wasm": "benutzt WASM anstelle des Browser-eigenen Hashers; verbessert Geschwindigkeit auf Chromium-basierten Browsern, erhöht aber die CPU-Auslastung. Viele ältere Versionen von Chrome haben Memory-Leaks, die den gesamten RAM verbrauchen und dann crashen, wenn diese Funktion aktiviert ist.\">wasm",

	"cft_text": "Favicon Text (leer lassen und neuladen zum Deaktivieren)",
	"cft_fg": "Vordergrundfarbe",
	"cft_bg": "Hintergrundfarbe",

	"cdt_lim": "max. Anz. Dateien, die in einem Ordner gezeigt werden sollen",
	"cdt_ask": "beim Runterscrollen nach $NAktion fragen statt mehr,$NDateien zu laden",
	"cdt_hsort": "`Menge an Sortierregeln (`,sorthref`) in Media-URLs enthalten sein sollen. Ein Wert von 0 sorgt dafür, dass Sortierregeln in Media-URLs ignoriert werden",
	"cdt_ren": "spezielles Rechtsklick-Menü aktivieren, das Browser-Menü ist weiterhin mit Shift + Rechtsklick erreichbar\">aktivieren",
	"cdt_rdb": "normales Rechtsklick-Menü anzeigen, wenn das benutzerdefinierte bereits offen ist und erneut rechts geklickt wird\">x2", //m

	"tt_entree": "Navpane anzeigen (Ordnerbaum Sidebar)$NHotkey: B",
	"tt_detree": "Breadcrumbs anzeigen$NHotkey: B",
	"tt_visdir": "zu ausgewähltem Ordner scrollen",
	"tt_ftree": "zw. Ordnerbaum / Textdateien wechseln$NHotkey: V",
	"tt_pdock": "übergeordnete Ordner in einem angedockten Fenster oben anzeigen",
	"tt_dynt": "autom. wachsen wenn Baum wächst",
	"tt_wrap": "Zeilenumbruch",
	"tt_hover": "Beim Hovern überlange Zeilen anzeigen$N(Scrollen funktioniert nicht ausser $N&nbsp; Cursor ist im linken Gutter)",
	"tt_gauto": "je nach ordnerinhalt als raster oder liste anzeigen", //m
	"tt_gathr": "raster verwenden, wenn dieser prozentsatz der dateien bilder/videos sind", //m

	"ml_pmode": "am Ende des Ordners...",
	"ml_btns": "cmds",
	"ml_tcode": "transcodieren",
	"ml_tcode2": "transcodieren zu",
	"ml_tint": "färben",
	"ml_eq": "Audio Equalizer",
	"ml_drc": "Dynamic Range Compressor",
	"ml_ss": "Stille Überspringen", //m

	"mt_loop": "Song wiederholen\">🔁",
	"mt_one": "Wiedergabe nach diesem Song beenden\">1️⃣",
	"mt_shuf": "Zufällige Wiedergabe im Ordner\">🔀",
	"mt_aplay": "automatisch abspielen, wenn der Link, mit dem du auf den Server zugreifst, eine Titel-ID enthält$N$NDeaktivieren verhindert auch, dass die Seiten-URL bei Musikwiedergabe mit Titel-IDs aktualisiert wird, um Autoplay zu verhindern, falls diese Einstellungen verloren gehen, die URL aber bestehen bleibt\">a▶",
	"mt_preload": "nächsten Titel gegen Ende vorladen für nahtlose Wiedergabe\">Vorladen",
	"mt_prescan": "vor Ende des letzten Titels zum nächsten Ordner wechseln,$Ndamit der Browser die$NWiedergabe nicht stoppt\">Navigation",
	"mt_fullpre": "versuchen, den gesamten Titel vorzuladen;$N✅ bei <b>unzuverlässiger</b> Verbindung aktivieren,$N❌ bei langsamer Verbindung deaktivieren\">vollst&auml;ndig",
	"mt_fau": "auf Handys verhindern, dass Musik stoppt, wenn der nächste Titel nicht schnell genug vorlädt (kann zu fehlerhafter Tag-Anzeige führen)\">☕️",
	"mt_waves": "Wellenform-Suchleiste:$NAudio-Amplitude in der Leiste anzeigen\">~s",
	"mt_npclip": "Buttons zum Kopieren des aktuellen Titels anzeigen\">/np",
	"mt_m3u_c": "Buttons zum Kopieren der$Nausgewählten Titel als m3u8-Wiedergabeliste anzeigen\">📻",
	"mt_octl": "OS-Integration (Media-Hotkeys/OSD)\">os-ctl",
	"mt_oseek": "Suchen via OS-Integration erlauben$N$NHinweis: auf einigen Geräten (iPhones)$Nersetzt dies den nächsten-Titel-Button\">Suchen",
	"mt_oscv": "Albumcover in OSD anzeigen\">Cover",
	"mt_follow": "den spielenden Titel im Blick behalten\">🎯",
	"mt_compact": "kompakte Steuerelemente\">⟎",
	"mt_uncache": "Cache leeren &nbsp;(probier das, wenn dein Browser$Neine defekte Kopie eines Titels zwischenspeichert und sich weigert, ihn abzuspielen)\">Cache leeren",
	"mt_mloop": "offenen Ordner wiederholen\">🔁 Schleife",
	"mt_mnext": "nächsten Ordner laden und fortfahren\">📂 nächster",
	"mt_mstop": "Wiedergabe beenden\">⏸ Stop",
	"mt_cflac": "FLAC / WAV zu {0} konvertierebn\">flac",
	"mt_caac": "AAC / M4A zu {0} konvertieren\">aac",
	"mt_coth": "Convertiere alle Dateien (die nicht MP3 sind) zu {0}\">oth",
	"mt_c2opus": "Beste Wahl für Desktops, Laptops, Android\">opus",
	"mt_c2owa": "opus-weba, für iOS 17.5 und neuer\">owa",
	"mt_c2caf": "opus-caf, für iOS 11 bis 17\">caf",
	"mt_c2mp3": "benutze dieses Format für ältere Geräte\">mp3",
	"mt_c2flac": "beste Klangqualität, aber riesige Downloads\">flac",
	"mt_c2wav": "unkomprimierte Wiedergabe (noch größer)\">wav",
	"mt_c2ok": "Gute Wahl, Chef!",
	"mt_c2nd": "Das ist nicht das empfohlene Ausgabeformat für dein Gerät, aber passt schon",
	"mt_c2ng": "Dein Gerät scheint dieses Ausgabeformat nicht zu unterstützen, aber lass trotzdem mal probieren",
	"mt_xowa": "Es gibt Bugs in iOS, die die Hintergrund-Wiedergabe mit diesem Format verhindern; bitte nutze caf oder mp3 stattdessen",
	"mt_tint": "Hintergrundlevel (0-100) auf der Seekbar$Num Buffern weniger ablenkend zu machen",
	"mt_eq": "`Aktiviert Equalizer und Lautstärkeregelung;$N$Nboost `0` = Standard 100% Lautstärke (unverändert)$N$Nwidth `1 &nbsp;` = Standard Stereo (unverändert)$Nwidth `0.5` = 50% Links-Rechts-Crossfeed$Nwidth `0 &nbsp;` = Mono$N$Nboost `-0.8` &amp; width `10` = Gesangsentfernung :^)$N$NDer Equalizer macht nahtlose Alben vollständig nahtlos, also lass' ihn mit allen Werten auf Null (außer width = 1) aktiviert, wenn dir das wichtig ist",
	"mt_drc": "Aktiviert den Dynamic Range Compressor (Lautstärkeglättung/-begrenzung); aktiviert auch den Equalizer zum Ausgleich, setze alle EQ-Felder außer 'width' auf 0, wenn du das nicht willst$N$Nsenkt die Lautstärke von Audio über SCHWELLENWERT dB; für jedes VERHÄLTNIS dB über SCHWELLENWERT gibt es 1 dB Ausgabe, also bedeuten Standardwerte von tresh -24 und ratio 12, dass es nie lauter als -22 dB werden sollte und der Equalizer-Boost sicher auf 0.8 oder sogar 1.8 mit ATK 0 und einem großen RLS wie 90 erhöht werden kann (funktioniert nur in Firefox; in anderen Browsern ist RLS max. 1)$N$N(siehe Wikipedia, dort wird es viel besser erklärt)",
	"mt_ss": "`Aktiviert Stille-Überspringen; multipliziert die Wiedergabegeschwindigkeit mit `vor`, nahe Anfang/Ende von Titeln, wenn die Lautstärke unter `laut` liegt und die Position innerhalb der ersten `anf`% oder letzten `end`% ist", //m
	"mt_ssvt": "Lautstärkeschwelle (0-255)\">laut", //m
	"mt_ssts": "Aktiv-Schwelle (% Titel, Anfang)\">anf", //m
	"mt_sste": "Aktiv-Schwelle (% Titel, Ende)\">end", //m
	"mt_sssm": "Wiedergabegeschwindigkeits-Multiplikator\">vor", //m

	"mb_play": "Abspielen",
	"mm_hashplay": "Diese Audiodatei abspielen?",
	"mm_m3u": "Drücke <code>Eingabe/OK</code> zum Abspielen\nDrücke <code>ESC/Abbrechen</code> zum Bearbeiten",
	"mp_breq": "Benötigt Firefox 82+ oder Chrome 73+ oder iOS 15+",
	"mm_bload": "Lädt...",
	"mm_bconv": "Konvertiere zu {0}, bitte warte...",
	"mm_opusen": "Dein Browser kann AAC- / M4A-Dateien nicht abspielen;\nUmwandlung zu Opus ist jetzt aktiv",
	"mm_playerr": "Wiedergabefehler: ",
	"mm_eabrt": "Der Wiedergabeversuch wurde abgebrochen",
	"mm_enet": "Dein Internet läuft auf Edge, wa?",
	"mm_edec": "Die Datei scheint beschädigt zu sein??",
	"mm_esupp": "Dein Browser versteht dieses Audioformat nicht",
	"mm_eunk": "Unbekannter Fehler",
	"mm_e404": "Konnte Datei nicht abspielen; Fehler 404: Datei nicht gefunden.",
	"mm_e403": "Konnte Datei nicht abspielen; Fehler 403: Zugriff verweigert.\n\nDrücke F5 zum Neuladen, vielleicht wurdest du abgemeldet",
	"mm_e415": "Konnte Datei nicht abspielen; Fehler 415: Umwandlung der Datei fehlgeschlagen; Serverlogs prüfen.", //m
	"mm_e500": "Konnte Datei nicht abspielen; Fehler 500: Prüfe die Serverlogs.",
	"mm_e5xx": "Konnte Datei nicht abspielen; Server Fehler ",
	"mm_nof": "finde keine weiteren Audiodateien in der Nähe",
	"mm_prescan": "Suche nach Musik zum Abspielen...",
	"mm_scank": "Nächster Song gefunden:",
	"mm_uncache": "Cache geleert; Alle Songs werden beim nächsten Abspielversuch neu heruntergeladen",
	"mm_hnf": "dieser Song existiert nicht mehr",

	"im_hnf": "dieses Bild existiert nicht mehr",

	"f_empty": 'Dieser Ordner ist leer',
	"f_chide": 'Dies blendet die Spalte «{0}» aus\n\nDu kannst Spalten in den Einstellungen wieder einblenden.',
	"f_bigtxt": "Diese Datei ist {0} MiB gross -- Sicher, dass du sie als Text anzeigen willst?",
	"f_bigtxt2": "Möchtest du stattdessen nur das Ende der Datei anzeigen? Das aktiviert ausserdem die Folgen- und Verfolgen-Funktion, welche neu hinzugefügte Textzeilen in Echtzeit anzeigt",
	"fbd_more": '<div id="blazy">zeige <code>{0}</code> von <code>{1}</code> Dateien; <a href="#" id="bd_more">{2} anzeigen</a> oder <a href="#" id="bd_all">alle anzeigen</a></div>',
	"fbd_all": '<div id="blazy">zeige <code>{0}</code> von <code>{1}</code> Dateien; <a href="#" id="bd_all">alle anzeigen</a></div>',
	"f_anota": "nur {0} der {1} Elemente wurden ausgewählt;\num den gesamten Ordner auszuwählen, zuerst nach unten scrollen",

	"f_dls": 'die Dateilinks im aktuellen Ordner wurden\nin Downloadlinks geändert',
	"f_dl_nd": 'ordner wird übersprungen (bitte zip/tar-download verwenden):\n', //m

	"f_partial": "Um eine Datei sicher herunterzuladen, die gerade hochgeladen wird, klicke bitte die Datei mit dem gleichen Namen, aber ohne die <code>.PARTIAL</code>-Endung. Bitte drücke Abbrechen oder Escape, um dies zu tun.\n\nWenn du auf OK / Eingabe drückst, ignorierst du diese Warnung und lädst die <code>.PARTIAL</code>-Datei herunter, die ziemlich sicher beschädigte Daten enthält.",

	"ft_paste": "{0} Elemente einfügen$NHotkey: STRG-V",
	"fr_eperm": 'Umbenennen fehlgeschlagen:\nDir fehlt die "Verschieben"-Berechtigung in diesem Ordner',
	"fd_eperm": 'Löschen fehlgeschlagen:\nDir fehlt die "Löschen"-Berechtigung in diesem Ordner',
	"fc_eperm": 'Ausschneiden fehlgeschlagen:\nDir fehlt die "Verschieben"-Berechtigung in diesem Ordner',
	"fp_eperm": 'Einfügen fehlgeschlagen:\nDir fehlt die "Schreiben"-Berechtigung in diesem Ordner',
	"fr_emore": "Wähle mindestens ein Element zum Umbenennen aus",
	"fd_emore": "Wähle mindestens ein Element zum Löschen aus",
	"fc_emore": "Wähle mindestens ein Element zum Ausschneiden aus",
	"fcp_emore": "Wähle mindestens ein Element aus, um es in die Zwischenablage zu kopieren",

	"fs_sc": "Teile diesen Ordner",
	"fs_ss": "Teile die ausgewählten Dateien",
	"fs_just1d": "Du kannst nicht mehrere Ordner auswählen \noder Dateien und Ordner in der Auswahl mischen.",
	"fs_abrt": "❌ Abbrechen",
	"fs_rand": "🎲 Zufallsname",
	"fs_go": "✅ Share erstellen",
	"fs_name": "Name",
	"fs_src": "Quelle",
	"fs_pwd": "Passwort",
	"fs_exp": "Ablauf",
	"fs_tmin": "Minuten",
	"fs_thrs": "Stunden",
	"fs_tdays": "Tage",
	"fs_never": "nie",
	"fs_pname": "optionaler Linkname; zufällig wenn leer",
	"fs_tsrc": "zu teilende Datei oder Ordner",
	"fs_ppwd": "optionales Passwort",
	"fs_w8": "erstelle Share...",
	"fs_ok": "drücke <code>Eingabe/OK</code> für Zwischenablage\ndrücke <code>ESC/Abbrechen</code> zum Schliessen",

	"frt_dec": "Kann Fälle von beschädigten Dateien beheben\">url-decode",
	"frt_rst": "Geänderte Dateinamen auf Orginale zurücksetzen\">↺ zurücksetzen",
	"frt_abrt": "Abbrechen und dieses Fenster schliessen\">❌ abbrechen",
	"frb_apply": "ÜBERNEHMEN",
	"fr_adv": "Stapel-/Metadaten-/Musterumbenennung\">erweitert",
	"fr_case": "Groß-/Kleinschreibung beachten (Regex)\">Großschreibung",
	"fr_win": "Windows-kompatible Namen; ersetzt <code>&lt;&gt;:&quot;\\|?*</code> durch japanische Fullwidth-Zeichen\">win",
	"fr_slash": "Ersetzt <code>/</code> durch ein Zeichen, das keine neuen Ordner erstellt\">no /",
	"fr_re": "`Regex-Suchmuster für Originaldateinamen; Erfassungsgruppen können im Formatfeld unten als `(1)` und `(2)` usw. referenziert werden",
	"fr_fmt": "`inspiriert von foobar2000:$N`(title)` wird durch Songtitel ersetzt,$N`[(artist) - ](title)` überspringt [diesen] Teil falls Interpret leer$N`$lpad((tn),2,0)` füllt die Titelnummer auf 2 Ziffern auf",
	"fr_pdel": "Löschen",
	"fr_pnew": "Speichern als",
	"fr_pname": "Gib der Vorlage einen Namen",
	"fr_aborted": "Abgebrochen",
	"fr_lold": "Alter Name",
	"fr_lnew": "Neuer Name",
	"fr_tags": "Tags für die ausgewählten Dateien (liest nur, als Referenz):",
	"fr_busy": "Benenne {0} Elemente um...\n\n{1}",
	"fr_efail": "Umbenennen fehlgeschlagen:\n",
	"fr_nchg": "{0} der neuen Namen wurden angepasst durch <code>win</code> und/oder <code>no /</code>\n\nMöchtest du mit diesen geänderten Namen fortfahren?",

	"fd_ok": "Löschen OK",
	"fd_err": "Löschen fehlgeschlagen:\n",
	"fd_none": "Nichts würde gelöscht; vielleicht durch die Serverkonfiguration blockiert (xbd)?",
	"fd_busy": "Lösche {0} Elemente...\n\n{1}",
	"fd_warn1": "Diese {0} Elemente LÖSCHEN?",
	"fd_warn2": "<b>Ich frage das letzte Mal!</b> Was weg ist, ist weg. Keine Chance, das rückgängig zu machen. Löschen?",

	"fc_ok": "{0} Elemente ausgeschnitten",
	"fc_warn": '{0} Elemente in die Zwischenablage kopiert\n\nAber: nur <b>dieses</b> Browsertab kann sie einfügen\n(da deine Auswahl so abartig riesig war)',

	"fcc_ok": "{0} Elemente in die Zwischenablage kopiert",
	"fcc_warn": '{0} Elemente in die Zwischenablage kopiert\n\nAber: nur <b>dieses</b> Browsertab kann sie einfügen\n(da deine Auswahl so abartig riesig war)',

	"fp_apply": "Diese Namen verwenden",
	"fp_skip": "Konflikte überspringen",
	"fp_ecut": "Kopiere erst ein paar Dateien / Ordner, um sie einzufügen\n\nTipp: Ausschneiden und Kopieren funktioniert über Browsertabs hinweg",
	"fp_ename": '{0} Elemente konnten nicht verschoben werden, weil bereits andere Dateien mit diesen Namen existieren. Gib ihnen unten neue Namen um fortzufahren, oder lass das Feld leer um sie zu überspringen ("Konflikte überspringen" macht das automatisch):',
	"fcp_ename": '{0} Elemente konnten nicht kopiert werden, weil bereits andere Dateien mit diesen Namen existieren. Gib ihnen unten neue Namen um fortzufahren, oder lass das Feld leer um sie zu überspringen ("Konflikte überspringen" macht das automatisch):',
	"fp_emore": "Es gibt noch ein paar Dateinamen, die geändert werden müssen",
	"fp_ok": "Verschieben OK",
	"fcp_ok": "Kopieren OK",
	"fp_busy": "Verschiebe {0} Elemente...\n\n{1}",
	"fcp_busy": "Kopiere {0} Elemente...\n\n{1}",
	"fp_abrt": "wird abgebrochen...",
	"fp_err": "Verschieben fehlgeschlagen:\n",
	"fcp_err": "Kopieren fehlgeschlagen:\n",
	"fp_confirm": "Diese {0} Elemente hierher verschieben?",
	"fcp_confirm": "Diese {0} Elemente hierher kopieren?",
	"fp_etab": 'Konnte die Zwischenablage nicht vom anderen Browsertab lesen',
	"fp_name": "Lade Datei von deinem Gerät hoch. Gib ihr einen Namen:",
	"fp_both_m": '<h6>Wähle, was eingefügt werden soll</h6><code>Eingabe</code> = {0} Dateien von «{1}» verschieben\n<code>ESC</code> = {2} Dateien von deinem Gerät hochladen',
	"fcp_both_m": '<h6>Wähle, was eingefügt werden soll</h6><code>Eingabe</code> = {0} Dateien von «{1}» kopieren\n<code>ESC</code> = {2} Dateien von deinem Gerät hochladen',
	"fp_both_b": '<a href="#" id="modal-ok">Verschieben</a><a href="#" id="modal-ng">Hochladen</a>',
	"fcp_both_b": '<a href="#" id="modal-ok">Kopieren</a><a href="#" id="modal-ng">Hochladen</a>',

	"mk_noname": "Tipp' mal vorher lieber einen Namen in das Textfeld links, bevor du das machst :p",
	"nmd_i1": "Füge auch die Dateiendung hinzu, z.B. <code>.md</code>",
	"nmd_i2": "Du kannst nur <code>.{0}</code>-Dateien erstellen, da dir Lösch-Rechte fehlen",

	"tv_load": "Textdatei wird geladen:\n\n{0}\n\n{1}% ({2} von {3} MiB geladen)",
	"tv_xe1": "Konnte Textdatei nicht laden:\n\nFehler ",
	"tv_xe2": "404, Datei nicht gefunden",
	"tv_lst": "Liste der Textdateien in",
	"tvt_close": "Zu Ordneransicht zurück$NHotkey: M (oder Esc)\">❌ Schliessen",
	"tvt_dl": "Diese Datei herunterladen$NHotkey: Y\">💾 Herunterladen",
	"tvt_prev": "Vorheriges Dokument zeigen$NHotkey: i\">⬆ vorh.",
	"tvt_next": "Nächstes Dokument zeigen$NHotkey: K\">⬇ nächst.",
	"tvt_sel": "Wählt diese Datei aus &nbsp; ( zum Ausschneiden / Kopieren / Löschen / ... )$NHotkey: S\">ausw.",
	"tvt_j": "json verschönern$NHotkey: shift-J\">j",
	"tvt_edit": "Datei im Texteditor zum Bearbeiten öffnen$NHotkey: E\">✏️ bearb.",
	"tvt_tail": "Datei auf Veränderungen überwachen; Neue Zeilen werden in Echtzeit angezeigt\">📡 folgen",
	"tvt_wrap": "Zeilenumbruch\">↵",
	"tvt_atail": "Automatisch nach unten scrollen\">⚓",
	"tvt_ctail": "Terminal-Farben dekodieren (ANSI Escape Codes)\">🌈",
	"tvt_ntail": "Scrollback limitieren (Menge an Bytes an Text, die geladen bleiben sollen)",

	"m3u_add1": "Song wurde zur M3U-Playlist hinzugefügt",
	"m3u_addn": "{0} Songs zur M3U-Playlist hinzugefügt",
	"m3u_clip": "M3U-Playlist in die Zwischenablage kopiert\n\nDu solltest eine neue Datei mit dem Namen something.m3u erstellen und die Playlist da rein kopieren; damit wird die Playlist abspielbar",

	"gt_vau": "nur Ton abspielen, kein Video zeigen\">🎧",
	"gt_msel": "Dateiauswahl aktivieren; STRG-klicke eine Datei zum überschreiben$N$N&lt;em&gt;wenn aktiv: Datei / Ordner doppelklicken zum Öffnen&lt;/em&gt;$N$NHotkey: S\">multiselect",
	"gt_crop": "Vorschaubilder mittig zuschneiden\">crop",
	"gt_3x": "hochauflösende Vorschaubilder\">3x",
	"gt_zoom": "zoom",
	"gt_chop": "kürzen",
	"gt_sort": "sortieren nach",
	"gt_name": "Name",
	"gt_sz": "Grösse",
	"gt_ts": "Datum",
	"gt_ext": "Typ",
	"gt_c1": "Dateinamen mehr kürzen (weniger zeigen)",
	"gt_c2": "Dateinamen weniger kürzen (mehr zeigen)",

	"sm_w8": "Suche ...",
	"sm_prev": "Die Suchresultate gehören zu einer vorherigen Suchanfrage:\n  ",
	"sl_close": "Suchresultate schliessen",
	"sl_hits": "Zeige {0} Treffer",
	"sl_moar": "Mehr laden",

	"s_sz": "Grösse",
	"s_dt": "Datum",
	"s_rd": "Pfad",
	"s_fn": "Name",
	"s_ta": "Tags",
	"s_ua": "up@",
	"s_ad": "adv.",
	"s_s1": "minimum MiB",
	"s_s2": "maximum MiB",
	"s_d1": "min. iso8601",
	"s_d2": "max. iso8601",
	"s_u1": "hochgeladen nach",
	"s_u2": "und/oder vor",
	"s_r1": "Pfad enthält &nbsp; (Leerzeichen-separiert)",
	"s_f1": "Name enthält &nbsp; (negieren mit -nope)",
	"s_t1": "Tags enthält &nbsp; (^=start, end=$)",
	"s_a1": "spezifische Metadaten-Eigenschaften",

	"md_eshow": "Kann nicht rendern ",
	"md_off": "[📜<em>readme</em>] deaktiviert in [⚙️] -- Dokument versteckt",

	"badreply": "Hab die Antwort vom Server nicht verstanden. (badreply)",

	"xhr403": "403: Zugriff verweigert\n\nVersuche, F5 zu drücken. Vielleicht wurdest du abgemeldet.",
	"xhr0": "Unbekannt (wahrschenlich Verbindung zum Server verloren oder der Server ist offline)",
	"cf_ok": "Sorry dafür -- Der DD" + wah + "oS-Schutz hat angeschlagen.\n\nEs sollte in etwa 30 Sekunden weitergehen.\n\nFalls nichts passiert, drück' F5, um die Seite neuzuladen",
	"tl_xe1": "Konnte Unterordner nicht auflisten:\n\nFehler ",
	"tl_xe2": "404: Ordner nicht gefunden",
	"fl_xe1": "Konnte Dateien in Ordner nicht auflisten:\n\nFehler ",
	"fl_xe2": "404: Ordner nicht gefunden",
	"fd_xe1": "Konnte Unterordner nicht erstellen:\n\nFehler ",
	"fd_xe2": "404: Übergeordneter Ordner nicht gefunden",
	"fsm_xe1": "Konnte Nachricht nicht senden:\n\nFehler ",
	"fsm_xe2": "404: Übergeordneter Ordner nicht gefunden",
	"fu_xe1": "Konnte unpost-Liste nicht laden:\n\nFehler ",
	"fu_xe2": "404: Datei nicht gefunden??",

	"fz_tar": "Unkomprimierte GNU TAR-Datei (Linux / Mac)",
	"fz_pax": "Unkomprimierte pax-Format TAR-Datei (langsamer)",
	"fz_targz": "GNU-TAR mit gzip Level 3 Kompression$N$Nüblicherweise recht langsam,$Nbenutze stattdessen ein unkomprimiertes TAR",
	"fz_tarxz": "GNU-TAR mit xz level 1 Kompression$N$Nüblicherweise recht langsam,$Nbenutze stattdessen ein unkomprimiertes TAR",
	"fz_zip8": "ZIP mit UTF8-Dateinamen (könnte kaputt gehen auf Windows 7 oder älter)",
	"fz_zipd": "ZIP mit traditionellen CP437-Dateinamen, für richtig alte Software",
	"fz_zipc": "CP437 mit früh berechnetem CRC32,$Nfür MS-DOS PKZIP v2.04g (Oktober 1993)$N(braucht länger zum Verarbeiten, bevor der Download starten kann)",

	"un_m1": "Unten kannst du deine neusten Uploads löschen (oder unvollständige abbrechen)",
	"un_upd": "Neu laden",
	"un_m4": "Oder die unten sichtbaren Dateien teilen:",
	"un_ulist": "Anzeigen",
	"un_ucopy": "Kopieren",
	"un_flt": "Optionale Filter:&nbsp; URL muss enthalten",
	"un_fclr": "Filter löschen",
	"un_derr": 'unpost-delete fehlgeschlagen:\n',
	"un_f5": 'Etwas ist kaputt gegangen, versuche die Seite neuzuladen (drücke dazu F5)',
	"un_uf5": "Sorry, aber du musst die Seite neuladen (z.B. in dem du F5 oder STRG-R drückst) bevor zu diesen Upload abbrechen kannst",
	"un_nou": '<b>Warnung:</b> Der Server ist grade zu beschäftigt, um unvollständige Uploads anzuzeigen; Drücke den "Neu laden"-Link in ein paar Sekunden',
	"un_noc": '<b>Warnung:</b> unpost von vollständig hochgeladenen Dateien ist über die Serverkonfiguration gesperrt',
	"un_max": "Zeige die ersten 2000 Dateien (benutze Filter, um die gewünschten Dateien zu finden)",
	"un_avail": "{0} zuletzt hochgeladene Dateien können gelöscht werden<br />{1} Unvollständige können abgebrochen werden",
	"un_m2": "Sortiert nach Upload-Zeitpunkt; neuste zuerst:",
	"un_no1": "Hoppala! Es gibt keine ausreichend aktuellen Uploads.",
	"un_no2": "Pech gehabt! Kein Upload, der zu dem Filter passen würde, ist neu genug",
	"un_next": "Lösche die nächsten {0} Dateien",
	"un_abrt": "Abbrechen",
	"un_del": "Löschen",
	"un_m3": "Deine letzten Uploads werden geladen ...",
	"un_busy": "Lösche {0} Dateien ...",
	"un_clip": "{0} Links in die Zwischenablage kopiert",

	"u_https1": "für bessere Performance solltest du",
	"u_https2": "auf HTTPS wechseln",
	"u_https3": " ",
	"u_ancient": 'Dein Browser ist verdammt antik -- vielleicht solltest du <a href="#" onclick="goto(\'bup\')">stattdessen bup benutzen</a>',
	"u_nowork": "Benötigt Firefox 53+ oder Chrome 57+ oder iOS 11+",
	"tail_2old": "Benötigt Firefox 105+ oder Chrome 71+ oder iOS 14.5+",
	"u_nodrop": 'Dein Browser ist zu alt für Drag-and-Drop Uploads',
	"u_notdir": "Das ist kein Ordner!\n\nDein Browser ist zu alt,\nversuch stattdessen dragdrop",
	"u_uri": "Um Bilder per Drag-and-Drop aus anderen Browserfenstern hochzuladen,\nlass' sie bitte über dem grossen Upload-Button fallen",
	"u_enpot": 'Zu <a href="#">Potato UI</a> wechseln (kann Upload-Geschw. verbessern)',
	"u_depot": 'Zu <a href="#">fancy UI</a> wechseln (kann Upload-Geschw. verschlechtern)',
	"u_gotpot": 'Wechsle zu Potato UI für verbesserte Upload-Geschwindigkeit,\n\nwenn du anderer Meinung bist, kannst du gerne zurück wechseln',
	"u_pott": "<p>Dateien: &nbsp; <b>{0}</b> fertig, &nbsp; <b>{1}</b> fehlgeschlagen, &nbsp; <b>{2}</b> in Bearbeitung, &nbsp; <b>{3}</b> ausstehend</p>",
	"u_ever": "Dies ist der Basic Uploader; up2k benötigt mind. <br>Chrome 21 // Firefox 13 // Edge 12 // Opera 12 // Safari 5.1",
	"u_su2k": 'Dies ist der Basic Uploader; <a href="#" id="u2yea">up2k</a> ist besser',
	"u_uput": 'Für Geschwindigkeit optimieren (Checksum überspringen)',
	"u_ewrite": 'Du hast kein Schreibzugriff auf diesen Ordner',
	"u_eread": 'Du hast kein Lesezugriff auf diesen Ordner',
	"u_enoi": 'file-search ist in der Serverkonfiguration nicht aktiviert',
	"u_enoow": "Überschreiben wird hier nicht funktionieren; benötige Lösch-Berechtigung",
	"u_badf": 'Diese {0} Dateien (von insgesammt {1}) wurden übersprungen, wahrscheinlich wegen Dateisystem-Berechtigungen:\n\n',
	"u_blankf": 'Diese {0} Dateien (von insgesammt {1}) sind leer; trotzdem hochladen?\n\n',
	"u_applef": 'Diese {0} Dateien (von insgesammt {1}) sind möglicherweise unerwünscht;\n<code>OK/Eingabe</code> drücken, um die folgenden Dateien zu überspringen.\nDrücke <code>Abbrechen/ESC</code> um sie NICHT zu überspringen und diese AUCH HOCHZULADEN:\n\n',
	"u_just1": '\nFunktioniert vielleicht besser, wenn du nur eine Datei auswählst',
	"u_ff_many": "Falls du <b>Linux / MacOS / Android</b> benutzt, <a href=\"https://bugzilla.mozilla.org/show_bug.cgi?id=1790500\" target=\"_blank\"><em>könnte</em> Firefox mit dieser Menge an Dateien crashen!</a>\nFalls das passiert, probier nochmal (oder benutz Chrome).",
	"u_up_life": "Dieser Upload wird vom Server gelöscht\n{0} nachdem er abgeschlossen ist",
	"u_asku": 'Diese {0} Dateien nach <code>{1}</code> hochladen',
	"u_unpt": "Du kannst diesen Upload rückgängig machen mit dem 🧯 oben-links",
	"u_bigtab": 'Versuche {0} Dateien anzuzeigen.\n\nDas könnte dein Browser crashen, bist du dir wirklich sicher?',
	"u_scan": 'Scanne Dateien...',
	"u_dirstuck": 'Ordner-Iterator blieb hängen beim Versuch, diese {0} Einträge zu lesen; überspringe:',
	"u_etadone": 'Fertig ({0}, {1} Dateien)',
	"u_etaprep": '(Upload wird vorbereitet)',
	"u_hashdone": 'Hashing vollständig',
	"u_hashing": 'Hash',
	"u_hs": 'Wir schütteln uns die Hände ("handshaking")...',
	"u_started": "Dateien werden hochgeladen; siehe [🚀]",
	"u_dupdefer": "Duplikat; wird nach allen anderen Dateien verarbeitet",
	"u_actx": "Klicke diesen Text um Performance-<br />Einbusen zu Vermeiden beim Wechsel auf andere Fenster/Tabs",
	"u_fixed": "OK!&nbsp; Habs repariert 👍",
	"u_cuerr": "failed to upload chunk {0} of {1};\nprobably harmless, continuing\n\nfile: {2}",
	"u_cuerr2": "server rejected upload (chunk {0} of {1});\nwill retry later\n\nfile: {2}\n\nerror ",
	"u_ehstmp": "versuche nochmal; siehe unten-rechts",
	"u_ehsfin": "Der Server hat die Anfrage zum Abschluss des Uploads abgelehnt; versuche nochmal...",
	"u_ehssrch": "Der Server hat die Anfrage zur Suche abgelehnt; versuche nochmal...",
	"u_ehsinit": "Der Server hat die Anfrage zum Start des Uploads abgelehnt; versuche nochmal...",
	"u_eneths": "Netzwerkfehler beim Upload-Handshake; versuche nochmal...",
	"u_enethd": "Netzwerkfehler beim Testen der Existenz des Ziels; versuche nochmal...",
	"u_cbusy": "Der Server mag uns grade nicht mehr nach einem Netzwerkglitch, warte einen Moment...",
	"u_ehsdf": "Server hat kein Speicherplatz mehr!\n\nwerde es erneut versuchen, falls jemand\ngenug Platz schafft um fortzufahren",
	"u_emtleak1": "scheint, als ob dein Browser ein Memory Leak hätte;\nbitte",
	"u_emtleak2": ' <a href="{0}">wechsle auf HTTPS (empfohlen)</a> oder ',
	"u_emtleak3": ' ',
	"u_emtleakc": 'versuche folgendes:\n<ul><li>drücke <code>F5</code> um die Seite neu zu laden</li><li>deaktivere dann den &nbsp;<code>mt</code>&nbsp; Button in den &nbsp;<code>⚙️ Einstellungen</code></li><li>und versuche den Upload nochmal.</li></ul>Uploads werden etwas langsamer sein, aber man kann ja nicht alles haben.\nSorry für die Umstände !\n\nPS: Chrome v107 <a href="https://bugs.chromium.org/p/chromium/issues/detail?id=1354816" target="_blank">hat ein Bugfix</a> dafür',
	"u_emtleakf": 'versuche folgendes:\n<ul><li>drücke <code>F5</code> um die Seite neu zu laden</li><li>aktivere dann <code>🥔</code> (potato) im Upload UI<li>und versuche den Upload nochmal</li></ul>\nPS: Firefox <a href="https://bugzilla.mozilla.org/show_bug.cgi?id=1790500" target="_blank">hat hoffentlich irgendwann ein Bugfix</a>',
	"u_s404": "nicht auf dem Server gefunden",
	"u_expl": "erklären",
	"u_maxconn": "die meisten Browser limitieren dies auf 6, aber Firefox lässt mehr zu unter <code>connections-per-server</code> in <code>about:config</code>",
	"u_tu": '<p class="warn">WARNUNG: Turbo aktiviert, <span>&nbsp;Client könnte unvollständige Uploads verpassen und nicht wiederholen; siehe Turbo-Button Tooltip</span></p>',
	"u_ts": '<p class="warn">WARNUNG: Turbo aktiviert, <span>&nbsp;Suchresultate können inkorrekt sein; siehe Turbo-Button Tooltip</span></p>',
	"u_turbo_c": "Turbo deaktiviert in der Serverkonfiguration",
	"u_turbo_g": "Turbo deaktiviert, da du keine Listen-Berechtigung\nauf diesem Volume hast",
	"u_life_cfg": 'Autodelete nach <input id="lifem" p="60" /> min (or <input id="lifeh" p="3600" /> h)',
	"u_life_est": 'Upload wird gelöscht <span id="lifew" tt="local time">---</span>',
	"u_life_max": 'Dieser Ordner erzwingt eine\nmax Lebensdauer von {0}',
	"u_unp_ok": 'unpost ist erlaubt für {0}',
	"u_unp_ng": 'unpost wird NICHT erlaubt',
	"ue_ro": 'Du hast nur Lese-Zugriff auf diesen Ordner\n\n',
	"ue_nl": 'Du bist nicht angemeldet',
	"ue_la": 'Du bist angemeldet als "{0}"',
	"ue_sr": 'Du bist derzeit im Suchmodus\n\nWechsle zum Upload-Modus indem du auf die Lupe 🔎 klickst (neben dem grossen SUCHEN Button), und versuche den Upload nochmal.\n\nSorry',
	"ue_ta": 'Versuche den Upload nochmal, sollte jetzt klappen',
	"ue_ab": "Diese Datei wird gerade in einem anderen Ordner hochgeladen, dieser Upload muss zuerst abgeschlossen werden, bevor die Datei woanders hochgeladen werden kann.\n\nDu kannst den Upload abbrechen und vergessen mit dem 🧯 oben-links",
	"ur_1uo": "OK: Datei erfolgreich hochgeladen",
	"ur_auo": "OK: Alle {0} Dateien erfolgreich hochgeladen",
	"ur_1so": "OK: Datei auf dem Server gefunden",
	"ur_aso": "OK: Alle {0} Dateien auf dem Server gefunden",
	"ur_1un": "Upload fehlgeschlagen, sorry",
	"ur_aun": "Alle {0} Uploads fehlgeschlagen, sorry",
	"ur_1sn": "Datei wurde NICHT auf dem Server gefunden",
	"ur_asn": "Die {0} Dateien wurden NICHT auf dem Server gefunden",
	"ur_um": "Fertig;\n{0} Uploads OK,\n{1} Uploads fehlgeschlagen, sorry",
	"ur_sm": "Fertig;\n{0} Uploads gefunden auf dem Server,\n{1} Dateien NICHT gefunden auf dem Server",

	"rc_opn": "öffnen",
	"rc_ply": "abspielen",
	"rc_pla": "als Audio abspielen",
	"rc_txt": "als Text öffnen",
	"rc_md": "im Texteditor öffnen",
	"rc_dl": "herunterladen",
	"rc_zip": "als Archiv herunterladen",
	"rc_cpl": "Link kopieren", //m
	"rc_del": "löschen",
	"rc_cut": "ausschneiden",
	"rc_cpy": "kopieren",
	"rc_pst": "einfügen",
	"rc_rnm": "umbenennen", //m
	"rc_nfo": "neuer Ordner",
	"rc_nfi": "neue Datei",
	"rc_sal": "alles auswählen",
	"rc_sin": "auswahl umkehren",
	"rc_shf": "diesen ordner teilen", //m
	"rc_shs": "auswahl teilen", //m

	"lang_set": "Neuladen um Änderungen anzuwenden?",

	"splash": {
		"a1": "Neu laden",
		"b1": "Tach, wie geht's? &nbsp; <small>(Du bist nicht angemeldet)</small>",
		"c1": "Abmelden",
		"d1": "Zustand",
		"d2": "Zeigt den Zustand aller aktiven Threads",
		"e1": "Config neu laden",
		"e2": "Konfigurationsdatei neu laden (Accounts/Volumes/VolFlags)$Nund scannt alle e2ds-Volumes$N$NBeachte: Jegliche Änderung an globalen Einstellungen$Nbenötigt einen Neustart zum Anwenden",
		"f1": "Du kannst lesen:",
		"g1": "Du kannst hochladen nach:",
		"cc1": "Andere Dinge:",
		"h1": "k304 deaktivieren",
		"i1": "k304 aktivieren",
		"j1": "k304 trennt die Clientverbindung bei jedem HTTP 304, was Bugs mit problematischen Proxies vorbeugen kann (z.B. nicht ladenden Seiten), macht Dinge aber generell langsamer",
		"k1": "Client-Einstellungen zurücksetzen",
		"l1": "Melde dich an für mehr:",
		"ls3": "Anmelden",
		"lu4": "Benutzername",
		"lp4": "Passwort",
		"lo3": "“{0}” überall abmelden",
		"lo2": "Das beendet die Sitzung in allen Browsern",
		"m1": "Willkommen zurück,",
		"n1": "404 Nicht gefunden &nbsp;┐( ´ -`)┌",
		"o1": 'or maybe you don\'t have access -- try a password or <a href="' + SR + '/?h">go home</a>',
		"p1": "403 Verboten &nbsp;~┻━┻",
		"q1": 'Benutze ein Passwort oder <a href="' + SR + '/?h">gehe zur Homepage</a>',
		"r1": "Gehe zur Homepage",
		".s1": "Neu scannen",
		"t1": "Aktion",
		"u2": "time since the last server write$N( upload / rename / ... )$N$N17d = 17 days$N1h23 = 1 hour 23 minutes$N4m56 = 4 minutes 56 seconds",
		"v1": "Verbinden",
		"v2": "Benutze diesen Server als lokale Festplatte",
		"w1": "Zu HTTPS wechseln",
		"x1": "Passwort ändern",
		"y1": "Shares bearbeiten",
		"z1": "Share entsperren:",
		"ta1": "Trage zuerst dein Passwort ein",
		"ta2": "Wiederhole dein Passwort zur Bestätigung:",
		"ta3": "Da stimmt etwas nicht; probier's nochmal",
		"nop": "FEHLER: Passwort darf nicht leer sein",
		"nou": "FEHLER: Benutzername und/oder Passwort dürfen nicht leer sein",
		"aa1": "Eingehende Dateien:",
		"ab1": "no304 deaktivieren",
		"ac1": "no304 aktivieren",
		"ad1": "Das Aktivieren von no304 deaktiviert jegliche Form von Caching; probier dies, wenn k304 nicht genug war. Dies verschwendet eine grosse Menge Netzwerk-Traffic!",
		"ae1": "Aktive Downloads:",
		"af1": "Zeige neue Uploads",
		"ag1": "Bekannte IdP-Benutzer anzeigen", //m
	}
};
